@@ -53,8 +53,8 @@ using namespace ::com::sun::star;
 bool SbiRuntime::isVBAEnabled()
 {
     bool result = false;
-    SbiInstance* pInst = pINST;
-    if ( pInst && pINST->pRun )
+    SbiInstance* pInst = GetSbData()->pInst;
+    if ( pInst && GetSbData()->pInst->pRun )
         result = pInst->pRun->bVBAEnabled;
     return result;
 }
@@ -196,7 +196,7 @@ SbiRuntime::pStep2 SbiRuntime::aStep2[] = {// all opcodes with two operands
     &SbiRuntime::StepSTMNT,         // beginning of a statement (+Line+Col)
     // E/A
     &SbiRuntime::StepOPEN,          // (+SvStreamFlags+Flags)
-    // Objekte
+    // Objects
     &SbiRuntime::StepLOCAL,     // define local variable (+StringId+Typ)
     &SbiRuntime::StepPUBLIC,        // module global variable (+StringID+Typ)
     &SbiRuntime::StepGLOBAL,        // define global variable (+StringID+Typ)
@@ -519,7 +519,7 @@ SbMethod* SbiInstance::GetCaller( sal_uInt16 nLevel )
 // Attention: pMeth can also be NULL (on a call of the init-code)
 
 SbiRuntime::SbiRuntime( SbModule* pm, SbMethod* pe, sal_uInt32 nStart )
-         : rBasic( *(StarBASIC*)pm->pParent ), pInst( pINST ),
+         : rBasic( *(StarBASIC*)pm->pParent ), pInst( GetSbData()->pInst ),
            pMod( pm ), pMeth( pe ), pImg( pMod->pImage ), mpExtCaller(0), m_nLastTime(0)
 {
     nFlags    = pe ? pe->GetDebugFlags() : 0;
@@ -711,17 +711,17 @@ sal_Bool SbiRuntime::Step()
 
         SbiOpcode eOp = (SbiOpcode ) ( *pCode++ );
         sal_uInt32 nOp1, nOp2;
-        if (eOp < SbOP0_END)
+        if( eOp <= SbOP0_END )
         {
             (this->*( aStep0[ eOp ] ) )();
         }
-        else if (eOp >= SbOP1_START && eOp < SbOP1_END)
+        else if( eOp >= SbOP1_START && eOp <= SbOP1_END )
         {
             nOp1 = *pCode++; nOp1 |= *pCode++ << 8; nOp1 |= *pCode++ << 16; nOp1 |= *pCode++ << 24;
 
             (this->*( aStep1[ eOp - SbOP1_START ] ) )( nOp1 );
         }
-        else if (eOp >= SbOP2_START && eOp < SbOP2_END)
+        else if( eOp >= SbOP2_START && eOp <= SbOP2_END )
         {
             nOp1 = *pCode++; nOp1 |= *pCode++ << 8; nOp1 |= *pCode++ << 16; nOp1 |= *pCode++ << 24;
             nOp2 = *pCode++; nOp2 |= *pCode++ << 8; nOp2 |= *pCode++ << 16; nOp2 |= *pCode++ << 24;
@@ -794,11 +794,6 @@ sal_Bool SbiRuntime::Step()
 
                 if( pRtErrHdl )
                 {
-                    SbErrorStack*& rErrStack = GetSbData()->pErrStack;
-                    if( rErrStack )
-                        delete rErrStack;
-                    rErrStack = new SbErrorStack();
-
                     // manipulate all the RTs that are below in the call-stack
                     pRt = this;
                     do
@@ -806,14 +801,9 @@ sal_Bool SbiRuntime::Step()
                         pRt->nError = err;
                         if( pRt != pRtErrHdl )
                             pRt->bRun = sal_False;
-
-                        SbErrorStackEntry *pEntry = new SbErrorStackEntry
-                            ( pRt->pMeth, pRt->nLine, pRt->nCol1, pRt->nCol2 );
-                        rErrStack->C40_INSERT(SbErrorStackEntry, pEntry, rErrStack->Count() );
-
-                        if( pRt == pRtErrHdl )
+                        else
                             break;
-                           pRt = pRt->pNext;
+                        pRt = pRt->pNext;
                     }
                     while( pRt );
                 }
@@ -912,11 +902,6 @@ SbMethod* SbiRuntime::GetCaller()
     return pMeth;
 }
 
-SbxArray* SbiRuntime::GetParams()
-{
-    return refParams;
-}
-
 //  Stacks
 
 // The expression-stack is available for the continous evaluation
