@@ -99,13 +99,14 @@ rtl::OUString toString(css::uno::TypeDescription const & type) {
     return rtl::OUString(d->pTypeName);
 }
 
-extern "C" void SAL_CALL freeProxyCallback(uno_ExtEnvironment *, void * pProxy)
+extern "C" void SAL_CALL freeProxyCallback(
+    SAL_UNUSED_PARAMETER uno_ExtEnvironment *, void * pProxy)
 {
     assert(pProxy != 0);
     static_cast< Proxy * >(pProxy)->do_free();
 }
 
-bool isThread(osl::Thread * thread) {
+bool isThread(salhelper::Thread * thread) {
     assert(thread != 0);
     return osl::Thread::getCurrentIdentifier() == thread->getIdentifier();
 }
@@ -245,14 +246,14 @@ void Bridge::start() {
         writer_ = w;
         state_ = STATE_STARTED;
     }
-    // It is important to call reader_->create() last here; both
+    // It is important to call reader_->launch() last here; both
     // Writer::execute and Reader::execute can call Bridge::terminate, but
     // Writer::execute is initially blocked in unblocked_.wait() until
     // Reader::execute has called bridge_->sendRequestChangeRequest(), so
-    // effectively only reader_->create() can lead to an early call to
+    // effectively only reader_->launch() can lead to an early call to
     // Bridge::terminate
-    w->create();
-    r->create();
+    w->launch();
+    r->launch();
 }
 
 void Bridge::terminate(bool final) {
@@ -413,7 +414,7 @@ css::uno::UnoInterfaceReference Bridge::registerIncomingInterface(
     rtl::OUString const & oid, css::uno::TypeDescription const & type)
 {
     assert(type.is());
-    if (oid.getLength() == 0) {
+    if (oid.isEmpty()) {
         return css::uno::UnoInterfaceReference();
     }
     css::uno::UnoInterfaceReference obj(findStub(oid, type));
@@ -495,7 +496,7 @@ rtl::OUString Bridge::registerOutgoingInterface(
 css::uno::UnoInterfaceReference Bridge::findStub(
     rtl::OUString const & oid, css::uno::TypeDescription const & type)
 {
-    assert(oid.getLength() != 0 && type.is());
+    assert(!oid.isEmpty() && type.is());
     osl::MutexGuard g(mutex_);
     Stubs::iterator i(stubs_.find(oid));
     if (i != stubs_.end()) {
@@ -517,7 +518,7 @@ css::uno::UnoInterfaceReference Bridge::findStub(
 void Bridge::releaseStub(
     rtl::OUString const & oid, css::uno::TypeDescription const & type)
 {
-    assert(oid.getLength() != 0 && type.is());
+    assert(!oid.isEmpty() && type.is());
     css::uno::UnoInterfaceReference obj;
     bool unused;
     {
@@ -806,8 +807,7 @@ void Bridge::handleCommitChangeRequest(
     assert(ok);
     (void) ok; // avoid warnings
     for (sal_Int32 i = 0; i != s.getLength(); ++i) {
-        if (s[i].Name.equalsAsciiL(
-                RTL_CONSTASCII_STRINGPARAM("CurrentContext")))
+        if ( s[i].Name == "CurrentContext" )
         {
             ccMode = true;
         } else {
@@ -889,7 +889,7 @@ Bridge::~Bridge() {
 css::uno::Reference< css::uno::XInterface > Bridge::getInstance(
     rtl::OUString const & sInstanceName) throw (css::uno::RuntimeException)
 {
-    if (sInstanceName.getLength() == 0) {
+    if (sInstanceName.isEmpty()) {
         throw css::uno::RuntimeException(
             rtl::OUString(
                 RTL_CONSTASCII_USTRINGPARAM(
