@@ -175,20 +175,20 @@ static sal_Int32 readLogLevelFromConfiguration()
     osl_getModuleURLFromAddress(
         (void*) readLogLevelFromConfiguration, (rtl_uString **) &fileName );
     fileName = OUString( fileName.getStr(), fileName.lastIndexOf( '/' )+1 );
-    fileName += OUString::createFromAscii(  SAL_CONFIGFILE("postgresql-sdbc.uno") );
+    fileName += OUString::createFromAscii( "postgresql-sdbc.ini" );
     rtl::Bootstrap bootstrapHandle( fileName );
 
     OUString str;
     if( bootstrapHandle.getFrom( ASCII_STR( "PQ_LOGLEVEL" ), str ) )
     {
-        if( str.equalsAscii( "NONE" ) )
+        if ( str == "NONE" )
             loglevel = LogLevel::NONE;
-        else if( str.equalsAscii( "ERROR" ) )
+        else if ( str == "ERROR" )
             loglevel = LogLevel::ERROR;
-        else if( str.equalsAscii( "SQL" ) )
-            loglevel = LogLevel::SQL;
-        else if( str.equalsAscii( "INFO" ) )
+        else if ( str == "SQL" )
             loglevel = LogLevel::SQL;
+        else if ( str == "INFO" )
+            loglevel = LogLevel::INFO;
         else
         {
             fprintf( stderr, "unknown loglevel %s\n",
@@ -785,20 +785,7 @@ static struct cppu::ImplementationEntry g_entries[] =
 extern "C"
 {
 
-//==================================================================================================
-void SAL_CALL component_getImplementationEnvironment(
-    const sal_Char ** ppEnvTypeName, uno_Environment ** )
-{
-    *ppEnvTypeName = CPPU_CURRENT_LANGUAGE_BINDING_NAME;
-}
-//==================================================================================================
-sal_Bool SAL_CALL component_writeInfo(
-    void * pServiceManager, void * pRegistryKey )
-{
-    return cppu::component_writeInfoHelper( pServiceManager, pRegistryKey, g_entries );
-}
-//==================================================================================================
-void * SAL_CALL component_getFactory(
+SAL_DLLPUBLIC_EXPORT void * SAL_CALL component_getFactory(
     const sal_Char * pImplName, void * pServiceManager, void * pRegistryKey )
 {
     return cppu::component_getFactoryHelper( pImplName, pServiceManager, pRegistryKey , g_entries );
