@@ -464,7 +464,7 @@ void ExtensionManager::activateExtension(
             //Check if this is a disabled user extension,
             if (i == 0 && bUserDisabled)
             {
-                   aExt->revokePackage(xAbortChannel, xCmdEnv);
+                   aExt->revokePackage(bStartup, xAbortChannel, xCmdEnv);
                    continue;
             }
 
@@ -473,7 +473,7 @@ void ExtensionManager::activateExtension(
             //repositories with a lower priority
             if (bActive)
             {
-                aExt->revokePackage(xAbortChannel, xCmdEnv);
+                aExt->revokePackage(bStartup, xAbortChannel, xCmdEnv);
             }
             else
             {
@@ -694,7 +694,7 @@ Reference<deploy::XPackage> ExtensionManager::addExtension(
                     try
                     {
                         xOldExtension->revokePackage(
-                            xAbortChannel, Reference<ucb::XCommandEnvironment>());
+                            false, xAbortChannel, Reference<ucb::XCommandEnvironment>());
                         //save the old user extension in case the user aborts
                         //store the extension in the tmp repository, this will overwrite
                         //xTmpPackage (same identifier). Do not let the user abort or
@@ -873,7 +873,7 @@ void ExtensionManager::removeExtension(
         Reference<deploy::XPackage> xOldExtension =
             xPackageManager->getDeployedPackage(
                 identifier, fileName, xCmdEnv);
-        xOldExtension->revokePackage(xAbortChannel, xCmdEnv);
+        xOldExtension->revokePackage(false, xAbortChannel, xCmdEnv);
 
         xPackageManager->removePackage(
             identifier, fileName, xAbortChannel, xCmdEnv);
@@ -1024,7 +1024,7 @@ sal_Int32 ExtensionManager::checkPrerequisitesAndEnable(
         if (ret)
         {
             //There are some unfulfilled prerequisites, try to revoke
-            extension->revokePackage(xAbortChannel, xCmdEnv);
+            extension->revokePackage(false, xAbortChannel, xCmdEnv);
         }
         const OUString id(dp_misc::getIdentifier(extension));
         activateExtension(id, extension->getName(),
@@ -1181,7 +1181,7 @@ uno::Sequence< uno::Sequence<Reference<deploy::XPackage> > >
               citVecVec = vecExtensions.begin();
         sal_Int32 j = 0;
         uno::Sequence< uno::Sequence<Reference<deploy::XPackage> > > seqSeq(vecExtensions.size());
-        for (;citVecVec != vecExtensions.end(); citVecVec++, j++)
+        for (;citVecVec != vecExtensions.end(); ++citVecVec, j++)
         {
             seqSeq[j] = comphelper::containerToSequence(*citVecVec);
         }
@@ -1223,7 +1223,7 @@ void ExtensionManager::reinstallDeployedExtensions(
         xPackageManager->reinstallDeployedPackages(xAbortChannel, xCmdEnv);
         //We must sync here, otherwise we will get exceptions when extensions
         //are removed.
-        dp_misc::syncRepositories(xCmdEnv);
+        dp_misc::syncRepositories(false, xCmdEnv);
         const uno::Sequence< Reference<deploy::XPackage> > extensions(
             xPackageManager->getDeployedPackages(xAbortChannel, xCmdEnv));
 
@@ -1233,7 +1233,7 @@ void ExtensionManager::reinstallDeployedExtensions(
             {
                 const OUString id =  dp_misc::getIdentifier(extensions[ pos ]);
                 const OUString fileName = extensions[ pos ]->getName();
-                OSL_ASSERT(id.getLength());
+                OSL_ASSERT(!id.isEmpty());
                 activateExtension(id, fileName, false, true, xAbortChannel, xCmdEnv );
             }
             catch (const lang::DisposedException &)
@@ -1506,28 +1506,6 @@ extern sdecl::ServiceDecl const serviceDecl(
     "com.sun.star.comp.deployment.ExtensionManager",
     "com.sun.star.comp.deployment.ExtensionManager");
 
-//------------------------------------------------------------------------------
-bool singleton_entries(
-    uno::Reference< registry::XRegistryKey > const & xRegistryKey )
-{
-    try {
-        uno::Reference< registry::XRegistryKey > xKey(
-            xRegistryKey->createKey(
-                serviceDecl.getImplementationName() +
-                // xxx todo: use future generated function to get singleton name
-                OUSTR("/UNO/SINGLETONS/"
-                      "com.sun.star.deployment.ExtensionManager") ) );
-        xKey->setStringValue( serviceDecl.getSupportedServiceNames()[0] );
-        return true;
-    }
-    catch (const registry::InvalidRegistryException & exc) {
-        (void) exc; // avoid warnings
-        OSL_FAIL( ::rtl::OUStringToOString(
-                        exc.Message, RTL_TEXTENCODING_UTF8 ).getStr() );
-        return false;
-    }
-}
-
 // XModifyBroadcaster
 //______________________________________________________________________________
 void ExtensionManager::addModifyListener(
