@@ -32,6 +32,7 @@
 #include "dp_platform.hxx"
 #include "dp_manager.h"
 #include "dp_identifier.hxx"
+#include "rtl/oustringostreaminserter.hxx"
 #include "rtl/ustrbuf.hxx"
 #include "rtl/string.hxx"
 #include "rtl/uri.hxx"
@@ -61,10 +62,8 @@
 #include "com/sun/star/task/XInteractionApprove.hpp"
 #include "com/sun/star/ucb/UnsupportedCommandException.hpp"
 #include "boost/bind.hpp"
-#include "tools/urlobj.hxx"
 #include "unotools/tempfile.hxx"
 
-#include "osl/file.hxx"
 #include <vector>
 #include <list>
 #include "dp_descriptioninfoset.hxx"
@@ -104,12 +103,9 @@ namespace {
 OUString getExtensionFolder(OUString const &  parentFolder,
                             Reference<ucb::XCommandEnvironment> const & xCmdEnv)
 {
-    ::ucbhelper::Content tempFolder(
-        parentFolder, xCmdEnv );
+    ::ucbhelper::Content tempFolder( parentFolder, xCmdEnv );
     Reference<sdbc::XResultSet> xResultSet(
-        tempFolder.createCursor(
-            Sequence<OUString>( &StrTitle::get(), 1 ),
-            ::ucbhelper::INCLUDE_FOLDERS_ONLY ) );
+                StrTitle::createCursor (tempFolder, ::ucbhelper::INCLUDE_FOLDERS_ONLY ) );
 
     OUString title;
     while (xResultSet->next())
@@ -125,9 +121,9 @@ OUString getExtensionFolder(OUString const &  parentFolder,
 void PackageManagerImpl::initActivationLayer(
     Reference<XCommandEnvironment> const & xCmdEnv )
 {
-    if (m_activePackages.getLength() == 0)
+    if (m_activePackages.isEmpty())
     {
-        OSL_ASSERT( m_registryCache.getLength() == 0 );
+        OSL_ASSERT( m_registryCache.isEmpty() );
         // documents temp activation:
         m_activePackagesDB.reset( new ActivePackages );
         ::ucbhelper::Content ucbContent;
@@ -136,22 +132,16 @@ void PackageManagerImpl::initActivationLayer(
         {
             // scan for all entries in m_packagesDir:
             Reference<sdbc::XResultSet> xResultSet(
-                ucbContent.createCursor(
-                    Sequence<OUString>( &StrTitle::get(), 1 ),
-                    ::ucbhelper::INCLUDE_FOLDERS_AND_DOCUMENTS ) );
+                        StrTitle::createCursor (ucbContent, ::ucbhelper::INCLUDE_FOLDERS_AND_DOCUMENTS ) );
+
             while (xResultSet->next())
             {
                 Reference<sdbc::XRow> xRow( xResultSet, UNO_QUERY_THROW );
                 OUString title( xRow->getString( 1 /* Title */ ) );
                 // xxx todo: remove workaround for tdoc
-                if (title.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM(
-                                            "this_is_a_dummy_stream_just_there_"
-                                            "as_a_workaround_for_a_"
-                                            "temporary_limitation_of_the_"
-                                            "storage_api_implementation") ))
+                if ( title == "this_is_a_dummy_stream_just_there_as_a_workaround_for_a_temporary_limitation_of_the_storage_api_implementation" )
                     continue;
-                if (title.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM(
-                                             "META-INF") ) )
+                if ( title == "META-INF" )
                     continue;
 
                 ::ucbhelper::Content sourceContent(
@@ -161,7 +151,7 @@ void PackageManagerImpl::initActivationLayer(
 
                 OUString mediaType( detectMediaType( sourceContent,
                                                      false /* no throw */) );
-                if (mediaType.getLength() >0)
+                if (!mediaType.isEmpty())
                 {
                     ActivePackages::Data dbData;
                     insertToActivationLayer(
@@ -180,7 +170,7 @@ void PackageManagerImpl::initActivationLayer(
     else
     {
         // user|share:
-        OSL_ASSERT( m_activePackages.getLength() > 0 );
+        OSL_ASSERT( !m_activePackages.isEmpty() );
         m_activePackages_expanded = expandUnoRcUrl( m_activePackages );
         m_registrationData_expanded = expandUnoRcUrl(m_registrationData);
         if (!m_readOnly)
@@ -203,12 +193,11 @@ void PackageManagerImpl::initActivationLayer(
             // clean up activation layer, scan for zombie temp dirs:
             ActivePackages::Entries id2temp( m_activePackagesDB->getEntries() );
 
-            ::ucbhelper::Content tempFolder(
-                m_activePackages_expanded, xCmdEnv );
+            ::ucbhelper::Content tempFolder( m_activePackages_expanded, xCmdEnv );
             Reference<sdbc::XResultSet> xResultSet(
-                tempFolder.createCursor(
-                    Sequence<OUString>( &StrTitle::get(), 1 ),
-                    ::ucbhelper::INCLUDE_DOCUMENTS_ONLY ) );
+                StrTitle::createCursor (tempFolder,
+                                         ::ucbhelper::INCLUDE_DOCUMENTS_ONLY ) );
+
             // get all temp directories:
             ::std::vector<OUString> tempEntries;
             ::std::vector<OUString> removedEntries;
@@ -304,7 +293,7 @@ void PackageManagerImpl::initActivationLayer(
 //______________________________________________________________________________
 void PackageManagerImpl::initRegistryBackends()
 {
-    if (m_registryCache.getLength() > 0)
+    if (!m_registryCache.isEmpty())
         create_folder( 0, m_registryCache,
                        Reference<XCommandEnvironment>(), false);
     m_xRegistry.set( ::dp_registry::create(
@@ -312,6 +301,41 @@ void PackageManagerImpl::initRegistryBackends()
                          m_xComponentContext ) );
 }
 
+// this overcomes previous rumours that the sal API is misleading
+// as to whether a directory is truly read-only or not
+static bool isMacroURLReadOnly( const OUString &rMacro )
+{
+    rtl::OUString aDirURL( rMacro );
+    ::rtl::Bootstrap::expandMacros( aDirURL );
+
+    ::osl::FileBase::RC aErr = ::osl::Directory::create( aDirURL );
+    if ( aErr == ::osl::FileBase::E_None )
+        return false; // it will be writeable
+    if ( aErr != ::osl::FileBase::E_EXIST )
+        return true; // some serious problem creating it
+
+    bool bError;
+    sal_uInt64 nWritten = 0;
+    rtl::OUString aFileURL( aDirURL + "/stamp.sys" );
+    ::osl::File aFile( aFileURL );
+
+    bError = aFile.open( osl_File_OpenFlag_Read |
+                         osl_File_OpenFlag_Write |
+                         osl_File_OpenFlag_Create ) != ::osl::FileBase::E_None;
+    if (!bError)
+        bError = aFile.write( "1", 1, nWritten ) != ::osl::FileBase::E_None;
+    if (aFile.close() != ::osl::FileBase::E_None)
+        bError = true;
+    if (osl::File::remove( aFileURL ) != ::osl::FileBase::E_None)
+        bError = true;
+
+    SAL_INFO(
+        "desktop.deployment",
+        "local url '" << rMacro << "' -> '" << aFileURL << "' "
+            << (bError ? "is" : "is not") << " readonly\n");
+    return bError;
+}
+
 //______________________________________________________________________________
 Reference<deployment::XPackageManager> PackageManagerImpl::create(
     Reference<XComponentContext> const & xComponentContext,
@@ -321,8 +345,8 @@ Reference<deployment::XPackageManager> PackageManagerImpl::create(
         xComponentContext, context );
     Reference<deployment::XPackageManager> xPackageManager( that );
 
-    OUString packages, logFile, stampURL;
-    if (context.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM("user") )) {
+    OUString packages, logFile, stamp;
+    if ( context == "user" ) {
         that->m_activePackages = OUSTR(
             "vnd.sun.star.expand:$UNO_USER_PACKAGES_CACHE/uno_packages");
         that->m_registrationData = OUSTR(
@@ -342,10 +366,9 @@ Reference<deployment::XPackageManager> PackageManagerImpl::create(
         //using virtualization it appears that he/she can. Then a shared extension can
         //be installed but is only visible for the user (because the extension is in
         //the virtual store).
-        stampURL = OUSTR(
-            "vnd.sun.star.expand:$UNO_USER_PACKAGES_CACHE/stamp.sys");
+        stamp = OUSTR("$UNO_USER_PACKAGES_CACHE");
     }
-    else if (context.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM("shared") )) {
+    else if ( context == "shared" ) {
         that->m_activePackages = OUSTR(
             "vnd.sun.star.expand:$UNO_SHARED_PACKAGES_CACHE/uno_packages");
         that->m_registrationData = OUSTR(
@@ -354,10 +377,9 @@ Reference<deployment::XPackageManager> PackageManagerImpl::create(
             "vnd.sun.star.expand:$SHARED_EXTENSIONS_USER/registry");
         logFile = OUSTR(
             "vnd.sun.star.expand:$SHARED_EXTENSIONS_USER/log.txt");
-        stampURL = OUSTR(
-            "vnd.sun.star.expand:$UNO_SHARED_PACKAGES_CACHE/stamp.sys");
+        stamp = OUSTR("$UNO_SHARED_PACKAGES_CACHE");
     }
-    else if (context.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM("bundled") )) {
+    else if ( context == "bundled" ) {
         that->m_activePackages = OUSTR(
             "vnd.sun.star.expand:$BUNDLED_EXTENSIONS");
         that->m_registrationData = OUSTR(
@@ -369,7 +391,7 @@ Reference<deployment::XPackageManager> PackageManagerImpl::create(
         //No stamp file. We assume that bundled is always readonly. It must not be
         //modified from ExtensionManager but only by the installer
     }
-    else if (context.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM("bundled_prereg") )) {
+    else if ( context == "bundled_prereg" ) {
         //This is a bundled repository but the registration data
         //is in the brand layer: share/prereg
         //It is special because the registration data are copied at the first startup
@@ -387,15 +409,14 @@ Reference<deployment::XPackageManager> PackageManagerImpl::create(
         logFile = OUSTR(
             "vnd.sun.star.expand:$BUNDLED_EXTENSIONS_PREREG/log.txt");
     }
-    else if (context.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM("tmp") )) {
+    else if ( context == "tmp" ) {
         that->m_activePackages = OUSTR(
             "vnd.sun.star.expand:$TMP_EXTENSIONS/extensions");
         that->m_registrationData = OUSTR(
             "vnd.sun.star.expand:$TMP_EXTENSIONS");
         that->m_registryCache = OUSTR(
             "vnd.sun.star.expand:$TMP_EXTENSIONS/registry");
-        stampURL = OUSTR(
-            "vnd.sun.star.expand:$TMP_EXTENSIONS/stamp.sys");
+        stamp = OUSTR("$TMP_EXTENSIONS");
     }
     else if (! context.matchAsciiL(
                  RTL_CONSTASCII_STRINGPARAM("vnd.sun.star.tdoc:/") )) {
@@ -407,41 +428,11 @@ Reference<deployment::XPackageManager> PackageManagerImpl::create(
     Reference<XCommandEnvironment> xCmdEnv;
 
     try {
-        //There is no stampURL for the bundled folder
-        if (stampURL.getLength() > 0)
-        {
-#define CURRENT_STAMP "1"
-            try {
-                //The osl file API does not allow to find out if one can write
-                //into a folder. Therefore we try to write a file. Then we delete
-                //it, so that it does not hinder uninstallation of OOo
-                // probe writing:
-                ::ucbhelper::Content ucbStamp( stampURL, xCmdEnv );
-                ::rtl::OString stamp(
-                    RTL_CONSTASCII_STRINGPARAM(CURRENT_STAMP) );
-                Reference<io::XInputStream> xData(
-                    ::xmlscript::createInputStream(
-                        ::rtl::ByteSequence(
-                            reinterpret_cast<sal_Int8 const *>(stamp.getStr()),
-                            stamp.getLength() ) ) );
-                ucbStamp.writeStream( xData, true /* replace existing */ );
-                that->m_readOnly = false;
-                erase_path( stampURL, xCmdEnv );
-            }
-            catch (const RuntimeException &) {
-                try {
-                    erase_path( stampURL, xCmdEnv );
-                } catch (...)
-                {
-                }
-                throw;
-            }
-            catch (const Exception &) {
-                that->m_readOnly = true;
-            }
-        }
+        // There is no stamp for the bundled folder:
+        if (!stamp.isEmpty())
+            that->m_readOnly = isMacroURLReadOnly( stamp );
 
-        if (!that->m_readOnly && logFile.getLength() > 0)
+        if (!that->m_readOnly && !logFile.isEmpty())
         {
             const Any any_logFile(logFile);
             that->m_xLogFile.set(
@@ -601,9 +592,9 @@ OUString PackageManagerImpl::detectMediaType(
         }
         catch (const beans::UnknownPropertyException &) {
         }
-        OSL_ENSURE( mediaType.getLength() > 0, "### no media-type?!" );
+        OSL_ENSURE( !mediaType.isEmpty(), "### no media-type?!" );
     }
-    if (mediaType.getLength() == 0)
+    if (mediaType.isEmpty())
     {
         try {
             Reference<deployment::XPackage> xPackage(
@@ -772,8 +763,7 @@ Reference<deployment::XPackage> PackageManagerImpl::addPackage(
     try {
         ::ucbhelper::Content sourceContent;
         create_ucb_content( &sourceContent, url, xCmdEnv ); // throws exc
-        const OUString title(sourceContent.getPropertyValue(
-                             StrTitle::get() ).get<OUString>() );
+        const OUString title( StrTitle::getTitle( sourceContent ) );
         const OUString title_enc( ::rtl::Uri::encode(
                                       title, rtl_UriCharClassPchar,
                                       rtl_UriEncodeIgnoreEscapes,
@@ -781,14 +771,14 @@ Reference<deployment::XPackage> PackageManagerImpl::addPackage(
         OUString destFolder;
 
         OUString mediaType(mediaType_);
-        if (mediaType.getLength() == 0)
+        if (mediaType.isEmpty())
             mediaType = detectMediaType( sourceContent );
 
         Reference<deployment::XPackage> xPackage;
         // copy file:
         progressUpdate(
             getResourceString(RID_STR_COPYING_PACKAGE) + title, xCmdEnv );
-        if (m_activePackages.getLength() == 0)
+        if (m_activePackages.isEmpty())
         {
             ::ucbhelper::Content docFolderContent;
             create_folder( &docFolderContent, m_context, xCmdEnv );
@@ -940,7 +930,7 @@ void PackageManagerImpl::removePackage(
             {
                 ActivePackages::Data val;
                 m_activePackagesDB->get( & val, id, fileName);
-                OSL_ASSERT(val.temporaryName.getLength());
+                OSL_ASSERT(!val.temporaryName.isEmpty());
                 OUString url(makeURL(m_activePackages_expanded,
                                      val.temporaryName + OUSTR("removed")));
                 ::ucbhelper::Content contentRemoved(url, xCmdEnv );
@@ -1037,7 +1027,7 @@ Reference<deployment::XPackage> PackageManagerImpl::getDeployedPackage_(
         if (INetContentTypes::parse( data.mediaType, type, subType, &params ))
         {
             INetContentTypeParameter const * param = params.find(
-                ByteString("platform") );
+                rtl::OString("platform") );
             if (param != 0 && !platform_fits( param->m_sValue ))
                 throw lang::IllegalArgumentException(
                     getResourceString(RID_STR_NO_SUCH_PACKAGE) + id,
@@ -1217,7 +1207,7 @@ void PackageManagerImpl::reinstallDeployedPackages(
 
         try_dispose( m_xRegistry );
         m_xRegistry.clear();
-        if (m_registryCache.getLength() > 0)
+        if (!m_registryCache.isEmpty())
             erase_path( m_registryCache, xCmdEnv );
         initRegistryBackends();
         Reference<util::XUpdatable> xUpdatable( m_xRegistry, UNO_QUERY );
@@ -1332,15 +1322,15 @@ bool PackageManagerImpl::synchronizeRemovedExtensions(
                 Reference<deployment::XPackage> xPackage = m_xRegistry->bindPackage(
                     url, i->second.mediaType, true, i->first, xCmdEnv );
                 OSL_ASSERT(xPackage.is()); //Even if the files are removed, we must get the object.
-                xPackage->revokePackage(xAbortChannel, xCmdEnv);
+                xPackage->revokePackage(true, xAbortChannel, xCmdEnv);
                 removePackage(xPackage->getIdentifier().Value, xPackage->getName(),
                               xAbortChannel, xCmdEnv);
                 bModified |= true;
             }
         }
-        catch( const uno::Exception & )
+        catch( const uno::Exception & e )
         {
-            OSL_ASSERT(0);
+            SAL_WARN("desktop.deployment", e.Message);
         }
     }
     return bModified;
@@ -1360,13 +1350,11 @@ bool PackageManagerImpl::synchronizeAddedExtensions(
     if (!create_ucb_content(
             NULL, m_activePackages_expanded, Reference<css::ucb::XCommandEnvironment>(), false))
         return bModified;
-    ::ucbhelper::Content tempFolder(
-        m_activePackages_expanded, xCmdEnv );
 
+    ::ucbhelper::Content tempFolder( m_activePackages_expanded, xCmdEnv );
     Reference<sdbc::XResultSet> xResultSet(
-        tempFolder.createCursor(
-            Sequence<OUString>( &StrTitle::get(), 1 ),
-            ::ucbhelper::INCLUDE_FOLDERS_ONLY ) );
+        StrTitle::createCursor( tempFolder,
+                                ::ucbhelper::INCLUDE_FOLDERS_ONLY ) );
 
     while (xResultSet->next())
     {
@@ -1430,7 +1418,7 @@ bool PackageManagerImpl::synchronizeAddedExtensions(
                         dbData.fileName = title;
                     dbData.mediaType = xPackage->getPackageType()->getMediaType();
                     dbData.version = xPackage->getVersion();
-                    OSL_ENSURE(dbData.version.getLength() > 0,
+                    OSL_ENSURE(!dbData.version.isEmpty(),
                                "Extension Manager: bundled and shared extensions must have "
                                "an identifier and a version");
 
