@@ -204,6 +204,7 @@ public:
                css::ucb::CommandAbortedException,
                css::lang::IllegalArgumentException, css::uno::RuntimeException);
     virtual void SAL_CALL revokePackage(
+        sal_Bool startup,
         css::uno::Reference<css::task::XAbortChannel> const & xAbortChannel,
         css::uno::Reference<css::ucb::XCommandEnvironment> const & xCmdEnv )
         throw (css::deployment::DeploymentException,
@@ -368,7 +369,7 @@ public:
     getComponentContext() const { return m_xComponentContext; }
 
     inline ::rtl::OUString const & getCachePath() const { return m_cachePath; }
-    inline bool transientMode() const { return m_cachePath.getLength() == 0; }
+    inline bool transientMode() const { return m_cachePath.isEmpty(); }
 
     inline ::rtl::OUString getContext() const {return m_context; }
 
