@@ -56,7 +56,6 @@
 #include <i18npool/mslangid.hxx>
 #include <tools/urlobj.hxx>
 #include <tools/resmgr.hxx>
-#include <tools/debug.hxx>
 #include <tools/wldcrd.hxx>
 #include <rtl/ustrbuf.hxx>
 #include <rtl/bootstrap.hxx>
@@ -679,7 +678,7 @@ throw ( NoSuchElementException, RuntimeException )
 //      protected methods
 //_________________________________________________________________________________________________________________
 
-IMPL_LINK( SubstitutePathVariables, implts_ConfigurationNotify, SubstitutePathNotify*, EMPTYARG )
+IMPL_LINK_NOARG(SubstitutePathVariables, implts_ConfigurationNotify)
 {
     /* SAFE AREA ----------------------------------------------------------------------------------------------- */
     ResetableGuard aLock( m_aLock );
@@ -690,17 +689,17 @@ IMPL_LINK( SubstitutePathVariables, implts_ConfigurationNotify, SubstitutePathNo
 rtl::OUString SubstitutePathVariables::ConvertOSLtoUCBURL( const rtl::OUString& aOSLCompliantURL ) const
 {
     RTL_LOGFILE_CONTEXT_AUTHOR( aLogger, "framework", "Ocke.Janssen@sun.com", "SubstitutePathVariables::ConvertOSLtoUCBURL" );
-    String                  aResult;
+    rtl::OUString aResult;
     rtl::OUString   aTemp;
 
     osl::FileBase::getSystemPathFromFileURL( aOSLCompliantURL, aTemp );
     utl::LocalFileHelper::ConvertPhysicalNameToURL( aTemp, aResult );
 
     // Not all OSL URL's can be mapped to UCB URL's!
-    if ( aResult.Len() == 0 )
+    if ( aResult.isEmpty() )
         return aOSLCompliantURL;
     else
-        return rtl::OUString( aResult );
+        return aResult;
 }
 
 rtl::OUString SubstitutePathVariables::GetWorkPath() const
@@ -717,12 +716,12 @@ rtl::OUString SubstitutePathVariables::GetWorkPath() const
                             ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("WritePath")),
                             ::comphelper::ConfigurationHelper::E_READONLY) >>= aWorkPath;
     }
-    catch(RuntimeException &)
+    catch(const RuntimeException &)
     {
     }
 
     // fallback in case config layer does not return an useable work dir value.
-    if (aWorkPath.getLength() < 1)
+    if (aWorkPath.isEmpty())
         aWorkPath = GetWorkVariableValue();
 
     return aWorkPath;
@@ -742,13 +741,13 @@ rtl::OUString SubstitutePathVariables::GetWorkVariableValue() const
                             ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Work")),
                             ::comphelper::ConfigurationHelper::E_READONLY) >>= aWorkPath;
     }
-    catch(RuntimeException &)
+    catch(const RuntimeException &)
     {
     }
 
     // fallback to $HOME in case platform dependend config layer does not return
     // an usuable work dir value.
-    if (aWorkPath.getLength() < 1)
+    if (aWorkPath.isEmpty())
     {
         osl::Security aSecurity;
         aSecurity.getHomeDir( aWorkPath );
@@ -785,7 +784,7 @@ rtl::OUString SubstitutePathVariables::GetPathVariableValue() const
         do
         {
             ::rtl::OUString sToken = aPathList.getToken(0, SAL_PATHSEPARATOR, nToken);
-            if (sToken.getLength())
+            if (!sToken.isEmpty())
             {
                 osl::FileBase::getFileURLFromSystemPath( sToken, aTmp );
                 if ( bAppendSep )
@@ -1017,10 +1016,10 @@ throw ( RuntimeException )
         if ( osl::FileBase::getFileURLFromSystemPath( rURL, aTemp ) == osl::FileBase::E_None )
         {
             aTemp = ConvertOSLtoUCBURL( aTemp );
-            if ( aTemp.getLength() )
+            if ( !aTemp.isEmpty() )
             {
                 aURL = INetURLObject( aTemp ).GetMainURL( INetURLObject::NO_DECODE );
-                if( !aURL.getLength() )
+                if( aURL.isEmpty() )
                     return rURL;
             }
             else
@@ -1174,10 +1173,7 @@ void SubstitutePathVariables::SetPredefinedPathVariables( PredefinedPathVariable
         aPreDefPathVariables.m_FixedVar[PREDEFVAR_BRANDBASEURL]);
 
     Any             aAny;
-    ::rtl::OUString aOfficePath;
-    ::rtl::OUString aUserPath;
     ::rtl::OUString aTmp;
-    ::rtl::OUString aTmp2;
     String          aResult;
 
     // Get inspath and userpath from bootstrap mechanism in every case as file URL
