@@ -95,9 +95,6 @@ void DiagramData::dump()
                   boost::bind( &dgm::Point::dump, _1 ) );
 }
 
-void DiagramLayout::layout( const dgm::Points & /*pTree*/, const awt::Point & /*pt*/ )
-{
-}
 
 void Diagram::setData( const DiagramDataPtr & pData)
 {
@@ -138,10 +135,10 @@ static sal_Int32 calcDepth( const rtl::OUString& rNodeName,
     const dgm::Connections::const_iterator aEndCxn( rCnx.end() );
     while( aCurrCxn != aEndCxn )
     {
-        if( aCurrCxn->msParTransId.getLength() &&
-            aCurrCxn->msSibTransId.getLength() &&
-            aCurrCxn->msSourceId.getLength() &&
-            aCurrCxn->msDestId.getLength() &&
+        if( !aCurrCxn->msParTransId.isEmpty() &&
+            !aCurrCxn->msSibTransId.isEmpty() &&
+            !aCurrCxn->msSourceId.isEmpty() &&
+            !aCurrCxn->msDestId.isEmpty() &&
             aCurrCxn->mnType != XML_presOf &&
             aCurrCxn->mnType != XML_presParOf &&
             rNodeName == aCurrCxn->msDestId )
@@ -176,7 +173,7 @@ void Diagram::build(  )
                << normalizeDotName(aCurrPoint->msModelId).getStr()
                << "[";
 
-        if( aCurrPoint->msPresentationLayoutName.getLength() )
+        if( !aCurrPoint->msPresentationLayoutName.isEmpty() )
             output << "label=\""
                    << rtl::OUStringToOString(
                        aCurrPoint->msPresentationLayoutName,
@@ -230,7 +227,7 @@ void Diagram::build(  )
 
         OSL_ENSURE(bInserted1,"Diagram::build(): non-unique point model id");
 
-        if( aCurrPoint->msPresentationLayoutName.getLength() )
+        if( !aCurrPoint->msPresentationLayoutName.isEmpty() )
         {
             DiagramData::PointsNameMap::value_type::second_type& rVec=
                 getData()->getPointsPresNameMap()[aCurrPoint->msPresentationLayoutName];
@@ -244,11 +241,11 @@ void Diagram::build(  )
     while( aCurrCxn != aEndCxn )
     {
 #if OSL_DEBUG_LEVEL > 1
-        if( aCurrCxn->msParTransId.getLength() ||
-            aCurrCxn->msSibTransId.getLength() )
+        if( !aCurrCxn->msParTransId.isEmpty() ||
+            !aCurrCxn->msSibTransId.isEmpty() )
         {
-            if( aCurrCxn->msSourceId.getLength() ||
-                aCurrCxn->msDestId.getLength() )
+            if( !aCurrCxn->msSourceId.isEmpty() ||
+                !aCurrCxn->msDestId.isEmpty() )
             {
                 output << "\t"
                        << normalizeDotName(aCurrCxn->msSourceId).getStr()
@@ -279,8 +276,8 @@ void Diagram::build(  )
                        << "\"];" << std::endl;
             }
         }
-        else if( aCurrCxn->msSourceId.getLength() ||
-                 aCurrCxn->msDestId.getLength() )
+        else if( !aCurrCxn->msSourceId.isEmpty() ||
+                 !aCurrCxn->msDestId.isEmpty() )
             output << "\t"
                    << normalizeDotName(aCurrCxn->msSourceId).getStr()
                    << " -> "
@@ -344,16 +341,6 @@ void Diagram::addTo( const ShapePtr & pParentShape )
         mpLayout->getNode()->accept( aCreationVisitor );
 }
 
-OUString Diagram::getLayoutId() const
-{
-    OUString sLayoutId;
-    if( mpLayout )
-    {
-        sLayoutId = mpLayout->getUniqueId();
-    }
-    return sLayoutId;
-}
-
 uno::Reference<xml::dom::XDocument> loadFragment(
     core::XmlFilterBase& rFilter,
     const rtl::Reference< core::FragmentHandler >& rxHandler )
@@ -392,7 +379,7 @@ void loadDiagram( ShapePtr& pShape,
     pDiagram->setLayout( pLayout );
 
     // data
-    if( rDataModelPath.getLength() > 0 )
+    if( !rDataModelPath.isEmpty() )
     {
         rtl::Reference< core::FragmentHandler > xRef(
             new DiagramDataFragmentHandler( rFilter, rDataModelPath, pData ));
@@ -408,44 +395,40 @@ void loadDiagram( ShapePtr& pShape,
                 pShape->addExtDrawingRelId( *aIt );
     }
 
-    // extLst is present, lets bet on that and ignore the rest of the data from here
-    if( !pData->getExtDrawings().size() )
+    // layout
+    if( !rLayoutPath.isEmpty() )
     {
-        // layout
-        if( !rLayoutPath.isEmpty() )
-        {
-            rtl::Reference< core::FragmentHandler > xRef(
-                    new DiagramLayoutFragmentHandler( rFilter, rLayoutPath, pLayout ));
-            importFragment(rFilter,
-                    loadFragment(rFilter,xRef),
-                    "DiagramLayout",
-                    pShape,
-                    xRef);
-        }
+        rtl::Reference< core::FragmentHandler > xRef(
+            new DiagramLayoutFragmentHandler( rFilter, rLayoutPath, pLayout ));
+        importFragment(rFilter,
+                       loadFragment(rFilter,xRef),
+                       "DiagramLayout",
+                       pShape,
+                       xRef);
+    }
 
-        // style
-        if( !rQStylePath.isEmpty() )
-        {
-            rtl::Reference< core::FragmentHandler > xRef(
-                    new DiagramQStylesFragmentHandler( rFilter, rQStylePath, pDiagram->getStyles() ));
-            importFragment(rFilter,
-                    loadFragment(rFilter,xRef),
-                    "DiagramQStyle",
-                    pShape,
-                    xRef);
-        }
+    // style
+    if( !rQStylePath.isEmpty() )
+    {
+        rtl::Reference< core::FragmentHandler > xRef(
+            new DiagramQStylesFragmentHandler( rFilter, rQStylePath, pDiagram->getStyles() ));
+        importFragment(rFilter,
+                       loadFragment(rFilter,xRef),
+                       "DiagramQStyle",
+                       pShape,
+                       xRef);
+    }
 
-        // colors
-        if( !rColorStylePath.isEmpty() )
-        {
-            rtl::Reference< core::FragmentHandler > xRef(
-                    new ColorFragmentHandler( rFilter, rColorStylePath, pDiagram->getColors() ));
-            importFragment(rFilter,
-                    loadFragment(rFilter,xRef),
-                    "DiagramColorStyle",
-                    pShape,
-                    xRef);
-        }
+    // colors
+    if( !rColorStylePath.isEmpty() )
+    {
+        rtl::Reference< core::FragmentHandler > xRef(
+            new ColorFragmentHandler( rFilter, rColorStylePath, pDiagram->getColors() ));
+        importFragment(rFilter,
+                       loadFragment(rFilter,xRef),
+                       "DiagramColorStyle",
+                       pShape,
+                       xRef);
     }
 
     // diagram loaded. now lump together & attach to shape
