@@ -188,7 +188,7 @@ namespace
         virtual ::com::sun::star::uno::Any operator() (const ::rtl::OUString& _sPropertyName,const ::com::sun::star::uno::Any& lhs) const
         {
             uno::Any aRet;
-            if ( _sPropertyName.equalsAscii(PROPERTY_PARAADJUST) )
+            if (_sPropertyName.equalsAsciiL(PROPERTY_PARAADJUST.ascii, PROPERTY_PARAADJUST.length))
             {
                 sal_Int16 nTextAlign = 0;
                 lhs >>= nTextAlign;
@@ -393,7 +393,7 @@ void OObjectBase::EndListening(sal_Bool /*bRemoveListener*/)
             {
                 m_xReportComponent->removePropertyChangeListener( ::rtl::OUString() , m_xPropertyChangeListener );
             }
-            catch(uno::Exception)
+            catch(const uno::Exception &)
             {
                 OSL_FAIL("OObjectBase::EndListening: Exception caught!");
             }
@@ -629,7 +629,7 @@ OUnoObject::OUnoObject(const ::rtl::OUString& _sComponentName
           ,m_nObjectType(_nObjectType)
 {
     DBG_CTOR( rpt_OUnoObject, NULL);
-    if ( rModelName.getLength() )
+    if ( !rModelName.isEmpty() )
         impl_initializeModel_nothrow();
 }
 //----------------------------------------------------------------------------
@@ -643,11 +643,9 @@ OUnoObject::OUnoObject(const uno::Reference< report::XReportComponent>& _xCompon
     DBG_CTOR( rpt_OUnoObject, NULL);
     impl_setUnoShape( uno::Reference< uno::XInterface >( _xComponent, uno::UNO_QUERY ) );
 
-    if ( rModelName.getLength() )
+    if ( !rModelName.isEmpty() )
         impl_initializeModel_nothrow();
 
-    if ( rModelName.getLength() )
-        impl_initializeModel_nothrow();
 }
 //----------------------------------------------------------------------------
 OUnoObject::~OUnoObject()
@@ -1204,7 +1202,7 @@ void OOle2Obj::impl_createDataProvider_nothrow(const uno::Reference< frame::XMod
             xReceiver->attachDataProvider( xDataProvider.get() );
         }
     }
-    catch(uno::Exception)
+    catch(const uno::Exception &)
     {
     }
 }
