@@ -223,24 +223,6 @@ namespace /* private */
 // volume handling functions
 //#####################################################
 
-//#####################################################
-oslFileError SAL_CALL osl_unmountVolumeDevice( oslVolumeDeviceHandle Handle )
-{
-    if ( Handle )
-        return osl_File_E_None;
-    else
-        return osl_File_E_INVAL;
-}
-
-//#####################################################
-oslFileError SAL_CALL osl_automountVolumeDevice( oslVolumeDeviceHandle Handle )
-{
-    if ( Handle )
-        return osl_File_E_None;
-    else
-        return osl_File_E_INVAL;
-}
-
 //#####################################################
 oslFileError SAL_CALL osl_acquireVolumeDeviceHandle( oslVolumeDeviceHandle Handle )
 {
@@ -405,7 +387,7 @@ static HANDLE WINAPI OpenDirectory( rtl_uString* pPath)
         sal_uInt32 nLen = rtl_uString_getLength( pPath );
         if ( nLen )
         {
-            TCHAR* pSuffix = 0;
+            const TCHAR* pSuffix = 0;
             sal_uInt32 nSuffLen = 0;
 
             if ( pPath->buffer[nLen - 1] != L'\\' )
@@ -1219,6 +1201,26 @@ oslFileError SAL_CALL osl_releaseDirectoryItem( oslDirectoryItem Item )
     return osl_File_E_None;
 }
 
+
+sal_Bool
+SAL_CALL osl_identicalDirectoryItem( oslDirectoryItem a, oslDirectoryItem b)
+{
+    DirectoryItem_Impl *pA = (DirectoryItem_Impl *) a;
+    DirectoryItem_Impl *pB = (DirectoryItem_Impl *) b;
+    if (a == b)
+        return sal_True;
+    /* same name => same item, unless renaming / moving madness has occurred */
+    if (rtl_ustr_compare_WithLength(
+                pA->m_pFullPath->buffer, pA->m_pFullPath->length,
+                pB->m_pFullPath->buffer, pB->m_pFullPath->length ) == 0)
+        return sal_True;
+
+    // FIXME: as/when/if this is used in anger on Windows we could
+    // do better here.
+
+    return sal_False;
+}
+
 //#####################################################
 // volume / file info handling functions
 //#####################################################
@@ -1745,7 +1747,6 @@ oslFileError SAL_CALL osl_getFileStatus(
     {
         if ( !pItemImpl->bFullPathNormalized )
         {
-            sal_uInt32 nLen = rtl_uString_getLength( pItemImpl->m_pFullPath );
             ::osl::LongPathBuffer< sal_Unicode > aBuffer( MAX_LONG_PATH );
             sal_uInt32 nNewLen = GetCaseCorrectPathName( reinterpret_cast<LPCTSTR>( rtl_uString_getStr( pItemImpl->m_pFullPath ) ),
                                                       ::osl::mingw_reinterpret_cast<LPTSTR>( aBuffer ),
