@@ -71,21 +71,15 @@ const sal_uInt16 MAXRECURSION = 400;
 // STATIC DATA -----------------------------------------------------------
 
 #ifdef USE_MEMPOOL
-// MemPools auf 4k Boundaries  - 64 Bytes ausrichten
-const sal_uInt16 nMemPoolValueCell = (0x8000 - 64) / sizeof(ScValueCell);
-const sal_uInt16 nMemPoolFormulaCell = (0x8000 - 64) / sizeof(ScFormulaCell);
-const sal_uInt16 nMemPoolStringCell = (0x4000 - 64) / sizeof(ScStringCell);
-const sal_uInt16 nMemPoolNoteCell = (0x1000 - 64) / sizeof(ScNoteCell);
-IMPL_FIXEDMEMPOOL_NEWDEL( ScValueCell,   nMemPoolValueCell, nMemPoolValueCell )
-IMPL_FIXEDMEMPOOL_NEWDEL( ScFormulaCell, nMemPoolFormulaCell, nMemPoolFormulaCell )
-IMPL_FIXEDMEMPOOL_NEWDEL( ScStringCell,  nMemPoolStringCell, nMemPoolStringCell )
-IMPL_FIXEDMEMPOOL_NEWDEL( ScNoteCell,    nMemPoolNoteCell, nMemPoolNoteCell )
+IMPL_FIXEDMEMPOOL_NEWDEL( ScValueCell )
+IMPL_FIXEDMEMPOOL_NEWDEL( ScFormulaCell )
+IMPL_FIXEDMEMPOOL_NEWDEL( ScStringCell )
+IMPL_FIXEDMEMPOOL_NEWDEL( ScNoteCell )
 #endif
 
 // ============================================================================
 
 ScBaseCell::ScBaseCell( CellType eNewType ) :
-    mpNote( 0 ),
     mpBroadcaster( 0 ),
     nTextWidth( TEXTWIDTH_DIRTY ),
     eCellType( sal::static_int_cast<sal_uInt8>(eNewType) ),
@@ -94,7 +88,6 @@ ScBaseCell::ScBaseCell( CellType eNewType ) :
 }
 
 ScBaseCell::ScBaseCell( const ScBaseCell& rCell ) :
-    mpNote( 0 ),
     mpBroadcaster( 0 ),
     nTextWidth( rCell.nTextWidth ),
     eCellType( rCell.eCellType ),
@@ -104,7 +97,6 @@ ScBaseCell::ScBaseCell( const ScBaseCell& rCell ) :
 
 ScBaseCell::~ScBaseCell()
 {
-    delete mpNote;
     delete mpBroadcaster;
     OSL_ENSURE( eCellType == CELLTYPE_DESTROYED, "BaseCell Destructor" );
 }
@@ -120,7 +112,7 @@ ScBaseCell* lclCloneCell( const ScBaseCell& rSrcCell, ScDocument& rDestDoc, cons
         case CELLTYPE_STRING:
             return new ScStringCell( static_cast< const ScStringCell& >( rSrcCell ) );
         case CELLTYPE_EDIT:
-            return new ScEditCell( static_cast< const ScEditCell& >( rSrcCell ), rDestDoc );
+            return new ScEditCell(static_cast<const ScEditCell&>(rSrcCell), rDestDoc, rDestPos);
         case CELLTYPE_FORMULA:
             return new ScFormulaCell( static_cast< const ScFormulaCell& >( rSrcCell ), rDestDoc, rDestPos, nCloneFlags );
         case CELLTYPE_NOTE:
@@ -179,6 +171,13 @@ void adjustRangeName(ScToken* pToken, ScDocument& rNewDoc, const ScDocument* pOl
     {
         bNewGlobal = bOldGlobal;
         pRangeData = new ScRangeData(*pOldRangeData, &rNewDoc);
+        ScTokenArray* pRangeNameToken = pRangeData->GetCode();
+        if (rNewDoc.GetPool() != const_cast<ScDocument*>(pOldDoc)->GetPool())
+        {
+            pRangeNameToken->ReadjustAbsolute3DReferences(pOldDoc, &rNewDoc, pRangeData->GetPos(), true);
+            pRangeNameToken->AdjustAbsoluteRefs(pOldDoc, aOldPos, aNewPos, false, true);
+        }
+
         bool bInserted;
         if (bNewGlobal)
             bInserted = rNewDoc.GetRangeName()->insert(pRangeData);
@@ -219,7 +218,7 @@ void adjustDBRange(ScToken* pToken, ScDocument& rNewDoc, const ScDocument* pOldD
     ScDBData* pNewDBData = aNewNamedDBs.findByName(aDBName);
     if (!pNewDBData)
     {
-        pNewDBData = new ScDBData(*pNewDBData);
+        pNewDBData = new ScDBData(*pDBData);
         aNewNamedDBs.insert(pNewDBData);
     }
     pToken->SetIndex(pNewDBData->GetIndex());
@@ -227,7 +226,7 @@ void adjustDBRange(ScToken* pToken, ScDocument& rNewDoc, const ScDocument* pOldD
 
 } // namespace
 
-ScBaseCell* ScBaseCell::CloneWithoutNote( ScDocument& rDestDoc, int nCloneFlags ) const
+ScBaseCell* ScBaseCell::Clone( ScDocument& rDestDoc, int nCloneFlags ) const
 {
     // notes will not be cloned -> cell address only needed for formula cells
     ScAddress aDestPos;
@@ -236,27 +235,13 @@ ScBaseCell* ScBaseCell::CloneWithoutNote( ScDocument& rDestDoc, int nCloneFlags
     return lclCloneCell( *this, rDestDoc, aDestPos, nCloneFlags );
 }
 
-ScBaseCell* ScBaseCell::CloneWithoutNote( ScDocument& rDestDoc, const ScAddress& rDestPos, int nCloneFlags ) const
+ScBaseCell* ScBaseCell::Clone( ScDocument& rDestDoc, const ScAddress& rDestPos, int nCloneFlags ) const
 {
     return lclCloneCell( *this, rDestDoc, rDestPos, nCloneFlags );
 }
 
-ScBaseCell* ScBaseCell::CloneWithNote( const ScAddress& rOwnPos, ScDocument& rDestDoc, const ScAddress& rDestPos, int nCloneFlags ) const
-{
-    ScBaseCell* pNewCell = lclCloneCell( *this, rDestDoc, rDestPos, nCloneFlags );
-    if( mpNote )
-    {
-        if( !pNewCell )
-            pNewCell = new ScNoteCell;
-        bool bCloneCaption = (nCloneFlags & SC_CLONECELL_NOCAPTION) == 0;
-        pNewCell->TakeNote( mpNote->Clone( rOwnPos, rDestDoc, rDestPos, bCloneCaption ) );
-    }
-    return pNewCell;
-}
-
 void ScBaseCell::Delete()
 {
-    DeleteNote();
     switch (eCellType)
     {
         case CELLTYPE_VALUE:
@@ -280,27 +265,9 @@ void ScBaseCell::Delete()
     }
 }
 
-bool ScBaseCell::IsBlank( bool bIgnoreNotes ) const
+bool ScBaseCell::IsBlank() const
 {
-    return (eCellType == CELLTYPE_NOTE) && (bIgnoreNotes || !mpNote);
-}
-
-void ScBaseCell::TakeNote( ScPostIt* pNote )
-{
-    delete mpNote;
-    mpNote = pNote;
-}
-
-ScPostIt* ScBaseCell::ReleaseNote()
-{
-    ScPostIt* pNote = mpNote;
-    mpNote = 0;
-    return pNote;
-}
-
-void ScBaseCell::DeleteNote()
-{
-    DELETEZ( mpNote );
+    return false;
 }
 
 void ScBaseCell::TakeBroadcaster( SvtBroadcaster* pBroadcaster )
@@ -321,9 +288,9 @@ void ScBaseCell::DeleteBroadcaster()
     DELETEZ( mpBroadcaster );
 }
 
-ScBaseCell* ScBaseCell::CreateTextCell( const String& rString, ScDocument* pDoc )
+ScBaseCell* ScBaseCell::CreateTextCell( const rtl::OUString& rString, ScDocument* pDoc )
 {
-    if ( rString.Search('\n') != STRING_NOTFOUND || rString.Search(CHAR_CR) != STRING_NOTFOUND )
+    if ( rString.indexOf('\n') != -1 || rString.indexOf(CHAR_CR) != -1 )
         return new ScEditCell( rString, pDoc );
     else
         return new ScStringCell( rString );
@@ -556,19 +523,19 @@ bool ScBaseCell::HasStringData() const
     }
 }
 
-String ScBaseCell::GetStringData() const
+rtl::OUString ScBaseCell::GetStringData() const
 {
-    String aStr;
+    rtl::OUString aStr;
     switch ( eCellType )
     {
         case CELLTYPE_STRING:
-            ((const ScStringCell*)this)->GetString( aStr );
+            aStr = ((const ScStringCell*)this)->GetString();
             break;
         case CELLTYPE_EDIT:
-            ((const ScEditCell*)this)->GetString( aStr );
+            aStr = ((const ScEditCell*)this)->GetString();
             break;
         case CELLTYPE_FORMULA:
-            ((ScFormulaCell*)this)->GetString( aStr );      // an der Formelzelle nicht-const
+            aStr = ((ScFormulaCell*)this)->GetString();      // an der Formelzelle nicht-const
             break;
     }
     return aStr;
@@ -606,16 +573,16 @@ bool ScBaseCell::CellEqual( const ScBaseCell* pCell1, const ScBaseCell* pCell2 )
                      ((const ScValueCell*)pCell2)->GetValue() );
         case CELLTYPE_STRING:       // String oder Edit
             {
-                String aText1;
+                rtl::OUString aText1;
                 if ( pCell1->GetCellType() == CELLTYPE_STRING )
-                    ((const ScStringCell*)pCell1)->GetString(aText1);
+                    aText1 = ((const ScStringCell*)pCell1)->GetString();
                 else
-                    ((const ScEditCell*)pCell1)->GetString(aText1);
-                String aText2;
+                    aText1 = ((const ScEditCell*)pCell1)->GetString();
+                rtl::OUString aText2;
                 if ( pCell2->GetCellType() == CELLTYPE_STRING )
-                    ((const ScStringCell*)pCell2)->GetString(aText2);
+                    aText2 = ((const ScStringCell*)pCell2)->GetString();
                 else
-                    ((const ScEditCell*)pCell2)->GetString(aText2);
+                    aText2 = ((const ScEditCell*)pCell2)->GetString();
                 return ( aText1 == aText2 );
             }
         case CELLTYPE_FORMULA:
@@ -660,13 +627,6 @@ ScNoteCell::ScNoteCell( SvtBroadcaster* pBC ) :
     TakeBroadcaster( pBC );
 }
 
-ScNoteCell::ScNoteCell( ScPostIt* pNote, SvtBroadcaster* pBC ) :
-    ScBaseCell( CELLTYPE_NOTE )
-{
-    TakeNote( pNote );
-    TakeBroadcaster( pBC );
-}
-
 #if OSL_DEBUG_LEVEL > 0
 ScNoteCell::~ScNoteCell()
 {
@@ -697,12 +657,7 @@ ScValueCell::~ScValueCell()
 
 // ============================================================================
 
-ScStringCell::ScStringCell() :
-    ScBaseCell( CELLTYPE_STRING )
-{
-}
-
-ScStringCell::ScStringCell( const String& rString ) :
+ScStringCell::ScStringCell( const rtl::OUString& rString ) :
     ScBaseCell( CELLTYPE_STRING ),
     maString( rString.intern() )
 {
@@ -721,34 +676,8 @@ ScStringCell::~ScStringCell()
 //      ScFormulaCell
 //
 
-ScFormulaCell::ScFormulaCell() :
-    ScBaseCell( CELLTYPE_FORMULA ),
-    eTempGrammar( FormulaGrammar::GRAM_DEFAULT),
-    pCode( NULL ),
-    pDocument( NULL ),
-    pPrevious(0),
-    pNext(0),
-    pPreviousTrack(0),
-    pNextTrack(0),
-    nFormatIndex(0),
-    nFormatType( NUMBERFORMAT_NUMBER ),
-    nSeenInIteration(0),
-    cMatrixFlag ( MM_NONE ),
-    bDirty( false ),
-    bChanged( false ),
-    bRunning( false ),
-    bCompile( false ),
-    bSubTotal( false ),
-    bIsIterCell( false ),
-    bInChangeTrack( false ),
-    bTableOpDirty( false ),
-    bNeedListening( false ),
-    aPos(0,0,0)
-{
-}
-
 ScFormulaCell::ScFormulaCell( ScDocument* pDoc, const ScAddress& rPos,
-                              const String& rFormula,
+                              const rtl::OUString& rFormula,
                               const FormulaGrammar::Grammar eGrammar,
                               sal_uInt8 cMatInd ) :
     ScBaseCell( CELLTYPE_FORMULA ),
@@ -775,6 +704,9 @@ ScFormulaCell::ScFormulaCell( ScDocument* pDoc, const ScAddress& rPos,
     aPos( rPos )
 {
     Compile( rFormula, true, eGrammar );    // bNoListening, Insert does that
+    if (!pCode)
+        // We need to have a non-NULL token array instance at all times.
+        pCode = new ScTokenArray;
 }
 
 // Wird von den Importfiltern verwendet
@@ -851,9 +783,6 @@ ScFormulaCell::ScFormulaCell( const ScFormulaCell& rCell, ScDocument& rDoc, cons
 {
     pCode = rCell.pCode->Clone();
 
-    if ( nCloneFlags & SC_CLONECELL_ADJUST3DREL )
-        pCode->ReadjustRelative3DReferences( rCell.aPos, aPos );
-
     // evtl. Fehler zuruecksetzen und neu kompilieren
     //  nicht im Clipboard - da muss das Fehlerflag erhalten bleiben
     //  Spezialfall Laenge=0: als Fehlerzelle erzeugt, dann auch Fehler behalten
@@ -881,8 +810,19 @@ ScFormulaCell::ScFormulaCell( const ScFormulaCell& rCell, ScDocument& rDoc, cons
                     adjustDBRange(pToken, rDoc, rCell.pDocument);
             }
         }
+
+        bool bCopyBetweenDocs = pDocument->GetPool() != rCell.pDocument->GetPool();
+        if (bCopyBetweenDocs && !(nCloneFlags & SC_CLONECELL_NOMAKEABS_EXTERNAL))
+        {
+            pCode->ReadjustAbsolute3DReferences( rCell.pDocument, &rDoc, rCell.aPos);
+        }
+
+        pCode->AdjustAbsoluteRefs( rCell.pDocument, rCell.aPos, aPos, false, bCopyBetweenDocs );
     }
 
+    if ( nCloneFlags & SC_CLONECELL_ADJUST3DREL )
+        pCode->ReadjustRelative3DReferences( rCell.aPos, aPos );
+
     if( !bCompile )
     {   // Name references with references and ColRowNames
         pCode->Reset();
@@ -1012,13 +952,6 @@ void ScFormulaCell::GetFormula( rtl::OUStringBuffer& rBuffer,
     }
 }
 
-void ScFormulaCell::GetFormula( String& rFormula, const FormulaGrammar::Grammar eGrammar ) const
-{
-    rtl::OUStringBuffer rBuffer( rFormula );
-    GetFormula( rBuffer, eGrammar );
-    rFormula = rBuffer.makeStringAndClear();
-}
-
 void ScFormulaCell::GetFormula( rtl::OUString& rFormula, const FormulaGrammar::Grammar eGrammar ) const
 {
     rtl::OUStringBuffer rBuffer( rFormula );
@@ -1041,10 +974,11 @@ void ScFormulaCell::GetResultDimensions( SCSIZE& rCols, SCSIZE& rRows )
     }
 }
 
-void ScFormulaCell::Compile( const String& rFormula, bool bNoListening,
+void ScFormulaCell::Compile( const rtl::OUString& rFormula, bool bNoListening,
                             const FormulaGrammar::Grammar eGrammar )
 {
-    if ( pDocument->IsClipOrUndo() ) return;
+    if ( pDocument->IsClipOrUndo() )
+        return;
     bool bWasInFormulaTree = pDocument->IsInFormulaTree( this );
     if ( bWasInFormulaTree )
         pDocument->RemoveFromFormulaTree( this );
@@ -1059,12 +993,12 @@ void ScFormulaCell::Compile( const String& rFormula, bool bNoListening,
         delete pCodeOld;
     if( !pCode->GetCodeError() )
     {
-        if ( !pCode->GetLen() && aResult.GetHybridFormula().Len() && rFormula == aResult.GetHybridFormula() )
+        if ( !pCode->GetLen() && aResult.GetHybridFormula().Len() && rFormula == rtl::OUString(aResult.GetHybridFormula()) )
         {   // nicht rekursiv CompileTokenArray/Compile/CompileTokenArray
-            if ( rFormula.GetChar(0) == '=' )
-                pCode->AddBad( rFormula.GetBuffer() + 1 );
+            if ( rFormula[0] == '=' )
+                pCode->AddBad( rFormula.copy(1) );
             else
-                pCode->AddBad( rFormula.GetBuffer() );
+                pCode->AddBad( rFormula );
         }
         bCompile = true;
         CompileTokenArray( bNoListening );
@@ -1131,9 +1065,9 @@ void ScFormulaCell::CompileXML( ScProgress& rProgress )
 
     ScCompiler aComp( pDocument, aPos, *pCode);
     aComp.SetGrammar(eTempGrammar);
-    String aFormula, aFormulaNmsp;
+    rtl::OUString aFormula, aFormulaNmsp;
     aComp.CreateStringFromXMLTokenArray( aFormula, aFormulaNmsp );
-    pDocument->DecXMLImportedFormulaCount( aFormula.Len() );
+    pDocument->DecXMLImportedFormulaCount( aFormula.getLength() );
     rProgress.SetStateCountDownOnPercent( pDocument->GetXMLImportedFormulaCount() );
     // pCode darf fuer Abfragen noch nicht geloescht, muss aber leer sein
     if ( pCode )
@@ -1145,10 +1079,10 @@ void ScFormulaCell::CompileXML( ScProgress& rProgress )
     {
         if ( !pCode->GetLen() )
         {
-            if ( aFormula.GetChar(0) == '=' )
-                pCode->AddBad( aFormula.GetBuffer() + 1 );
+            if ( aFormula[0] == '=' )
+                pCode->AddBad( aFormula.copy( 1 ) );
             else
-                pCode->AddBad( aFormula.GetBuffer() );
+                pCode->AddBad( aFormula );
         }
         bSubTotal = aComp.CompileTokenArray();
         if( !pCode->GetCodeError() )
@@ -1452,9 +1386,9 @@ void ScFormulaCell::Interpret()
                 {
                     rRecursionHelper.SetInRecursionReturn( false);
                     for (ScFormulaRecursionList::const_iterator aIter(
-                                rRecursionHelper.GetStart());
+                                rRecursionHelper.GetIterationStart());
                             !rRecursionHelper.IsInReturn() && aIter !=
-                            rRecursionHelper.GetEnd(); ++aIter)
+                            rRecursionHelper.GetIterationEnd(); ++aIter)
                     {
                         ScFormulaCell* pCell = (*aIter).pCell;
                         if (pCell->IsDirtyOrInTableOpDirty())
@@ -1474,7 +1408,7 @@ void ScFormulaCell::Interpret()
                 else if (bResumeIteration ||
                         rRecursionHelper.IsDoingIteration())
                     rRecursionHelper.GetList().erase(
-                            rRecursionHelper.GetStart(),
+                            rRecursionHelper.GetIterationStart(),
                             rRecursionHelper.GetLastIterationStart());
                 else
                     rRecursionHelper.Clear();
@@ -1510,7 +1444,9 @@ void ScFormulaCell::InterpretTail( ScInterpretTailParameter eTailParam )
         // #i11719# no UPN and no error and no token code but result string present
         // => interpretation of this cell during name-compilation and unknown names
         // => can't exchange underlying code array in CompileTokenArray() /
-        // Compile() because interpreter's token iterator would crash.
+        // Compile() because interpreter's token iterator would crash or pCode
+        // would be deleted twice if this cell was interpreted during
+        // compilation.
         // This should only be a temporary condition and, since we set an
         // error, if ran into it again we'd bump into the dirty-clearing
         // condition further down.
@@ -1519,12 +1455,7 @@ void ScFormulaCell::InterpretTail( ScInterpretTailParameter eTailParam )
             pCode->SetCodeError( errNoCode );
             // This is worth an assertion; if encountered in daily work
             // documents we might need another solution. Or just confirm correctness.
-            OSL_FAIL( "ScFormulaCell::Interpret: no UPN, no error, no token, but string -> Try compiling it." );
-            // Force Compilation
-            String aFormula = aResult.GetHybridFormula();
-            aResult.SetHybridFormula( String() );
-            Compile( aFormula );
-            InterpretTail( eTailParam );
+            OSL_FAIL( "ScFormulaCell::Interpret: no UPN, no error, no token, but hybrid formula string" );
             return;
         }
         CompileTokenArray();
@@ -1970,9 +1901,9 @@ void ScFormulaCell::AddRecalcMode( ScRecalcMode nBits )
 }
 
 // Dynamically create the URLField on a mouse-over action on a hyperlink() cell.
-void ScFormulaCell::GetURLResult( String& rURL, String& rCellText )
+void ScFormulaCell::GetURLResult( rtl::OUString& rURL, rtl::OUString& rCellText )
 {
-    String aCellString;
+    rtl::OUString aCellString;
 
     Color* pColor;
 
@@ -1993,7 +1924,7 @@ void ScFormulaCell::GetURLResult( String& rURL, String& rCellText )
     }
     else
     {
-        GetString( aCellString );
+        aCellString = GetString();
         pFormatter->GetOutputString( aCellString, nCellFormat, rCellText, &pColor );
     }
     ScConstMatrixRef xMat( aResult.GetMatrix());
@@ -2007,7 +1938,7 @@ void ScFormulaCell::GetURLResult( String& rURL, String& rCellText )
             pFormatter->GetOutputString( nMatVal.fVal, nURLFormat, rURL, &pColor );
     }
 
-    if(!rURL.Len())
+    if(rURL.isEmpty())
     {
         if(IsValue())
             pFormatter->GetOutputString( GetValue(), nURLFormat, rURL, &pColor );
@@ -2034,8 +1965,8 @@ void ScFormulaCell::MaybeInterpret()
 
 EditTextObject* ScFormulaCell::CreateURLObject()
 {
-    String aCellText;
-    String aURL;
+    rtl::OUString aCellText;
+    rtl::OUString aURL;
     GetURLResult( aURL, aCellText );
 
     SvxURLField aUrlField( aURL, aCellText, SVXURLFORMAT_APPDEFAULT);
