@@ -29,7 +29,6 @@
 
 // INCLUDE ---------------------------------------------------------------
 
-#define _ZFORLIST_DECLARE_TABLE
 #include "scitems.hxx"
 #include <editeng/eeitem.hxx>
 
@@ -75,6 +74,7 @@
 #include "chartlis.hxx"
 #include "markdata.hxx"
 #include "conditio.hxx"
+#include "colorscale.hxx"
 #include "validat.hxx"
 #include "progress.hxx"
 #include "detdata.hxx"
@@ -131,12 +131,10 @@ ScDocument::ScDocument( ScDocumentMode  eMode,
         mpUndoManager( NULL ),
         pEditEngine( NULL ),
         pNoteEngine( NULL ),
-        pNoteItemPool( NULL ),
         pShell( pDocShell ),
         pPrinter( NULL ),
         pVirtualDevice_100th_mm( NULL ),
         pDrawLayer( NULL ),
-        pCondFormList( NULL ),
         pValidationList( NULL ),
         pFormatExchangeList( NULL ),
         pRangeName(NULL),
@@ -146,7 +144,6 @@ ScDocument::ScDocument( ScDocumentMode  eMode,
         pEOFormulaTree( NULL ),
         pFormulaTrack( NULL ),
         pEOFormulaTrack( NULL ),
-        pOtherObjects( NULL ),
         pClipData( NULL ),
         pDetOpList(NULL),
         pChangeTrack( NULL ),
@@ -221,7 +218,8 @@ ScDocument::ScDocument( ScDocumentMode  eMode,
         mbExecuteLinkEnabled( true ),
         mbChangeReadOnlyEnabled( false ),
         mbStreamValidLocked( false ),
-        mnNamedRangesLockCount( 0 )
+        mnNamedRangesLockCount( 0 ),
+        mbIsInTest( false )
 {
     SetStorageGrammar( formula::FormulaGrammar::GRAM_STORAGE_DEFAULT);
 
@@ -326,7 +324,7 @@ void ScDocument::SetChangeTrack( ScChangeTrack* pTrack )
 }
 
 
-IMPL_LINK( ScDocument, TrackTimeHdl, Timer*, EMPTYARG )
+IMPL_LINK_NOARG(ScDocument, TrackTimeHdl)
 {
     if ( ScDdeLink::IsInUpdate() )      // nicht verschachteln
     {
@@ -411,11 +409,6 @@ ScDocument::~ScDocument()
 
     Clear( true );              // true = from destructor (needed for SdrModel::ClearModel)
 
-    if (pCondFormList)
-    {
-        pCondFormList->DeleteAndDestroy( 0, pCondFormList->Count() );
-        DELETEZ(pCondFormList);
-    }
     if (pValidationList)
     {
         pValidationList->DeleteAndDestroy( 0, pValidationList->Count() );
@@ -437,7 +430,6 @@ ScDocument::~ScDocument()
     delete pChangeTrack;
     delete pEditEngine;
     delete pNoteEngine;
-    SfxItemPool::Free(pNoteItemPool);
     delete pChangeViewSettings;         // und weg damit
     delete pVirtualDevice_100th_mm;
 
@@ -451,7 +443,6 @@ ScDocument::~ScDocument()
     xPoolHelper.clear();
 
     delete pScriptTypeData;
-    delete pOtherObjects;
     delete pRecursionHelper;
 
     OSL_POSTCOND( !pAutoNameCache, "AutoNameCache still set in dtor" );
@@ -461,11 +452,6 @@ void ScDocument::InitClipPtrs( ScDocument* pSourceDoc )
 {
     OSL_ENSURE(bIsClip, "InitClipPtrs und nicht bIsClip");
 
-    if (pCondFormList)
-    {
-        pCondFormList->DeleteAndDestroy( 0, pCondFormList->Count() );
-        DELETEZ(pCondFormList);
-    }
     if (pValidationList)
     {
         pValidationList->DeleteAndDestroy( 0, pValidationList->Count() );
@@ -478,9 +464,6 @@ void ScDocument::InitClipPtrs( ScDocument* pSourceDoc )
 
     //  bedingte Formate / Gueltigkeiten
     //! Vorlagen kopieren?
-    const ScConditionalFormatList* pSourceCond = pSourceDoc->pCondFormList;
-    if ( pSourceCond )
-        pCondFormList = new ScConditionalFormatList(this, *pSourceCond);
     const ScValidationDataList* pSourceValid = pSourceDoc->pValidationList;
     if ( pSourceValid )
         pValidationList = new ScValidationDataList(this, *pSourceValid);
@@ -520,7 +503,7 @@ ScFieldEditEngine& ScDocument::GetEditEngine()
 {
     if ( !pEditEngine )
     {
-        pEditEngine = new ScFieldEditEngine( GetEnginePool(), GetEditPool() );
+        pEditEngine = new ScFieldEditEngine(this, GetEnginePool(), GetEditPool());
         pEditEngine->SetUpdateMode( false );
         pEditEngine->EnableUndo( false );
         pEditEngine->SetRefMapMode( MAP_100TH_MM );
@@ -757,8 +740,6 @@ bool ScDocument::MoveTab( SCTAB nOldPos, SCTAB nNewPos, ScProgress* pProgress )
                 UpdateChartRef( URM_REORDER,
                                     0,0,nOldPos, MAXCOL,MAXROW,nOldPos, 0,0,nDz );
                 UpdateRefAreaLinks( URM_REORDER, aSourceRange, 0,0,nDz );
-                if ( pCondFormList )
-                    pCondFormList->UpdateMoveTab( nOldPos, nNewPos );
                 if ( pValidationList )
                     pValidationList->UpdateMoveTab( nOldPos, nNewPos );
                 if ( pUnoBroadcaster )
@@ -823,7 +804,8 @@ bool ScDocument::CopyTab( SCTAB nOldPos, SCTAB nNewPos, const ScMarkData* pOnlyM
     {
         if (nNewPos >= static_cast<SCTAB>(maTabs.size()))
         {
-            maTabs.push_back( new ScTable(this, static_cast<SCTAB>(maTabs.size()), aName) );
+            nNewPos = static_cast<SCTAB>(maTabs.size());
+            maTabs.push_back(new ScTable(this, nNewPos, aName));
         }
         else
         {
@@ -866,9 +848,6 @@ bool ScDocument::CopyTab( SCTAB nOldPos, SCTAB nNewPos, const ScMarkData* pOnlyM
                     if (*it && it != maTabs.begin()+nOldPos && it != maTabs.begin()+nNewPos)
                         (*it)->StartAllListeners();
 
-                //  update conditional formats after table is inserted
-                if ( pCondFormList )
-                    pCondFormList->UpdateReference( URM_INSDEL, aRange, 0,0,1 );
                 if ( pValidationList )
                     pValidationList->UpdateReference( URM_INSDEL, aRange, 0,0,1 );
                 // sheet names of references may not be valid until sheet is copied
@@ -904,11 +883,18 @@ bool ScDocument::CopyTab( SCTAB nOldPos, SCTAB nNewPos, const ScMarkData* pOnlyM
         if (pDrawLayer)
             DrawCopyPage( static_cast<sal_uInt16>(nOldPos), static_cast<sal_uInt16>(nNewPos) );
 
+        if (pDPCollection)
+            pDPCollection->CopyToTab(nOldPos, nNewPos);
+
         maTabs[nNewPos]->SetPageStyle( maTabs[nOldPos]->GetPageStyle() );
         maTabs[nNewPos]->SetPendingRowHeights( maTabs[nOldPos]->IsPendingRowHeights() );
 
         // Copy the custom print range if exists.
         maTabs[nNewPos]->CopyPrintRange(*maTabs[nOldPos]);
+
+        // Copy the RTL settings
+        maTabs[nNewPos]->SetLayoutRTL(maTabs[nOldPos]->IsLayoutRTL());
+        maTabs[nNewPos]->SetLoadingRTL(maTabs[nOldPos]->IsLoadingRTL());
     }
     else
         SetAutoCalc( bOldAutoCalc );
@@ -944,6 +930,10 @@ sal_uLong ScDocument::TransferTab( ScDocument* pSrcDoc, SCTAB nSrcPos,
         pSrcDoc->GetName(nSrcPos, aName);
         CreateValidTabName(aName);
         bValid = InsertTab(nDestPos, aName);
+
+        // Copy the RTL settings
+        maTabs[nDestPos]->SetLayoutRTL(pSrcDoc->maTabs[nSrcPos]->IsLayoutRTL());
+        maTabs[nDestPos]->SetLoadingRTL(pSrcDoc->maTabs[nSrcPos]->IsLoadingRTL());
     }
     else                        // bestehende Tabelle ersetzen
     {
@@ -982,80 +972,6 @@ sal_uLong ScDocument::TransferTab( ScDocument* pSrcDoc, SCTAB nSrcPos,
 
         if ( !bResultsOnly )
         {
-            bool bNamesLost = false;
-            // array containing range names which might need update of indices.
-            // The instances inserted into this vector are managed by the
-            // range name container of this document, so no need to delete
-            // them afterward.
-            ::std::vector<ScRangeData*> aSrcRangeNames;
-
-            // the index mapping thereof
-            ScRangeData::IndexMap aSrcRangeMap;
-            bool bRangeNameReplace = false;
-
-            // find named ranges that are used in the source sheet
-            std::set<sal_uInt16> aUsedNames;
-            pSrcDoc->maTabs[nSrcPos]->FindRangeNamesInUse( 0, 0, MAXCOL, MAXROW, aUsedNames );
-
-            if (pSrcDoc->pRangeName)
-            {
-                ScRangeName::const_iterator itr = pSrcDoc->pRangeName->begin(), itrEnd = pSrcDoc->pRangeName->end();
-                for (; itr != itrEnd; ++itr)        //! DB-Bereiche Pivot-Bereiche auch !!!
-                {
-                    sal_uInt16 nOldIndex = itr->second->GetIndex();
-                    bool bInUse = ( aUsedNames.find(nOldIndex) != aUsedNames.end() );
-                    if (bInUse)
-                    {
-                        const ScRangeData* pExistingData = GetRangeName()->findByUpperName(itr->second->GetUpperName());
-                        if (pExistingData)
-                        {
-                            // the name exists already in the destination document
-                            // -> use the existing name, but show a warning
-                            // (when refreshing links, the existing name is used and the warning not shown)
-
-                            sal_uInt16 nExistingIndex = pExistingData->GetIndex();
-
-                            // don't modify the named range
-                            aSrcRangeMap.insert(
-                                ScRangeData::IndexMap::value_type(nOldIndex, nExistingIndex));
-                            bRangeNameReplace = true;
-                            bNamesLost = true;
-                        }
-                        else
-                        {
-                            ScRangeData* pData = new ScRangeData( *itr->second );
-                            pData->SetDocument(this);
-                            if ( pRangeName->findByIndex( pData->GetIndex() ) )
-                                pData->SetIndex(0);     // need new index, done in Insert
-                            if (!pRangeName->insert(pData))
-                            {
-                                OSL_FAIL("can't insert name");     // shouldn't happen
-                                pData = NULL;
-                            }
-                            else
-                            {
-                                pData->TransferTabRef( nSrcPos, nDestPos );
-                                aSrcRangeNames.push_back(pData);
-                                sal_uInt16 nNewIndex = pData->GetIndex();
-                                aSrcRangeMap.insert(
-                                    ScRangeData::IndexMap::value_type(nOldIndex, nNewIndex));
-                                if ( !bRangeNameReplace )
-                                    bRangeNameReplace = ( nOldIndex != nNewIndex );
-                            }
-                        }
-                    }
-                }
-            }
-            if ( bRangeNameReplace )
-            {
-                // first update all inserted named formulas if they contain other
-                // range names and used indices changed
-                for (size_t i = 0, n = aSrcRangeNames.size(); i < n; ++i)       //! DB-Bereiche Pivot-Bereiche auch
-                    aSrcRangeNames[i]->ReplaceRangeNamesInUse( aSrcRangeMap );
-
-                // then update the formulas, they might need the just updated range names
-                maTabs[nDestPos]->ReplaceRangeNamesInUse( 0, 0, MAXCOL, MAXROW, aSrcRangeMap );
-            }
 
             SCsTAB nDz = ((SCsTAB)nDestPos) - (SCsTAB)nSrcPos;
             maTabs[nDestPos]->UpdateReference(URM_COPY, 0, 0, nDestPos,
@@ -1063,11 +979,6 @@ sal_uLong ScDocument::TransferTab( ScDocument* pSrcDoc, SCTAB nSrcPos,
                                                      0, 0, nDz, NULL);
             // Readjust self-contained absolute references to this sheet
             maTabs[nDestPos]->TestTabRefAbs(nSrcPos);
-            if (bNamesLost)
-            {
-                nRetVal += 2;
-                // message: duplicate names
-            }
             maTabs[nDestPos]->CompileAll();
         }
 
@@ -1164,8 +1075,8 @@ ScFieldEditEngine* ScDocument::CreateFieldEditEngine()
     ScFieldEditEngine* pNewEditEngine = NULL;
     if (!pCacheFieldEditEngine)
     {
-        pNewEditEngine = new ScFieldEditEngine( GetEnginePool(),
-            GetEditPool(), false );
+        pNewEditEngine = new ScFieldEditEngine(
+            this, GetEnginePool(), GetEditPool(), false);
     }
     else
     {
