@@ -36,6 +36,7 @@
 #include <editeng/bolnitem.hxx>
 #include <editeng/editdata.hxx>     // can be removed if table has a bLayoutRTL flag
 #include <editeng/shaditem.hxx>
+#include <editeng/brshitem.hxx>
 
 #include "fillinfo.hxx"
 #include "document.hxx"
@@ -49,6 +50,7 @@
 #include "poolhelp.hxx"
 #include "docpool.hxx"
 #include "conditio.hxx"
+#include "colorscale.hxx"
 #include "stlpool.hxx"
 
 // -----------------------------------------------------------------------
@@ -390,8 +392,8 @@ void ScDocument::FillInfo( ScTableInfo& rTabInfo, SCCOL nX1, SCROW nY1, SCCOL nX
                 bool bHiddenRow = true;
                 SCROW nHiddenEndRow = -1;
                 (void) pThisCol->Search( nY1, nUIndex );
-                while ( nUIndex < pThisCol->nCount &&
-                        (nThisRow=pThisCol->pItems[nUIndex].nRow) <= nY2 )
+                while ( nUIndex < pThisCol->maItems.size() &&
+                        (nThisRow=pThisCol->maItems[nUIndex].nRow) <= nY2 )
                 {
                     if (nThisRow > nHiddenEndRow)
                         bHiddenRow = RowHidden( nThisRow, nTab, NULL, &nHiddenEndRow);
@@ -403,7 +405,7 @@ void ScDocument::FillInfo( ScTableInfo& rTabInfo, SCCOL nX1, SCROW nY1, SCCOL nX
 
                         RowInfo* pThisRowInfo = &pRowInfo[nArrY];
                         CellInfo* pInfo = &pThisRowInfo->pCellInfo[nArrX];
-                        pInfo->pCell = pThisCol->pItems[nUIndex].pCell;
+                        pInfo->pCell = pThisCol->maItems[nUIndex].pCell;
                         if (pInfo->pCell->GetCellType() != CELLTYPE_NOTE)
                         {
                             pThisRowInfo->bEmptyText = false;                   // Zeile nicht leer
@@ -478,6 +480,8 @@ void ScDocument::FillInfo( ScTableInfo& rTabInfo, SCCOL nX1, SCROW nY1, SCCOL nX
 
                         sal_uLong nConditional = ((const SfxUInt32Item&)pPattern->
                                                 GetItem(ATTR_CONDITIONAL)).GetValue();
+
+                        ScConditionalFormatList* pCondFormList = GetCondFormList(nTab);
                         const ScConditionalFormat* pCondForm = NULL;
                         if ( nConditional && pCondFormList )
                             pCondForm = pCondFormList->GetFormat( nConditional );
@@ -513,13 +517,16 @@ void ScDocument::FillInfo( ScTableInfo& rTabInfo, SCCOL nX1, SCROW nY1, SCCOL nX
                                 //  nWidth wird nicht mehr einzeln gesetzt
 
                                 bool bEmbed = false; //bIsEmbedded &&
+#if 0 // Huh? Is this intentional or accidental? Clang warns
+      // "expression result unused", so ifdef out these lines. The
+      // code has been like this since 2004.
                                         nTab    >= aEmbedRange.aStart.Tab() &&
                                         nTab    <= aEmbedRange.aEnd.Tab()   &&
                                         nX      >= aEmbedRange.aStart.Col() &&
                                         nX      <= aEmbedRange.aEnd.Col()   &&
                                         nCurRow >= aEmbedRange.aStart.Row() &&
                                         nCurRow <= aEmbedRange.aEnd.Row();
-
+#endif
                                 if (bScenario)
                                 {
                                     pInfo->pBackground = ScGlobal::GetButtonBrushItem();
@@ -538,12 +545,12 @@ void ScDocument::FillInfo( ScTableInfo& rTabInfo, SCCOL nX1, SCROW nY1, SCCOL nX
 
                                 if ( pCondForm )
                                 {
-                                    String aStyle = pCondForm->GetCellStyle( pInfo->pCell,
+                                    ScCondFormatData aData = pCondForm->GetData( pInfo->pCell,
                                                         ScAddress( nX, nCurRow, nTab ) );
-                                    if (aStyle.Len())
+                                    if (!aData.aStyleName.isEmpty())
                                     {
                                         SfxStyleSheetBase* pStyleSheet =
-                                                pStlPool->Find( aStyle, SFX_STYLE_FAMILY_PARA );
+                                                pStlPool->Find( aData.aStyleName, SFX_STYLE_FAMILY_PARA );
                                         if ( pStyleSheet )
                                         {
                                             //! Style-Sets cachen !!!
@@ -552,6 +559,15 @@ void ScDocument::FillInfo( ScTableInfo& rTabInfo, SCCOL nX1, SCROW nY1, SCCOL nX
                                         }
                                         // if style is not there, treat like no condition
                                     }
+                                    if(aData.pColorScale)
+                                    {
+                                        pInfo->pColorScale = aData.pColorScale;
+                                    }
+
+                                    if(aData.pDataBar)
+                                    {
+                                        pInfo->pDataBar = aData.pDataBar;
+                                    }
                                 }
 
                                 ++nArrY;
@@ -670,6 +686,11 @@ void ScDocument::FillInfo( ScTableInfo& rTabInfo, SCCOL nX1, SCROW nY1, SCCOL nX
                         bAnyShadow = true;
                     }
                 }
+                if(pInfo->pColorScale)
+                {
+                    pRowInfo[nArrY].bEmptyBack = false;
+                    pInfo->pBackground = new SvxBrushItem(*pInfo->pColorScale, ATTR_BACKGROUND);
+                }
             }
         }
     }
