@@ -47,7 +47,7 @@ extern WKTYP                eTyp;
 
 static const sal_Char*      GetAddInName( const sal_uInt8 nIndex );
 
-static DefTokenId           lcl_KnownAddIn( const ByteString& sTest );
+static DefTokenId           lcl_KnownAddIn(const rtl::OString& rTest);
 
 //extern double decipher_Number123( sal_uInt32 nValue );
 
@@ -65,23 +65,23 @@ void LotusToSc::DoFunc( DefTokenId eOc, sal_uInt8 nAnz, const sal_Char* pExtStri
 
     if( eOc == ocNoName )
     {
-        ByteString              t;
+        rtl::OString t;
         if( pExtString )
         {
-            const ByteString    s( "@<<@123>>" );
+            const rtl::OString s(RTL_CONSTASCII_STRINGPARAM("@<<@123>>"));
 
             t = pExtString;
 
-            xub_StrLen          n = t.Search( s );
-            if( n != STRING_NOTFOUND )
-                t.Erase( 0, n + s.Len() );
+            sal_Int32 n = t.indexOf(s);
+            if( n != -1 )
+                t = t.copy(n + s.getLength());
 
             t = comphelper::string::stripEnd(t, '(');
 
             eOc = lcl_KnownAddIn( t );
 
             if( eOc == ocNoName )
-                t.Insert( "L123_", 0 );
+                t = rtl::OString(RTL_CONSTASCII_STRINGPARAM("L123_")) + t;
         }
         else
             t = "#UNKNOWN FUNC NAME#";
@@ -125,8 +125,7 @@ void LotusToSc::DoFunc( DefTokenId eOc, sal_uInt8 nAnz, const sal_Char* pExtStri
             break;
         case ocChose:
         {// 1. Parameter ++
-            if (nAnz >= 1)
-                IncToken( eParam[ nAnz - 1 ] );
+            IncToken( eParam[ nAnz - 1 ] );
         }
             break;
         case ocFind:
@@ -139,8 +138,7 @@ void LotusToSc::DoFunc( DefTokenId eOc, sal_uInt8 nAnz, const sal_Char* pExtStri
         case ocMid:
         case ocReplace:
         {// 2. Parameter ++
-            if (nAnz >= 2)
-                IncToken( eParam[ nAnz - 2 ] );
+            IncToken( eParam[ nAnz - 2 ] );
         }
             break;
         case ocZins:
@@ -544,8 +542,7 @@ ConvErr LotusToSc::Convert( const ScTokenArray*& rpErg, sal_Int32& rRest,
                 break;
             case FT_ConstString:
             {
-                String  aTmp( ScfTools::ReadCString( aIn, nBytesLeft, eSrcChar ) );
-
+                String  aTmp(ScfTools::read_zeroTerminated_uInt8s_ToOUString(aIn, nBytesLeft, eSrcChar));
                 aStack << aPool.Store( aTmp );
             }
                 break;
@@ -564,7 +561,7 @@ ConvErr LotusToSc::Convert( const ScTokenArray*& rpErg, sal_Int32& rRest,
                 break;
             case FT_Nrref:
             {
-                String      aTmp( ScfTools::ReadCString( aIn, nBytesLeft, eSrcChar ) );
+                String  aTmp(ScfTools::read_zeroTerminated_uInt8s_ToOUString(aIn, nBytesLeft, eSrcChar));
                 if( rRangeNameBufferWK3.FindRel( aTmp, nRngIndex ) )
                     aStack << aPool.Store( nRngIndex );
                 else
@@ -577,7 +574,7 @@ ConvErr LotusToSc::Convert( const ScTokenArray*& rpErg, sal_Int32& rRest,
                 break;
             case FT_Absnref:
             {
-                String      aTmp( ScfTools::ReadCString( aIn, nBytesLeft, eSrcChar ) );
+                String aTmp(ScfTools::read_zeroTerminated_uInt8s_ToOUString(aIn, nBytesLeft, eSrcChar));
                 if( rRangeNameBufferWK3.FindAbs( aTmp, nRngIndex ) )
                     aStack << aPool.Store( nRngIndex );
                 else
@@ -610,18 +607,14 @@ ConvErr LotusToSc::Convert( const ScTokenArray*& rpErg, sal_Int32& rRest,
 
                 if( nStrLen )
                 {
-					sal_Char*	p = new (::std::nothrow) sal_Char[ nStrLen + 1 ];
-                    if (p)
-                    {
-                        aIn.Read( p, nStrLen );
-                        p[ nStrLen ] = 0x00;
+//                  String  t( ReadString( aIn, nStrLen, eSrcChar ) );
+                    sal_Char*   p = new sal_Char[ nStrLen + 1 ];
+                    aIn.Read( p, nStrLen );
+                    p[ nStrLen ] = 0x00;
 
-                        DoFunc( ocNoName, nAnz, p );
+                    DoFunc( ocNoName, nAnz, p );
 
-                        delete[] p;
-                    }
-                    else
-                        DoFunc( ocNoName, nAnz, NULL );
+                    delete[] p;
                 }
                 else
                     DoFunc( ocNoName, nAnz, NULL );
@@ -2001,79 +1994,77 @@ const sal_Char* GetAddInName( const sal_uInt8 n )
 }
 
 
-static DefTokenId lcl_KnownAddIn( const ByteString& sTest )
+DefTokenId lcl_KnownAddIn( const rtl::OString& rTest )
 {
     DefTokenId  eId = ocNoName;
 
-    if( sTest == "FACT" )
+    if (rTest.equalsL(RTL_CONSTASCII_STRINGPARAM("FACT")))
             eId = ocFact;
-    else if(sTest== "ISEMPTY")
+    else if (rTest.equalsL(RTL_CONSTASCII_STRINGPARAM("ISEMPTY")))
             eId=ocIsEmpty;
-    else if(sTest== "DEGTORAD")
+    else if (rTest.equalsL(RTL_CONSTASCII_STRINGPARAM("DEGTORAD")))
             eId=ocRad;
-    else if(sTest== "RADTODEG")
+    else if (rTest.equalsL(RTL_CONSTASCII_STRINGPARAM("RADTODEG")))
             eId=ocDeg;
-    else if(sTest== "SIGN")
+    else if (rTest.equalsL(RTL_CONSTASCII_STRINGPARAM("SIGN")))
             eId=ocPlusMinus;
-    else if(sTest== "ACOSH")
+    else if (rTest.equalsL(RTL_CONSTASCII_STRINGPARAM("ACOSH")))
             eId=ocArcCosHyp;
-    else if(sTest== "ACOTH")
+    else if (rTest.equalsL(RTL_CONSTASCII_STRINGPARAM("ACOTH")))
             eId=ocArcCotHyp;
-    else if(sTest== "ASINH")
+    else if (rTest.equalsL(RTL_CONSTASCII_STRINGPARAM("ASINH")))
             eId=ocArcSinHyp;
-    else if(sTest== "ATANH")
+    else if (rTest.equalsL(RTL_CONSTASCII_STRINGPARAM("ATANH")))
             eId=ocArcTanHyp;
-    else if(sTest== "COSH")
+    else if (rTest.equalsL(RTL_CONSTASCII_STRINGPARAM("COSH")))
             eId=ocCosHyp;
-    else if(sTest== "COTH")
+    else if (rTest.equalsL(RTL_CONSTASCII_STRINGPARAM("COTH")))
             eId=ocCotHyp;
-    else if(sTest== "SINH")
+    else if (rTest.equalsL(RTL_CONSTASCII_STRINGPARAM("SINH")))
             eId=ocSinHyp;
-    else if(sTest== "TANH")
+    else if (rTest.equalsL(RTL_CONSTASCII_STRINGPARAM("TANH")))
             eId=ocTanHyp;
-    else if(sTest== "EVEN")
+    else if (rTest.equalsL(RTL_CONSTASCII_STRINGPARAM("EVEN")))
             eId=ocIsEven;
-    else if(sTest== "ODD")
+    else if (rTest.equalsL(RTL_CONSTASCII_STRINGPARAM("ODD")))
             eId=ocIsOdd;
-    else if(sTest== "ACOT")
+    else if (rTest.equalsL(RTL_CONSTASCII_STRINGPARAM("ACOT")))
             eId=ocArcCot;
-    else if(sTest== "COT")
+    else if (rTest.equalsL(RTL_CONSTASCII_STRINGPARAM("COT")))
             eId=ocCot;
-    else if(sTest== "TRUNC")
+    else if (rTest.equalsL(RTL_CONSTASCII_STRINGPARAM("TRUNC")))
             eId=ocTrunc;
-    else if(sTest== "GEOMEAN")
+    else if (rTest.equalsL(RTL_CONSTASCII_STRINGPARAM("GEOMEAN")))
             eId=ocGeoMean;
-    else if(sTest== "HARMEAN")
+    else if (rTest.equalsL(RTL_CONSTASCII_STRINGPARAM("HARMEAN")))
             eId=ocHarMean;
-    else if(sTest== "CORREL")
+    else if (rTest.equalsL(RTL_CONSTASCII_STRINGPARAM("CORREL")))
             eId=ocCorrel;
-    else if(sTest== "MEDIAN")
+    else if (rTest.equalsL(RTL_CONSTASCII_STRINGPARAM("MEDIAN")))
             eId=ocMedian;
-    else if(sTest== "COV")
+    else if (rTest.equalsL(RTL_CONSTASCII_STRINGPARAM("COV")))
             eId=ocCovar;
-    else if(sTest== "SKEWNESS")
+    else if (rTest.equalsL(RTL_CONSTASCII_STRINGPARAM("SKEWNESS")))
             eId=ocSchiefe;
-    else if(sTest== "CHITEST")
+    else if (rTest.equalsL(RTL_CONSTASCII_STRINGPARAM("CHITEST")))
             eId=ocChiTest;
-    else if(sTest== "FTEST")
+    else if (rTest.equalsL(RTL_CONSTASCII_STRINGPARAM("FTEST")))
             eId=ocFTest;
-    else if(sTest== "AVEDEV")
+    else if (rTest.equalsL(RTL_CONSTASCII_STRINGPARAM("AVEDEV")))
             eId=ocAveDev;
-    else if(sTest== "PRODUCT")
+    else if (rTest.equalsL(RTL_CONSTASCII_STRINGPARAM("PRODUCT")))
             eId=ocProduct;
-    else if(sTest== "PERMUT")
+    else if (rTest.equalsL(RTL_CONSTASCII_STRINGPARAM("PERMUT")))
             eId=ocVariationen;
-    else if(sTest== "GAMMALN")
+    else if (rTest.equalsL(RTL_CONSTASCII_STRINGPARAM("GAMMALN")))
             eId=ocGammaLn;
-    else if(sTest== "POISSON")
+    else if (rTest.equalsL(RTL_CONSTASCII_STRINGPARAM("POISSON")))
             eId=ocPoissonDist;
-    else if(sTest== "NORMAL")
+    else if (rTest.equalsL(RTL_CONSTASCII_STRINGPARAM("NORMAL")))
             eId=ocNormDist;
-    else if(sTest== "CRITBINOMIAL")
+    else if (rTest.equalsL(RTL_CONSTASCII_STRINGPARAM("CRITBINOMIAL")))
             eId=ocKritBinom;
     return eId;
-
-
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
