@@ -56,7 +56,11 @@
 
 //--------------------------------------------------------- EXTERNE VARIABLEN -
 extern WKTYP                eTyp;           // -> filter.cxx, aktueller Dateityp
+extern sal_Char*            pDummy2;        // -> memory.cxx
 extern ScDocument*          pDoc;           // -> filter.cxx, Aufhaenger zum Dokumentzugriff
+extern CharSet              eCharNach;      // -> filter.cxx, Zeichenkonvertierung von->nach
+
+extern sal_Bool                 bFormInit;      // -> memory.cxx, fuer GetFormHandle()
 
 //--------------------------------------------------------- GLOBALE VARIABLEN -
 sal_uInt8                       nDefaultFormat; // -> op.cpp, Standard-Zellenformat
@@ -82,8 +86,6 @@ void PutFormString( SCCOL nCol, SCROW nRow, SCTAB nTab, sal_Char* pString )
 {
     // Label-Format-Auswertung
     OSL_ENSURE( pString != NULL, "PutFormString(): pString == NULL" );
-    if (!pString)
-        return;
 
     sal_Char            cForm;
     SvxHorJustifyItem*  pJustify = NULL;
@@ -115,9 +117,12 @@ void PutFormString( SCCOL nCol, SCROW nRow, SCTAB nTab, sal_Char* pString )
             pJustify = pAttrStandard;
     }
 
-    pDoc->ApplyAttr( nCol, nRow, nTab, *pJustify );
-    ScStringCell*	pZelle = new ScStringCell( String( pString, pLotusRoot->eCharsetQ ) );
-    pDoc->PutCell( nCol, nRow, nTab, pZelle, true );
+    if( pString )
+    {
+        pDoc->ApplyAttr( nCol, nRow, nTab, *pJustify );
+        ScStringCell*   pZelle = new ScStringCell( String( pString, pLotusRoot->eCharsetQ ) );
+        pDoc->PutCell( nCol, nRow, nTab, pZelle, true );
+    }
 }
 
 
@@ -208,11 +213,11 @@ SfxUInt32Item* FormCache::NewAttr( sal_uInt8 nFormat, sal_uInt8 nSt )
     // neues Format erzeugen
     sal_uInt8       nL, nH; // Low-/High-Nibble
     sal_uInt8       nForm = nFormat;
-    String      aFormString;
-    const sal_Char* pFormString = 0;
+    String          aFormString;
     sal_Int16       eType = NUMBERFORMAT_ALL;
     sal_uInt32      nIndex1;
     sal_uInt32      nHandle;
+    NfIndexTableOffset eIndexTableOffset = NF_NUMERIC_START;
     sal_Bool        bDefault = false;
     //void GenerateFormat( aFormString, eType, COUNTRY_SYSTEM, LANGUAGE_SYSTEM,
     //  sal_Bool bThousand, sal_Bool IsRed, sal_uInt16 nPrecision, sal_uInt16 nAnzLeading );
@@ -297,57 +302,61 @@ SfxUInt32Item* FormCache::NewAttr( sal_uInt8 nFormat, sal_uInt8 nSt )
                 case 0x02:  // Datum: Tag, Monat, Jahr
                     //fDate;dfDayMonthYearLong;
                     eType = NUMBERFORMAT_DATE;
-                    pFormString = "TT.MM.JJJJ";
+                    eIndexTableOffset = NF_DATE_SYS_DDMMYYYY;
                     break;
                 case 0x03:  // Datum: Tag, Monat
                     //fDate;dfDayMonthLong;
                     eType = NUMBERFORMAT_DATE;
-                    pFormString = "TT.MMMM";
+                    aFormString = pFormTable->GetKeyword( eLanguage, NF_KEY_DD);
+                    aFormString += pFormTable->GetDateSep();    // matches last eLanguage
+                    aFormString += pFormTable->GetKeyword( eLanguage, NF_KEY_MMMM);
                     break;
                 case 0x04:  // Datum: Monat, Jahr
                     //fDate;dfMonthYearLong;
                     eType = NUMBERFORMAT_DATE;
-                    pFormString = "MM.JJJJ";
+                    aFormString = pFormTable->GetKeyword( eLanguage, NF_KEY_MM);
+                    aFormString += pFormTable->GetDateSep();    // matches last eLanguage
+                    aFormString += pFormTable->GetKeyword( eLanguage, NF_KEY_YYYY);
                     break;
                 case 0x05:  // Textformate
                     //fString;nSt;
                     eType = NUMBERFORMAT_TEXT;
-                    pFormString = "@";
+                    eIndexTableOffset = NF_TEXT;
                     break;
                 case 0x06:  // versteckt
                     //wFlag |= paHideAll;bSetFormat = sal_False;
                     eType = NUMBERFORMAT_NUMBER;
-                    pFormString = "";
+                    aFormString = "\"\"";
                     break;
                 case 0x07:  // Time: hour, min, sec
                     //fTime;tfHourMinSec24;
                     eType = NUMBERFORMAT_TIME;
-                    pFormString = "HH:MM:SS";
+                    eIndexTableOffset = NF_TIME_HHMMSS;
                     break;
                 case 0x08:  // Time: hour, min
                     //fTime;tfHourMin24;
                     eType = NUMBERFORMAT_TIME;
-                    pFormString = "HH:MM";
+                    eIndexTableOffset = NF_TIME_HHMM;
                     break;
                 case 0x09:  // Date, intern sal_Int32 1
                     //fDate;dfDayMonthYearLong;
                     eType = NUMBERFORMAT_DATE;
-                    pFormString = "TT.MM.JJJJ";
+                    eIndexTableOffset = NF_DATE_SYS_DDMMYYYY;
                     break;
                 case 0x0A:  // Date, intern sal_Int32 2
                     //fDate;dfDayMonthYearLong;
                     eType = NUMBERFORMAT_DATE;
-                    pFormString = "TT.MM.JJJJ";
+                    eIndexTableOffset = NF_DATE_SYS_DDMMYYYY;
                     break;
                 case 0x0B:  // Time, intern sal_Int32 1
                     //fTime;tfHourMinSec24;
                     eType = NUMBERFORMAT_TIME;
-                    pFormString = "HH:MM:SS";
+                    eIndexTableOffset = NF_TIME_HHMMSS;
                     break;
                 case 0x0C:  // Time, intern sal_Int32 2
                     //fTime;tfHourMinSec24;
                     eType = NUMBERFORMAT_TIME;
-                    pFormString = "HH:MM:SS";
+                    eIndexTableOffset = NF_TIME_HHMMSS;
                     break;
                 case 0x0F:  // Standardeinstellung
                     //fStandard;nSt;
@@ -372,11 +381,10 @@ SfxUInt32Item* FormCache::NewAttr( sal_uInt8 nFormat, sal_uInt8 nSt )
     // Format in Table schieben
     if( bDefault )
         nHandle = 0;
+    else if (eIndexTableOffset != NF_NUMERIC_START)
+        nHandle = pFormTable->GetFormatIndex( eIndexTableOffset, eLanguage);
     else
     {
-        if( pFormString )
-            aFormString.AssignAscii( pFormString );
-
         xub_StrLen  nDummy;
         pFormTable->PutEntry( aFormString, nDummy, eType, nHandle, eLanguage );
     }
