@@ -83,51 +83,36 @@ using namespace com::sun::star;
 
 #define DEFCHARSET          RTL_TEXTENCODING_MS_1252
 
-#define SC10TOSTRING(p)		String((p),DEFCHARSET)
+#define SC10TOSTRING(p)     String(p,DEFCHARSET)
 
 const SCCOL SC10MAXCOL = 255;   // #i85906# don't try to load more columns than there are in the file
 
 
-/** Those strings are used with SC10TOSTRING() and strcmp() and such, hence 
-    need to be 0-terminated. */
-static void lcl_ReadFixedString( SvStream& rStream, void* pData, size_t nLen )
+void lcl_ReadFileHeader(SvStream& rStream, Sc10FileHeader& rFileHeader)
 {
-    sal_Char* pBuf = static_cast<sal_Char*>(pData);
-    if (!nLen)
-        pBuf[0] = 0;
-    else
-    {
-        rStream.Read( pBuf, nLen);
-        pBuf[nLen-1] = 0;
-    }
-}
-
-
-static void lcl_ReadFileHeader(SvStream& rStream, Sc10FileHeader& rFileHeader)
-{
-	lcl_ReadFixedString( rStream, &rFileHeader.CopyRight, sizeof(rFileHeader.CopyRight));
+    rStream.Read(&rFileHeader.CopyRight, sizeof(rFileHeader.CopyRight));
     rStream >> rFileHeader.Version;
     rStream.Read(&rFileHeader.Reserved, sizeof(rFileHeader.Reserved));
 }
 
 
-static void lcl_ReadTabProtect(SvStream& rStream, Sc10TableProtect& rProtect)
+void lcl_ReadTabProtect(SvStream& rStream, Sc10TableProtect& rProtect)
 {
-	lcl_ReadFixedString( rStream, &rProtect.PassWord, sizeof(rProtect.PassWord));
+    rStream.Read(&rProtect.PassWord, sizeof(rProtect.PassWord));
     rStream >> rProtect.Flags;
     rStream >> rProtect.Protect;
 }
 
 
-static void lcl_ReadSheetProtect(SvStream& rStream, Sc10SheetProtect& rProtect)
+void lcl_ReadSheetProtect(SvStream& rStream, Sc10SheetProtect& rProtect)
 {
-	lcl_ReadFixedString( rStream, &rProtect.PassWord, sizeof(rProtect.PassWord));
+    rStream.Read(&rProtect.PassWord, sizeof(rProtect.PassWord));
     rStream >> rProtect.Flags;
     rStream >> rProtect.Protect;
 }
 
 
-static void lcl_ReadRGB(SvStream& rStream, Sc10Color& rColor)
+void lcl_ReadRGB(SvStream& rStream, Sc10Color& rColor)
 {
     rStream >> rColor.Dummy;
     rStream >> rColor.Blue;
@@ -136,21 +121,21 @@ static void lcl_ReadRGB(SvStream& rStream, Sc10Color& rColor)
 }
 
 
-static void lcl_ReadPalette(SvStream& rStream, Sc10Color* pPalette)
+void lcl_ReadPalette(SvStream& rStream, Sc10Color* pPalette)
 {
     for (sal_uInt16 i = 0; i < 16; i++)
         lcl_ReadRGB(rStream, pPalette[i]);
 }
 
 
-static void lcl_ReadValueFormat(SvStream& rStream, Sc10ValueFormat& rFormat)
+void lcl_ReadValueFormat(SvStream& rStream, Sc10ValueFormat& rFormat)
 {
     rStream >> rFormat.Format;
     rStream >> rFormat.Info;
 }
 
 
-static void lcl_ReadLogFont(SvStream& rStream, Sc10LogFont& rFont)
+void lcl_ReadLogFont(SvStream& rStream, Sc10LogFont& rFont)
 {
     rStream >> rFont.lfHeight;
     rStream >> rFont.lfWidth;
@@ -165,11 +150,11 @@ static void lcl_ReadLogFont(SvStream& rStream, Sc10LogFont& rFont)
     rStream >> rFont.lfClipPrecision;
     rStream >> rFont.lfQuality;
     rStream >> rFont.lfPitchAndFamily;
-	lcl_ReadFixedString( rStream, &rFont.lfFaceName, sizeof(rFont.lfFaceName));
+    rStream.Read(&rFont.lfFaceName, sizeof(rFont.lfFaceName));
 }
 
 
-static void lcl_ReadBlockRect(SvStream& rStream, Sc10BlockRect& rBlock)
+void lcl_ReadBlockRect(SvStream& rStream, Sc10BlockRect& rBlock)
 {
     rStream >> rBlock.x1;
     rStream >> rBlock.y1;
@@ -178,9 +163,9 @@ static void lcl_ReadBlockRect(SvStream& rStream, Sc10BlockRect& rBlock)
 }
 
 
-static void lcl_ReadHeadFootLine(SvStream& rStream, Sc10HeadFootLine& rLine)
+void lcl_ReadHeadFootLine(SvStream& rStream, Sc10HeadFootLine& rLine)
 {
-	lcl_ReadFixedString( rStream, &rLine.Title, sizeof(rLine.Title));
+    rStream.Read(&rLine.Title, sizeof(rLine.Title));
     lcl_ReadLogFont(rStream, rLine.LogFont);
     rStream >> rLine.HorJustify;
     rStream >> rLine.VerJustify;
@@ -194,7 +179,7 @@ static void lcl_ReadHeadFootLine(SvStream& rStream, Sc10HeadFootLine& rLine)
 }
 
 
-static void lcl_ReadPageFormat(SvStream& rStream, Sc10PageFormat& rFormat)
+void lcl_ReadPageFormat(SvStream& rStream, Sc10PageFormat& rFormat)
 {
     lcl_ReadHeadFootLine(rStream, rFormat.HeadLine);
     lcl_ReadHeadFootLine(rStream, rFormat.FootLine);
@@ -215,7 +200,7 @@ static void lcl_ReadPageFormat(SvStream& rStream, Sc10PageFormat& rFormat)
     rStream >> rFormat.PrintColRow;
     rStream >> rFormat.PrintNote;
     rStream >> rFormat.TopBottomDir;
-	lcl_ReadFixedString( rStream, &rFormat.PrintAreaName, sizeof(rFormat.PrintAreaName));
+    rStream.Read(&rFormat.PrintAreaName, sizeof(rFormat.PrintAreaName));
     lcl_ReadBlockRect(rStream, rFormat.PrintArea);
     rStream.Read(&rFormat.PrnZoom, sizeof(rFormat.PrnZoom));
     rStream >> rFormat.FirstPageNo;
@@ -227,7 +212,7 @@ static void lcl_ReadPageFormat(SvStream& rStream, Sc10PageFormat& rFormat)
 }
 
 
-static void lcl_ReadGraphHeader(SvStream& rStream, Sc10GraphHeader& rHeader)
+void lcl_ReadGraphHeader(SvStream& rStream, Sc10GraphHeader& rHeader)
 {
     rStream >> rHeader.Typ;
     rStream >> rHeader.CarretX;
@@ -247,9 +232,9 @@ static void lcl_ReadGraphHeader(SvStream& rStream, Sc10GraphHeader& rHeader)
 }
 
 
-static void lcl_ReadImageHeaer(SvStream& rStream, Sc10ImageHeader& rHeader)
+void lcl_ReadImageHeaer(SvStream& rStream, Sc10ImageHeader& rHeader)
 {
-	lcl_ReadFixedString( rStream, &rHeader.FileName, sizeof(rHeader.FileName));
+    rStream.Read(&rHeader.FileName, sizeof(rHeader.FileName));
     rStream >> rHeader.Typ;
     rStream >> rHeader.Linked;
     rStream >> rHeader.x1;
@@ -260,7 +245,7 @@ static void lcl_ReadImageHeaer(SvStream& rStream, Sc10ImageHeader& rHeader)
 }
 
 
-static void lcl_ReadChartHeader(SvStream& rStream, Sc10ChartHeader& rHeader)
+void lcl_ReadChartHeader(SvStream& rStream, Sc10ChartHeader& rHeader)
 {
     rStream >> rHeader.MM;
     rStream >> rHeader.xExt;
@@ -269,7 +254,7 @@ static void lcl_ReadChartHeader(SvStream& rStream, Sc10ChartHeader& rHeader)
 }
 
 
-static void lcl_ReadChartSheetData(SvStream& rStream, Sc10ChartSheetData& rSheetData)
+void lcl_ReadChartSheetData(SvStream& rStream, Sc10ChartSheetData& rSheetData)
 {
     rStream >> rSheetData.HasTitle;
     rStream >> rSheetData.TitleX;
@@ -298,15 +283,15 @@ static void lcl_ReadChartSheetData(SvStream& rStream, Sc10ChartSheetData& rSheet
 }
 
 
-static void lcl_ReadChartTypeData(SvStream& rStream, Sc10ChartTypeData& rTypeData)
+void lcl_ReadChartTypeData(SvStream& rStream, Sc10ChartTypeData& rTypeData)
 {
     rStream >> rTypeData.NumSets;
     rStream >> rTypeData.NumPoints;
     rStream >> rTypeData.DrawMode;
     rStream >> rTypeData.GraphType;
     rStream >> rTypeData.GraphStyle;
-	lcl_ReadFixedString( rStream, &rTypeData.GraphTitle, sizeof(rTypeData.GraphTitle));
-	lcl_ReadFixedString( rStream, &rTypeData.BottomTitle, sizeof(rTypeData.BottomTitle));
+    rStream.Read(&rTypeData.GraphTitle, sizeof(rTypeData.GraphTitle));
+    rStream.Read(&rTypeData.BottomTitle, sizeof(rTypeData.BottomTitle));
     sal_uInt16 i;
     for (i = 0; i < 256; i++)
         rStream >> rTypeData.SymbolData[i];
@@ -322,7 +307,7 @@ static void lcl_ReadChartTypeData(SvStream& rStream, Sc10ChartTypeData& rTypeDat
         rStream >> rTypeData.NumGraphStyles[i];
     rStream >> rTypeData.ShowLegend;
     for (i = 0; i < 256; i++)
-		lcl_ReadFixedString( rStream, &rTypeData.LegendText[i], sizeof(Sc10ChartText));
+        rStream.Read(&rTypeData.LegendText[i], sizeof(Sc10ChartText));
     rStream >> rTypeData.ExplodePie;
     rStream >> rTypeData.FontUse;
     for (i = 0; i < 5; i++)
@@ -335,8 +320,8 @@ static void lcl_ReadChartTypeData(SvStream& rStream, Sc10ChartTypeData& rTypeDat
     rStream >> rTypeData.Labels;
     rStream >> rTypeData.LabelEvery;
     for (i = 0; i < 50; i++)
-		lcl_ReadFixedString( rStream, &rTypeData.LabelText[i], sizeof(Sc10ChartText));
-	lcl_ReadFixedString( rStream, &rTypeData.LeftTitle, sizeof(rTypeData.LeftTitle));
+        rStream.Read(&rTypeData.LabelText[i], sizeof(Sc10ChartText));
+    rStream.Read(&rTypeData.LeftTitle, sizeof(rTypeData.LeftTitle));
     rStream.Read(&rTypeData.Reserved, sizeof(rTypeData.Reserved));
 }
 
@@ -361,7 +346,7 @@ double lcl_PascalToDouble(sal_Char* tp6)
 }
 
 
-static void lcl_ChangeColor( sal_uInt16 nIndex, Color& rColor )
+void lcl_ChangeColor( sal_uInt16 nIndex, Color& rColor )
 {
     ColorData aCol;
 
@@ -397,23 +382,6 @@ String lcl_MakeOldPageStyleFormatName( sal_uInt16 i )
     return aName;
 }
 
-
-template < typename T > sal_uLong insert_new( ScCollection* pCollection, SvStream& rStream )
-{
-    T* pData = new (::std::nothrow) T( rStream);
-    sal_uLong nError = rStream.GetError();
-    if (pData)
-    {
-        if (nError)
-            delete pData;
-        else
-            pCollection->Insert( pData);
-    }
-    else
-        nError = errOutOfMemory;
-    return nError;
-}
-
 //--------------------------------------------
 // Font
 //--------------------------------------------
@@ -444,7 +412,8 @@ Sc10FontCollection::Sc10FontCollection(SvStream& rStream) :
     rStream >> nAnz;
     for (sal_uInt16 i=0; (i < nAnz) && (nError == 0); i++)
     {
-        nError = insert_new<Sc10FontData>( this, rStream);
+      Insert(new Sc10FontData(rStream));
+      nError = rStream.GetError();
     }
   }
   else
@@ -488,7 +457,8 @@ Sc10NameCollection::Sc10NameCollection(SvStream& rStream) :
     rStream >> nAnz;
     for (sal_uInt16 i=0; (i < nAnz) && (nError == 0); i++)
     {
-        nError = insert_new<Sc10NameData>( this, rStream);
+      Insert(new Sc10NameData(rStream));
+      nError = rStream.GetError();
     }
   }
   else
@@ -504,7 +474,7 @@ Sc10NameCollection::Sc10NameCollection(SvStream& rStream) :
 
 Sc10PatternData::Sc10PatternData(SvStream& rStream)
 {
-  lcl_ReadFixedString( rStream, Name, sizeof(Name));
+  rStream.Read(Name, sizeof(Name));
   lcl_ReadValueFormat(rStream, ValueFormat);
   lcl_ReadLogFont(rStream, LogFont);
 
@@ -532,7 +502,8 @@ Sc10PatternCollection::Sc10PatternCollection(SvStream& rStream) :
     rStream >> nAnz;
     for (sal_uInt16 i=0; (i < nAnz) && (nError == 0); i++)
     {
-        nError = insert_new<Sc10PatternData>( this, rStream);
+      Insert(new Sc10PatternData(rStream));
+      nError = rStream.GetError();
     }
   }
   else
@@ -548,7 +519,7 @@ Sc10PatternCollection::Sc10PatternCollection(SvStream& rStream) :
 
 Sc10DataBaseData::Sc10DataBaseData(SvStream& rStream)
 {
-	lcl_ReadFixedString( rStream, &DataBaseRec.Name, sizeof(DataBaseRec.Name));
+    rStream.Read(&DataBaseRec.Name, sizeof(DataBaseRec.Name));
     rStream >> DataBaseRec.Tab;
     lcl_ReadBlockRect(rStream, DataBaseRec.Block);
     rStream >> DataBaseRec.RowHeader;
@@ -563,21 +534,21 @@ Sc10DataBaseData::Sc10DataBaseData(SvStream& rStream)
     rStream >> DataBaseRec.QueryField0;
     rStream >> DataBaseRec.QueryOp0;
     rStream >> DataBaseRec.QueryByString0;
-	lcl_ReadFixedString( rStream, &DataBaseRec.QueryString0, sizeof(DataBaseRec.QueryString0));
+    rStream.Read(&DataBaseRec.QueryString0, sizeof(DataBaseRec.QueryString0));
     DataBaseRec.QueryValue0 = ScfTools::ReadLongDouble(rStream);
 
     rStream >> DataBaseRec.QueryConnect1;
     rStream >> DataBaseRec.QueryField1;
     rStream >> DataBaseRec.QueryOp1;
     rStream >> DataBaseRec.QueryByString1;
-	lcl_ReadFixedString( rStream, &DataBaseRec.QueryString1, sizeof(DataBaseRec.QueryString1));
+    rStream.Read(&DataBaseRec.QueryString1, sizeof(DataBaseRec.QueryString1));
     DataBaseRec.QueryValue1 = ScfTools::ReadLongDouble(rStream);
 
     rStream >> DataBaseRec.QueryConnect2;
     rStream >> DataBaseRec.QueryField2;
     rStream >> DataBaseRec.QueryOp2;
     rStream >> DataBaseRec.QueryByString2;
-	lcl_ReadFixedString( rStream, &DataBaseRec.QueryString2, sizeof(DataBaseRec.QueryString2));
+    rStream.Read(&DataBaseRec.QueryString2, sizeof(DataBaseRec.QueryString2));
     DataBaseRec.QueryValue2 = ScfTools::ReadLongDouble(rStream);
 }
 
@@ -590,12 +561,13 @@ Sc10DataBaseCollection::Sc10DataBaseCollection(SvStream& rStream) :
   rStream >> ID;
   if (ID == DataBaseID)
   {
-	lcl_ReadFixedString( rStream, ActName, sizeof(ActName));
+    rStream.Read(ActName, sizeof(ActName));
     sal_uInt16 nAnz;
     rStream >> nAnz;
     for (sal_uInt16 i=0; (i < nAnz) && (nError == 0); i++)
     {
-        nError = insert_new<Sc10DataBaseData>( this, rStream);
+      Insert(new Sc10DataBaseData(rStream));
+      nError = rStream.GetError();
     }
   }
   else
@@ -1129,16 +1101,12 @@ void Sc10Import::LoadPalette()
 void Sc10Import::LoadFontCollection()
 {
     pFontCollection = new Sc10FontCollection(rStream);
-    if (!nError)
-        nError = pFontCollection->GetError();
 }
 
 
 void Sc10Import::LoadNameCollection()
 {
     pNameCollection = new Sc10NameCollection(rStream);
-    if (!nError)
-        nError = pNameCollection->GetError();
 }
 
 
@@ -1159,10 +1127,6 @@ void Sc10Import::ImportNameCollection()
 void Sc10Import::LoadPatternCollection()
 {
     pPatternCollection = new Sc10PatternCollection( rStream );
-    if (!nError)
-        nError = pPatternCollection->GetError();
-    if (nError == errOutOfMemory)
-        return;     // hopeless
     ScStyleSheetPool* pStylePool = pDoc->GetStyleSheetPool();
     for( sal_uInt16 i = 0 ; i < pPatternCollection->GetCount() ; i++ )
     {
@@ -1393,10 +1357,6 @@ void Sc10Import::LoadPatternCollection()
 void Sc10Import::LoadDataBaseCollection()
 {
     pDataBaseCollection = new Sc10DataBaseCollection(rStream);
-    if (!nError)
-        nError = pDataBaseCollection->GetError();
-    if (nError == errOutOfMemory)
-        return;     // hopeless
     for( sal_uInt16 i = 0 ; i < pDataBaseCollection->GetCount() ; i++ )
     {
         Sc10DataBaseData* pOldData = pDataBaseCollection->At(i);
@@ -1748,7 +1708,7 @@ void Sc10Import::LoadColAttr(SCCOL Col, SCTAB Tab)
         sal_uInt16 nValue1;
         Sc10ColData *pColData;
 
-        // Font (Name, Groesse)
+        // Font (Name, Size)
         nStart = 0;
         nEnd = 0;
         nLimit = aFont.Count;
@@ -1760,29 +1720,26 @@ void Sc10Import::LoadColAttr(SCCOL Col, SCTAB Tab)
             {
                 FontFamily eFam = FAMILY_DONTKNOW;
                 Sc10FontData* pFont = pFontCollection->At(pColData->Value);
-                if (pFont)
+                switch (pFont->PitchAndFamily & 0xF0)
                 {
-                    switch (pFont->PitchAndFamily & 0xF0)
-                    {
-                        case ffDontCare   : eFam = FAMILY_DONTKNOW;		break;
-                        case ffRoman      : eFam = FAMILY_ROMAN;		break;
-                        case ffSwiss      : eFam = FAMILY_SWISS;		break;
-                        case ffModern     : eFam = FAMILY_MODERN;		break;
-                        case ffScript     : eFam = FAMILY_SCRIPT;		break;
-                        case ffDecorative : eFam = FAMILY_DECORATIVE;	break;
-                        default: eFam = FAMILY_DONTKNOW;		break;
-                    }
-                    ScPatternAttr aScPattern(pDoc->GetPool());
-                    aScPattern.GetItemSet().Put(SvxFontItem(eFam, SC10TOSTRING( pFont->FaceName ), EMPTY_STRING,
-                        PITCH_DONTKNOW, RTL_TEXTENCODING_DONTKNOW, ATTR_FONT ));
-                    aScPattern.GetItemSet().Put(SvxFontHeightItem(Abs(pFont->Height), 100, ATTR_FONT_HEIGHT ));
-                    pDoc->ApplyPatternAreaTab(Col, nStart, Col, nEnd, Tab, aScPattern);
+                    case ffDontCare   : eFam = FAMILY_DONTKNOW;     break;
+                    case ffRoman      : eFam = FAMILY_ROMAN;        break;
+                    case ffSwiss      : eFam = FAMILY_SWISS;        break;
+                    case ffModern     : eFam = FAMILY_MODERN;       break;
+                    case ffScript     : eFam = FAMILY_SCRIPT;       break;
+                    case ffDecorative : eFam = FAMILY_DECORATIVE;   break;
+                    default: eFam = FAMILY_DONTKNOW;        break;
                 }
+                ScPatternAttr aScPattern(pDoc->GetPool());
+                aScPattern.GetItemSet().Put(SvxFontItem(eFam, SC10TOSTRING( pFont->FaceName ), EMPTY_STRING,
+                    PITCH_DONTKNOW, RTL_TEXTENCODING_DONTKNOW, ATTR_FONT ));
+                aScPattern.GetItemSet().Put(SvxFontHeightItem(Abs(pFont->Height), 100, ATTR_FONT_HEIGHT ));
+                pDoc->ApplyPatternAreaTab(Col, nStart, Col, nEnd, Tab, aScPattern);
             }
             nStart = nEnd + 1;
         }
 
-    // Fontfarbe
+    // Font color
     nStart = 0;
     nEnd = 0;
     nLimit = aColor.Count;
@@ -1801,7 +1758,7 @@ void Sc10Import::LoadColAttr(SCCOL Col, SCTAB Tab)
         nStart = nEnd + 1;
     }
 
-    // Fontattribute (Fett, Kursiv...)
+    // Font attributes (Bold, Italic...)
     nStart = 0;
     nEnd = 0;
     nLimit = aAttr.Count;
@@ -1826,7 +1783,7 @@ void Sc10Import::LoadColAttr(SCCOL Col, SCTAB Tab)
         nStart = nEnd + 1;
     }
 
-    // Zellausrichtung
+    // Cell alignment
     nStart = 0;
     nEnd = 0;
     nLimit = aJustify.Count;
@@ -1877,15 +1834,15 @@ void Sc10Import::LoadColAttr(SCCOL Col, SCTAB Tab)
                 aScPattern.GetItemSet().Put(SfxInt32Item(ATTR_ROTATE_VALUE,27000));
 
             sal_Int16 Margin = Max((sal_uInt16)20, (sal_uInt16)(EJustify * 20));
-            if (((OJustify & ojBottomTop) == ojBottomTop) || ((OJustify & ojBottomTop) == ojBottomTop))
+            if (OJustify & ojBottomTop)
                 aScPattern.GetItemSet().Put(SvxMarginItem(20, Margin, 20, Margin, ATTR_MARGIN));
             else
                 aScPattern.GetItemSet().Put(SvxMarginItem(Margin, 20, Margin, 20, ATTR_MARGIN));
             pDoc->ApplyPatternAreaTab(Col, nStart, Col, nEnd, Tab, aScPattern);
         }
-    nStart = nEnd + 1;
+        nStart = nEnd + 1;
     }
-    // Umrandung
+    // Border
     sal_Bool            bEnd = false;
     sal_uInt16          nColorIndex = 0;
     sal_uInt16          nFrameIndex = 0;
@@ -2009,9 +1966,9 @@ void Sc10Import::LoadColAttr(SCCOL Col, SCTAB Tab)
         pColData++;
     }
 
-    // ACHTUNG: Code bis hier ueberarbeitet ... jetzt hab' ich keinen Bock mehr! (GT)
+    // ATTENTION: Code up to here works more or less ... from here I've had enough ! (GT)
 
-    // Hintergrund (Farbe, Raster)
+    // Background (Color, Raster)
     sal_uInt16      nRasterIndex = 0;
     bEnd        = false;
     nColorIndex = 0;
@@ -2099,7 +2056,7 @@ void Sc10Import::LoadColAttr(SCCOL Col, SCTAB Tab)
         nHelpMe--;
     }
 
-    // Zahlenformate
+    // Number format
     nStart = 0;
     nEnd = 0;
     nLimit = aValue.Count;
@@ -2121,7 +2078,7 @@ void Sc10Import::LoadColAttr(SCCOL Col, SCTAB Tab)
         nStart = nEnd + 1;
     }
 
-    // Zellattribute (Schutz, Versteckt...)
+    // Cell attributes (Protected, hidden...)
     nStart = 0;
     nEnd = 0;
     for (i=0; i<aFlag.Count; i++)
@@ -2140,7 +2097,7 @@ void Sc10Import::LoadColAttr(SCCOL Col, SCTAB Tab)
         nStart = nEnd + 1;
     }
 
-    // ZellVorlagen
+    // Cell style
     nStart = 0;
     nEnd = 0;
     ScStyleSheetPool* pStylePool = pDoc->GetStyleSheetPool();
@@ -2163,31 +2120,35 @@ void Sc10Import::LoadColAttr(SCCOL Col, SCTAB Tab)
         nStart = nEnd + 1;
     }
   }
+
+  delete[] aFont.pData;
+  delete[] aAttr.pData;
+  delete[] aJustify.pData;
+  delete[] aFrame.pData;
+  delete[] aRaster.pData;
+  delete[] aValue.pData;
+  delete[] aColor.pData;
+  delete[] aFrameColor.pData;
+  delete[] aFlag.pData;
+  delete[] aPattern.pData;
 }
 
 
 void Sc10Import::LoadAttr(Sc10ColAttr& rAttr)
 {
-    // rAttr is not reused, otherwise we'd have to delete [] rAttr.pData;
-    rStream >> rAttr.Count;
-    if (rAttr.Count)
+  rStream >> rAttr.Count;
+  rAttr.pData = new Sc10ColData[rAttr.Count];
+  if (rAttr.pData != NULL)
+  {
+    for (sal_uInt16 i = 0; i < rAttr.Count; i++)
     {
-        rAttr.pData = new (::std::nothrow) Sc10ColData[rAttr.Count];
-        if (rAttr.pData != NULL)
-        {
-            for (sal_uInt16 i = 0; i < rAttr.Count; i++)
-            {
-                rStream >> rAttr.pData[i].Row;
-                rStream >> rAttr.pData[i].Value;
-            }
-            nError = rStream.GetError();
-        }
-        else
-        {
-            nError = errOutOfMemory;
-            rAttr.Count = 0;
-        }
+      rStream >> rAttr.pData[i].Row;
+      rStream >> rAttr.pData[i].Value;
     }
+    nError = rStream.GetError();
+  }
+  else
+    nError = errOutOfMemory;
 }
 
 
@@ -2396,28 +2357,22 @@ void Sc10Import::LoadObjects()
           {
             Sc10ChartHeader ChartHeader;
             Sc10ChartSheetData ChartSheetData;
-			Sc10ChartTypeData* pTypeData = new (::std::nothrow) Sc10ChartTypeData;
-            if (!pTypeData)
-                nError = errOutOfMemory;
-            else
-            {
-                lcl_ReadChartHeader(rStream, ChartHeader);
+            Sc10ChartTypeData* pTypeData = new Sc10ChartTypeData;
+            lcl_ReadChartHeader(rStream, ChartHeader);
 
-                //!	altes Metafile verwenden ??
-                rStream.SeekRel(ChartHeader.Size);
+            //! altes Metafile verwenden ??
+            rStream.SeekRel(ChartHeader.Size);
 
-                lcl_ReadChartSheetData(rStream, ChartSheetData);
- 
-                lcl_ReadChartTypeData(rStream, *pTypeData);
+            lcl_ReadChartSheetData(rStream, ChartSheetData);
+            lcl_ReadChartTypeData(rStream, *pTypeData);
 
-                Rectangle aRect( Point(nStartX,nStartY), Size(nSizeX,nSizeY) );
-                Sc10InsertObject::InsertChart( pDoc, static_cast<SCTAB>(GraphHeader.CarretZ), aRect,
-                        static_cast<SCTAB>(GraphHeader.CarretZ),
-                        ChartSheetData.DataX1, ChartSheetData.DataY1,
-                        ChartSheetData.DataX2, ChartSheetData.DataY2 );
+            Rectangle aRect( Point(nStartX,nStartY), Size(nSizeX,nSizeY) );
+            Sc10InsertObject::InsertChart( pDoc, static_cast<SCTAB>(GraphHeader.CarretZ), aRect,
+                                static_cast<SCTAB>(GraphHeader.CarretZ),
+                                ChartSheetData.DataX1, ChartSheetData.DataY1,
+                                ChartSheetData.DataX2, ChartSheetData.DataY2 );
 
-                delete pTypeData;
-            }
+            delete pTypeData;
           }
           break;
           default :
