@@ -89,8 +89,6 @@ namespace sd {
 static sal_uInt16 SidArray[] = {
     SID_STYLE_FAMILY2,                //    5542
     SID_STYLE_FAMILY5,                //    5545
-    SID_REDO,                         //    5700
-    SID_UNDO,                         //    5701
     SID_CUT,                          //    5710
     SID_COPY,                         //    5711
     SID_ATTR_TABSTOP,                 //   10002
@@ -1368,23 +1366,6 @@ void FuText::ReceiveRequest(SfxRequest& rReq)
     }
 }
 
-
-
-/*************************************************************************
-|*
-|* SpellChecker: Error-LinkHdl
-|*
-\************************************************************************/
-
-IMPL_LINK( FuText, SpellError, void *, nLang )
-{
-    String aError( SvtLanguageTable::GetLanguageString( (LanguageType)(sal_uLong)nLang ) );
-    ErrorHandler::HandleError(* new StringErrorInfo(
-                                ERRCODE_SVX_LINGU_LANGUAGENOTEXISTS, aError) );
-    return 0;
-}
-
-
 void FuText::DoubleClick(const MouseEvent& )
 {
     // Nothing to do
