@@ -42,6 +42,7 @@
 #include <com/sun/star/task/XInteractionHandler.hpp>
 #include <com/sun/star/task/XStatusIndicator.hpp>
 #include <com/sun/star/task/XStatusIndicatorFactory.hpp>
+#include <com/sun/star/frame/DocumentTemplates.hpp>
 #include <com/sun/star/frame/XDocumentTemplates.hpp>
 #include <com/sun/star/frame/XStorable.hpp>
 #include <comphelper/processfactory.hxx>
@@ -342,9 +343,6 @@ sal_Bool SfxObjectShell::APISaveAs_Impl
                 aParams );
 
         }
-
-        // prevent picklist-entry
-        GetMedium()->SetUpdatePickList( sal_False );
     }
 
     return bOk;
@@ -668,7 +666,7 @@ void SfxObjectShell::ExecFile_Impl(SfxRequest &rReq)
                 // if the document is a new one then it appeares in the picklist immediatelly
                 // after SaveAs operation triggered from GUI
             }
-            catch( task::ErrorCodeIOException& aErrorEx )
+            catch( const task::ErrorCodeIOException& aErrorEx )
             {
                 nErrorCode = (sal_uInt32)aErrorEx.ErrCode;
             }
@@ -769,7 +767,9 @@ void SfxObjectShell::ExecFile_Impl(SfxRequest &rReq)
                 {
                     if ( !pNameItem )
                     {
+#ifndef DISABLE_SCRIPTING
                         SbxBase::SetError( SbxERR_WRONG_ARGS );
+#endif
                         rReq.Ignore();
                         return;
                     }
@@ -839,7 +839,9 @@ void SfxObjectShell::ExecFile_Impl(SfxRequest &rReq)
             if ( (!pRegionItem && !pRegionNrItem ) || !pNameItem )
             {
                 DBG_ASSERT( rReq.IsAPI(), "non-API call without Arguments" );
+#ifndef DISABLE_SCRIPTING
                 SbxBase::SetError( SbxERR_WRONG_ARGS );
+#endif
                 rReq.Ignore();
                 return;
             }
@@ -858,10 +860,8 @@ void SfxObjectShell::ExecFile_Impl(SfxRequest &rReq)
             try
             {
                 uno::Reference< frame::XStorable > xStorable( GetModel(), uno::UNO_QUERY_THROW );
-                ::rtl::OUString aService( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.frame.DocumentTemplates" ) );
                 uno::Reference< frame::XDocumentTemplates > xTemplates(
-                                comphelper::getProcessServiceFactory()->createInstance( aService ),
-                                uno::UNO_QUERY_THROW );
+                                frame::DocumentTemplates::create(comphelper::getProcessComponentContext()) );
 
                 bOk = xTemplates->storeTemplate( aTemplateGroup, aTemplateName, xStorable );
             }
