@@ -41,7 +41,6 @@
 #include <com/sun/star/frame/XTitle.hpp>
 #include <osl/mutex.hxx>
 
-#include <tools/resary.hxx>
 #include <vcl/msgbox.hxx>
 #include <vcl/wrkwin.hxx>
 #include <vcl/svapp.hxx>
@@ -127,6 +126,8 @@ namespace {
 
 static WeakReference< XInterface > s_xCurrentComponent;
 
+#ifndef DISABLE_SCRIPTING
+
 // remember all registered components for VBA compatibility, to be able to remove them on disposing the model
 typedef ::std::map< XInterface*, ::rtl::OString > VBAConstantNameMap;
 static VBAConstantNameMap s_aRegisteredVBAConstants;
@@ -143,15 +144,17 @@ static VBAConstantNameMap s_aRegisteredVBAConstants;
     if( xProps.is() ) try
     {
         ::rtl::OUString aConstName;
-        xProps->getPropertyValue( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "VBAGlobalConstantName" ) ) ) >>= aConstName;
+        xProps->getPropertyValue( ::rtl::OUString( "VBAGlobalConstantName"  ) ) >>= aConstName;
         return ::rtl::OUStringToOString( aConstName, RTL_TEXTENCODING_ASCII_US );
     }
-    catch( uno::Exception& ) // not supported
+    catch (const uno::Exception&) // not supported
     {
     }
     return ::rtl::OString();
 }
 
+#endif
+
 } // namespace
 
 //=========================================================================
@@ -189,6 +192,7 @@ void SAL_CALL SfxModelListener_Impl::disposing( const com::sun::star::lang::Even
         SfxObjectShell::SetCurrentComponent( Reference< XInterface >() );
     }
 
+#ifndef DISABLE_SCRIPTING
     /*  Remove VBA component from AppBasic. As every application registers its
         own current component, the disposed component may not be the "current
         component" of the SfxObjectShell. */
@@ -202,6 +206,7 @@ void SAL_CALL SfxModelListener_Impl::disposing( const com::sun::star::lang::Even
             s_aRegisteredVBAConstants.erase( aIt );
         }
     }
+#endif
 
     if ( mpDoc->Get_Impl()->bHiddenLockedByAPI )
     {
@@ -237,7 +242,6 @@ SfxObjectShell_Impl::SfxObjectShell_Impl( SfxObjectShell& _rDocShell )
     ,bImportDone ( sal_False)
     ,bInPrepareClose( sal_False )
     ,bPreparedForClose( sal_False )
-    ,bWaitingForPicklist( sal_True )
     ,bForbidReload( sal_False )
     ,bBasicInitialized( sal_False )
     ,bIsPrintJobCancelable( sal_True )
@@ -410,7 +414,7 @@ SfxObjectShell::~SfxObjectShell()
     // The removing of the temporary file must be done as the latest step in the document destruction
     if ( pImp->aTempName.Len() )
     {
-        String aTmp;
+        rtl::OUString aTmp;
         ::utl::LocalFileHelper::ConvertPhysicalNameToURL( pImp->aTempName, aTmp );
         ::utl::UCBContentHelper::Kill( aTmp );
     }
@@ -466,7 +470,7 @@ sal_Bool SfxObjectShell::Close()
             {
                 xCloseable->close( sal_True );
             }
-            catch( Exception& )
+            catch (const Exception&)
             {
                 pImp->bClosing = sal_False;
             }
@@ -657,7 +661,7 @@ sal_uInt16 SfxObjectShell::PrepareClose
             {
                 SfxBoolItem aWarnItem( SID_FAIL_ON_WARNING, bUI );
                 const SfxPoolItem* ppArgs[] = { &aWarnItem, 0 };
-                pPoolItem = pFrame->GetBindings().ExecuteSynchron( SID_SAVEDOC, ppArgs );
+                pPoolItem = pFrame->GetBindings().ExecuteSynchron( IsReadOnlyMedium() ? SID_SAVEASDOC : SID_SAVEDOC, ppArgs );
             }
 
             if ( !pPoolItem || pPoolItem->ISA(SfxVoidItem) || ( pPoolItem->ISA(SfxBoolItem) && !( (const SfxBoolItem*) pPoolItem )->GetValue() ) )
@@ -677,6 +681,7 @@ sal_uInt16 SfxObjectShell::PrepareClose
 }
 
 //--------------------------------------------------------------------
+#ifndef DISABLE_SCRIPTING
 namespace
 {
     static BasicManager* lcl_getBasicManagerForDocument( const SfxObjectShell& _rDocument )
@@ -710,15 +715,20 @@ namespace
         return pBasMgr;
     }
 }
+#endif
 
 //--------------------------------------------------------------------
 
 BasicManager* SfxObjectShell::GetBasicManager() const
 {
+#ifdef DISABLE_SCRIPTING
+    return NULL;
+#else
     BasicManager* pBasMgr = lcl_getBasicManagerForDocument( *this );
     if ( !pBasMgr )
         pBasMgr = SFX_APP()->GetBasicManager();
     return pBasMgr;
+#endif
 }
 
 //--------------------------------------------------------------------
@@ -732,6 +742,9 @@ void SfxObjectShell::SetHasNoBasic()
 
 sal_Bool SfxObjectShell::HasBasic() const
 {
+#ifdef DISABLE_SCRIPTING
+    return sal_False;
+#else
     if ( pImp->m_bNoBasicCapabilities )
         return sal_False;
 
@@ -739,9 +752,11 @@ sal_Bool SfxObjectShell::HasBasic() const
         const_cast< SfxObjectShell* >( this )->InitBasicManager_Impl();
 
     return pImp->pBasicManager->isValid();
+#endif
 }
 
 //--------------------------------------------------------------------
+#ifndef DISABLE_SCRIPTING
 namespace
 {
     const Reference< XLibraryContainer >&
@@ -762,7 +777,7 @@ namespace
                                         xContext, xStorageDoc )
                                 ,   UNO_QUERY_THROW );
             }
-            catch( const Exception& )
+            catch (const Exception&)
             {
                 DBG_UNHANDLED_EXCEPTION();
             }
@@ -770,11 +785,12 @@ namespace
         return _rxContainer;
     }
 }
-
+#endif
 //--------------------------------------------------------------------
 
 Reference< XLibraryContainer > SfxObjectShell::GetDialogContainer()
 {
+#ifndef DISABLE_SCRIPTING
     if ( !pImp->m_bNoBasicCapabilities )
         return lcl_getOrCreateLibraryContainer( false, pImp->xDialogLibraries, GetModel() );
 
@@ -783,6 +799,7 @@ Reference< XLibraryContainer > SfxObjectShell::GetDialogContainer()
         return pBasMgr->GetDialogLibraryContainer().get();
 
     OSL_FAIL( "SfxObjectShell::GetDialogContainer: falling back to the application - is this really expected here?" );
+#endif
     return SFX_APP()->GetDialogContainer();
 }
 
@@ -790,6 +807,7 @@ Reference< XLibraryContainer > SfxObjectShell::GetDialogContainer()
 
 Reference< XLibraryContainer > SfxObjectShell::GetBasicContainer()
 {
+#ifndef DISABLE_SCRIPTING
     if ( !pImp->m_bNoBasicCapabilities )
         return lcl_getOrCreateLibraryContainer( true, pImp->xBasicLibraries, GetModel() );
 
@@ -798,6 +816,7 @@ Reference< XLibraryContainer > SfxObjectShell::GetBasicContainer()
         return pBasMgr->GetScriptLibraryContainer().get();
 
     OSL_FAIL( "SfxObjectShell::GetBasicContainer: falling back to the application - is this really expected here?" );
+#endif
     return SFX_APP()->GetBasicContainer();
 }
 
@@ -805,7 +824,11 @@ Reference< XLibraryContainer > SfxObjectShell::GetBasicContainer()
 
 StarBASIC* SfxObjectShell::GetBasic() const
 {
+#ifdef DISABLE_SCRIPTING
+    return NULL;
+#else
     return GetBasicManager()->GetLib(0);
+#endif
 }
 
 //--------------------------------------------------------------------
@@ -847,10 +870,12 @@ void SfxObjectShell::InitBasicManager_Impl()
         does not take ownership but stores only the raw pointer. Owner of all
         Basic managers is the global BasicManagerRepository instance.
      */
+#ifndef DISABLE_SCRIPTING
     DBG_ASSERT( !pImp->bBasicInitialized && !pImp->pBasicManager->isValid(), "Lokaler BasicManager bereits vorhanden");
     pImp->pBasicManager->reset( BasicManagerRepository::getDocumentBasicManager( GetModel() ) );
     DBG_ASSERT( pImp->pBasicManager->isValid(), "SfxObjectShell::InitBasicManager_Impl: did not get a BasicManager!" );
     pImp->bBasicInitialized = sal_True;
+#endif
 }
 
 //--------------------------------------------------------------------
@@ -932,6 +957,7 @@ void SfxObjectShell::SetCurrentComponent( const Reference< XInterface >& _rxComp
     // In other words, it's still possible that we here do something which is not necessary,
     // but we should have filtered quite some unnecessary calls already.
 
+#ifndef DISABLE_SCRIPTING
     BasicManager* pAppMgr = SFX_APP()->GetBasicManager();
     s_xCurrentComponent = _rxComponent;
     if ( pAppMgr )
@@ -943,7 +969,7 @@ void SfxObjectShell::SetCurrentComponent( const Reference< XInterface >& _rxComp
         if ( _rxComponent.is() )
         {
             ::rtl::OString aVBAConstName = lclGetVBAGlobalConstName( _rxComponent );
-            if ( aVBAConstName.getLength() > 0 )
+            if ( !aVBAConstName.isEmpty() )
             {
                 pAppMgr->SetGlobalUNOConstant( aVBAConstName.getStr(), Any( _rxComponent ) );
                 s_aRegisteredVBAConstants[ _rxComponent.get() ] = aVBAConstName;
@@ -953,13 +979,14 @@ void SfxObjectShell::SetCurrentComponent( const Reference< XInterface >& _rxComp
         else if ( xOldCurrentComp.is() )
         {
             ::rtl::OString aVBAConstName = lclGetVBAGlobalConstName( xOldCurrentComp );
-            if ( aVBAConstName.getLength() > 0 )
+            if ( !aVBAConstName.isEmpty() )
             {
                 pAppMgr->SetGlobalUNOConstant( aVBAConstName.getStr(), Any( Reference< XInterface >() ) );
                 s_aRegisteredVBAConstants.erase( xOldCurrentComp.get() );
             }
         }
     }
+#endif
 }
 
 Reference< XInterface > SfxObjectShell::GetCurrentComponent()
@@ -994,44 +1021,48 @@ String SfxObjectShell::GetServiceNameFromFactory( const String& rFact )
 
     if ( aFact.EqualsAscii("swriter") )
     {
-        aServiceName = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.text.TextDocument"));
+        aServiceName = ::rtl::OUString("com.sun.star.text.TextDocument");
     }
     else if ( aFact.EqualsAscii("sweb") || aFact.EqualsAscii("swriter/web") )
     {
-        aServiceName = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.text.WebDocument"));
+        aServiceName = ::rtl::OUString("com.sun.star.text.WebDocument");
     }
     else if ( aFact.EqualsAscii("sglobal") || aFact.EqualsAscii("swriter/globaldocument") )
     {
-        aServiceName = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.text.GlobalDocument"));
+        aServiceName = ::rtl::OUString("com.sun.star.text.GlobalDocument");
     }
     else if ( aFact.EqualsAscii("scalc") )
     {
-        aServiceName = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.sheet.SpreadsheetDocument"));
+        aServiceName = ::rtl::OUString("com.sun.star.sheet.SpreadsheetDocument");
     }
     else if ( aFact.EqualsAscii("sdraw") )
     {
-        aServiceName = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.drawing.DrawingDocument"));
+        aServiceName = ::rtl::OUString("com.sun.star.drawing.DrawingDocument");
     }
     else if ( aFact.EqualsAscii("simpress") )
     {
-        aServiceName = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.presentation.PresentationDocument"));
+        aServiceName = ::rtl::OUString("com.sun.star.presentation.PresentationDocument");
     }
     else if ( aFact.EqualsAscii("schart") )
     {
-        aServiceName = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.chart.ChartDocument"));
+        aServiceName = ::rtl::OUString("com.sun.star.chart.ChartDocument");
     }
     else if ( aFact.EqualsAscii("smath") )
     {
-        aServiceName = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.formula.FormulaProperties"));
+        aServiceName = ::rtl::OUString("com.sun.star.formula.FormulaProperties");
     }
+#ifndef DISABLE_SCRIPTING
     else if ( aFact.EqualsAscii("sbasic") )
     {
-        aServiceName = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.script.BasicIDE"));
+        aServiceName = ::rtl::OUString("com.sun.star.script.BasicIDE");
     }
+#endif
+#ifndef DISABLE_DBCONNECTIVITY
     else if ( aFact.EqualsAscii("sdatabase") )
     {
-        aServiceName = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.sdb.OfficeDatabaseDocument"));
+        aServiceName = ::rtl::OUString("com.sun.star.sdb.OfficeDatabaseDocument");
     }
+#endif
 
     return aServiceName;
 }
@@ -1072,7 +1103,7 @@ Reference<lang::XComponent> SfxObjectShell::CreateAndLoadComponent( const SfxIte
     SFX_ITEMSET_ARG(&rSet, pFileNameItem, SfxStringItem, SID_FILE_NAME, sal_False);
     SFX_ITEMSET_ARG(&rSet, pTargetItem, SfxStringItem, SID_TARGETNAME, sal_False);
     ::rtl::OUString aURL;
-    ::rtl::OUString aTarget(RTL_CONSTASCII_USTRINGPARAM("_blank"));
+    ::rtl::OUString aTarget("_blank");
     if ( pFileNameItem )
         aURL = pFileNameItem->GetValue();
     if ( pTargetItem )
@@ -1085,15 +1116,16 @@ Reference<lang::XComponent> SfxObjectShell::CreateAndLoadComponent( const SfxIte
     }
     else
         xLoader = uno::Reference < frame::XComponentLoader >( comphelper::getProcessServiceFactory()->createInstance(
-            ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.frame.Desktop")) ), uno::UNO_QUERY );
+            ::rtl::OUString("com.sun.star.frame.Desktop") ), uno::UNO_QUERY );
 
     Reference <lang::XComponent> xComp;
     try
     {
         xComp = xLoader->loadComponentFromURL(aURL, aTarget, 0, aProps);
     }
-    catch( uno::Exception& )
-    {}
+    catch (const uno::Exception&)
+    {
+    }
 
     return xComp;
 }
