@@ -53,9 +53,9 @@
 // Problem der Implementation: Keine Hierarchischen commits. Daher nur
 // insgesamt transaktionsorientert oder direkt.
 
-StgDirEntry::StgDirEntry( const void* pBuffer, sal_uInt32 nBufferLen, sal_Bool * pbOk ) : StgAvlNode()
+StgDirEntry::StgDirEntry( const void* pFrom, sal_Bool * pbOk ) : StgAvlNode()
 {
-	*pbOk = aEntry.Load( pBuffer, nBufferLen );
+    *pbOk = aEntry.Load( pFrom );
 
     InitMembers();
 }
@@ -102,13 +102,8 @@ StgDirEntry::~StgDirEntry()
 
 short StgDirEntry::Compare( const StgAvlNode* p ) const
 {
-    short nResult = -1;
-    if ( p )
-    {
-        const StgDirEntry* pEntry = (const StgDirEntry*) p;
-        nResult = aEntry.Compare( pEntry->aEntry );
-    }
-    return nResult;
+    const StgDirEntry* pEntry = (const StgDirEntry*) p;
+    return aEntry.Compare( pEntry->aEntry );
 }
 
 // Enumerate the entry numbers.
@@ -268,9 +263,9 @@ void StgDirEntry::OpenStream( StgIo& rIo, sal_Bool bForceBig )
     sal_Int32 nThreshold = (sal_uInt16) rIo.aHdr.GetThreshold();
     delete pStgStrm;
     if( !bForceBig && aEntry.GetSize() < nThreshold )
-		pStgStrm = new StgSmallStrm( rIo, *this );
+        pStgStrm = new StgSmallStrm( rIo, this );
     else
-		pStgStrm = new StgDataStrm( rIo, *this );
+        pStgStrm = new StgDataStrm( rIo, this );
     if( bInvalid && aEntry.GetSize() )
     {
         // This entry has invalid data, so delete that data
@@ -328,10 +323,6 @@ sal_Bool StgDirEntry::SetSize( sal_Int32 nNewSize )
     }
     else
     {
-        OSL_ENSURE( pStgStrm, "The pointer may not be NULL!" );
-        if ( !pStgStrm )
-            return sal_False;
-
         sal_Bool bRes = sal_False;
         StgIo& rIo = pStgStrm->GetIo();
         sal_Int32 nThreshold = rIo.aHdr.GetThreshold();
@@ -411,10 +402,6 @@ sal_Int32 StgDirEntry::Seek( sal_Int32 nNew )
     }
     else
     {
-        OSL_ENSURE( pStgStrm, "The pointer may not be NULL!" );
-        if ( !pStgStrm )
-            return nPos;
-
         sal_Int32 nSize = aEntry.GetSize();
 
         if( nNew < 0 )
@@ -434,7 +421,6 @@ sal_Int32 StgDirEntry::Seek( sal_Int32 nNew )
         pStgStrm->Pos2Page( nNew );
         nNew = pStgStrm->GetPos();
     }
-
     return nPos = nNew;
 }
 
@@ -449,14 +435,7 @@ sal_Int32 StgDirEntry::Read( void* p, sal_Int32 nLen )
     else if( pCurStrm )
         nLen = pCurStrm->Read( p, nLen );
     else
-    {
-        OSL_ENSURE( pStgStrm, "The pointer may not be NULL!" );
-        if ( !pStgStrm )
-            return 0;
-
         nLen = pStgStrm->Read( p, nLen );
-    }
-
     nPos += nLen;
     return nLen;
 }
@@ -474,11 +453,6 @@ sal_Int32 StgDirEntry::Write( const void* p, sal_Int32 nLen )
     // Is this stream opened in transacted mode? Do we have to make a copy?
     if( !bDirect && !pTmpStrm && !Strm2Tmp() )
         return 0;
-
-    OSL_ENSURE( pStgStrm, "The pointer may not be NULL!" );
-    if ( !pStgStrm )
-        return 0;
-
     if( pTmpStrm )
     {
         nLen = pTmpStrm->Write( p, nLen );
@@ -635,10 +609,6 @@ sal_Bool StgDirEntry::Strm2Tmp()
             {
                 if( n )
                 {
-                    OSL_ENSURE( pStgStrm, "The pointer may not be NULL!" );
-                    if ( !pStgStrm )
-                        return sal_False;
-
                     sal_uInt8 aTempBytes[ 4096 ];
                     void* p = static_cast<void*>( aTempBytes );
                     pStgStrm->Pos2Page( 0L );
@@ -660,13 +630,9 @@ sal_Bool StgDirEntry::Strm2Tmp()
             else
                 n = 1;
         }
-
         if( n )
         {
-            OSL_ENSURE( pStgStrm, "The pointer may not be NULL!" );
-            if ( pStgStrm )
-                pStgStrm->GetIo().SetError( pTmpStrm->GetError() );
-
+            pStgStrm->GetIo().SetError( pTmpStrm->GetError() );
             delete pTmpStrm;
             pTmpStrm = NULL;
             return sal_False;
@@ -684,9 +650,6 @@ sal_Bool StgDirEntry::Tmp2Strm()
         pTmpStrm = pCurStrm, pCurStrm = NULL;
     if( pTmpStrm )
     {
-        OSL_ENSURE( pStgStrm, "The pointer may not be NULL!" );
-        if ( !pStgStrm )
-            return sal_False;
         sal_uLong n = pTmpStrm->GetSize();
         StgStrm* pNewStrm;
         StgIo& rIo = pStgStrm->GetIo();
@@ -806,7 +769,6 @@ StgDirStrm::StgDirStrm( StgIo& r )
         // the TOC pages can be removed.
         pEntry = (StgDirEntry*) this; // just for a bit pattern
         SetupEntry( 0, pRoot );
-        rIo.Revert( pEntry );
         pEntry = NULL;
     }
 }
@@ -824,7 +786,7 @@ void StgDirStrm::SetupEntry( sal_Int32 n, StgDirEntry* pUpper )
     if( p )
     {
         sal_Bool bOk(sal_False);
-        StgDirEntry* pCur = new StgDirEntry( p, STGENTRY_SIZE, &bOk );
+        StgDirEntry* pCur = new StgDirEntry( p, &bOk );
 
         if( !bOk )
         {
@@ -856,15 +818,15 @@ void StgDirStrm::SetupEntry( sal_Int32 n, StgDirEntry* pUpper )
         if( nLeaf != 0 && nLeft != 0 && nRight != 0 )
         {
             //fdo#41642 Do we need to check full chain upwards for loops ?
-            if (pUpper && pUpper->aEntry.GetLeaf(STG_CHILD) == nLeaf)
-            {
-                OSL_FAIL("Leaf node of upper StgDirEntry is same as current StgDirEntry's leaf node. Circular entry chain, discarding link");
-                delete pCur;
-                return;
-            }
-
             if (pUpper)
             {
+                if (pUpper->aEntry.GetLeaf(STG_CHILD) == nLeaf)
+                {
+                    OSL_FAIL("Leaf node of upper StgDirEntry is same as current StgDirEntry's leaf node. Circular entry chain, discarding link");
+                    delete pCur;
+                    return;
+                }
+
                 StgDirEntry *pUpperUpper = pUpper->pUp;
                 if (pUpperUpper && pUpperUpper->aEntry.GetLeaf(STG_CHILD) == nLeaf)
                 {
@@ -872,7 +834,7 @@ void StgDirStrm::SetupEntry( sal_Int32 n, StgDirEntry* pUpper )
                     delete pCur;
                     return;
                 }
-             }
+            }
 
             if( StgAvlNode::Insert
                 ( (StgAvlNode**) ( pUpper ? &pUpper->pDown : &pRoot ), pCur ) )
@@ -901,9 +863,6 @@ void StgDirStrm::SetupEntry( sal_Int32 n, StgDirEntry* pUpper )
 sal_Bool StgDirStrm::SetSize( sal_Int32 nBytes )
 {
     // Always allocate full pages
-    if ( nBytes < 0 )
-        nBytes = 0;
-
     nBytes = ( ( nBytes + nPageSize - 1 ) / nPageSize ) * nPageSize;
     return StgStrm::SetSize( nBytes );
 }
@@ -912,7 +871,7 @@ sal_Bool StgDirStrm::SetSize( sal_Int32 nBytes )
 
 sal_Bool StgDirStrm::Store()
 {
-    if( !pRoot || !pRoot->IsDirty() )
+    if( !pRoot->IsDirty() )
         return sal_True;
     if( !pRoot->StoreStreams( rIo ) )
         return sal_False;
