@@ -28,7 +28,6 @@
 
 
 #include "winmtf.hxx"
-#include <boost/scoped_array.hpp>
 #include <vcl/gdimtf.hxx>
 #include <svtools/wmf.hxx>
 #include <rtl/crc.h>
@@ -355,55 +354,28 @@ void WMFReader::ReadRecordParams( sal_uInt16 nFunc )
 
         case W_META_POLYPOLYGON:
         {
-            bool bRecordOk = true;
             sal_uInt16  nPoly = 0;
             Point*  pPtAry;
             // Number of polygons:
             *pWMF >> nPoly;
             // Number of points of each polygon. Determine total number of points
-            boost::scoped_array<sal_uInt16> xPolygonPointCounts(new sal_uInt16[nPoly]);
-            sal_uInt16* pnPoints = xPolygonPointCounts.get();
+            sal_uInt16* pnPoints = new sal_uInt16[ nPoly ];
             sal_uInt16 nPoints = 0;
             for(sal_uInt16 i = 0; i < nPoly; i++ )
             {
                 *pWMF >> pnPoints[i];
-
-                if (pnPoints[i] > SAL_MAX_UINT16 - nPoints)
-                {
-                    bRecordOk = false;
-                    break;
-                }
-
                 nPoints += pnPoints[i];
             }
-
-            SAL_WARN_IF(!bRecordOk, "svtools", "polypolygon record has more polygons that we can handle");
-
-            bRecordOk &= pWMF->good();
-
-            if (!bRecordOk)
-            {
-                pWMF->SetError( SVSTREAM_FILEFORMAT_ERROR );
-                break;
-            }
-
             // Polygon points are:
-            boost::scoped_array<Point> xPolygonPoints(new Point[nPoints]);
-            pPtAry = xPolygonPoints.get();
+            pPtAry  = new Point[nPoints];
             for (sal_uInt16 i = 0; i < nPoints; i++ )
                 pPtAry[ i ] = ReadPoint();
 
-            bRecordOk &= pWMF->good();
-
-            if (!bRecordOk)
-            {
-                pWMF->SetError( SVSTREAM_FILEFORMAT_ERROR );
-                break;
-            }
-
             // Produce PolyPolygon Actions
             PolyPolygon aPolyPoly( nPoly, pnPoints, pPtAry );
             pOut->DrawPolyPolygon( aPolyPoly );
+            delete[] pPtAry;
+            delete[] pnPoints;
         }
         break;
 
@@ -903,7 +875,7 @@ void WMFReader::ReadRecordParams( sal_uInt16 nFunc )
                             if ( nEscLen <= ( nRecSize * 2 ) )
                             {
 #ifdef OSL_BIGENDIAN
-                                sal_uInt32 nTmp = SWAPLONG( nEsc );
+                                sal_uInt32 nTmp = OSL_SWAPDWORD( nEsc );
                                 sal_uInt32 nCheckSum = rtl_crc32( 0, &nTmp, 4 );
 #else
                                 sal_uInt32 nCheckSum = rtl_crc32( 0, &nEsc, 4 );
@@ -936,15 +908,18 @@ void WMFReader::ReadRecordParams( sal_uInt16 nFunc )
                                                 SvMemoryStream aMemoryStream( nEscLen );
                                                 aMemoryStream.Write( pData, nEscLen );
                                                 aMemoryStream.Seek( STREAM_SEEK_TO_BEGIN );
-                                                aMemoryStream >> aPt.X()
-                                                              >> aPt.Y()
+                                                //#fdo39428 SvStream no longer supports operator>>(long&)
+                                                sal_Int32 nTmpX(0), nTmpY(0);
+                                                aMemoryStream >> nTmpX
+                                                              >> nTmpY
                                                               >> nStringLen;
+                                                 aPt.X() = nTmpX;
+                                                 aPt.Y() = nTmpY;
 
                                                 if ( ( static_cast< sal_uInt64 >( nStringLen ) * sizeof( sal_Unicode ) ) < ( nEscLen - aMemoryStream.Tell() ) )
                                                 {
-                                                    sal_Unicode* pBuf = aString.AllocBuffer( (xub_StrLen)nStringLen );
-                                                    for (sal_uInt32 i = 0; i < nStringLen; i++ )
-                                                        aMemoryStream >> pBuf[ i ];
+
+                                                    aString = read_uInt16s_ToOUString(aMemoryStream, nStringLen);
                                                     aMemoryStream >> nDXCount;
                                                     if ( ( static_cast< sal_uInt64 >( nDXCount ) * sizeof( sal_Int32 ) ) >= ( nEscLen - aMemoryStream.Tell() ) )
                                                         nDXCount = 0;
@@ -1124,8 +1099,13 @@ sal_Bool WMFReader::ReadHeader()
         return false;
     if (nMetaKey != 0x00090001)
     {
-        pWMF->SetError( SVSTREAM_FILEFORMAT_ERROR );
-        return false;
+        sal_uInt16 aNextWord(0);
+        *pWMF >> aNextWord;
+        if (nMetaKey != 0x10000 || aNextWord != 0x09)
+        {
+            pWMF->SetError( SVSTREAM_FILEFORMAT_ERROR );
+            return false;
+        }
     }
 
     pWMF->SeekRel( 2 ); // Version (von Windows)
@@ -1353,43 +1333,16 @@ sal_Bool WMFReader::GetPlaceableBound( Rectangle& rPlaceableBound, SvStream* pSt
 
                 case W_META_POLYPOLYGON:
                 {
-                    bool bRecordOk = true;
                     sal_uInt16 nPoly, nPoints = 0;
                     *pStm >> nPoly;
                     for(sal_uInt16 i = 0; i < nPoly; i++ )
                     {
-                        sal_uInt16 nP = 0;
+                        sal_uInt16 nP;
                         *pStm >> nP;
-                        if (nP > SAL_MAX_UINT16 - nPoints)
-                        {
-                            bRecordOk = false;
-                            break;
-                        }
-                        nPoints += nP;
+                        nPoints = nPoints + nP;
                     }
-
-                    SAL_WARN_IF(!bRecordOk, "svtools", "polypolygon record has more polygons that we can handle");
-
-                    bRecordOk &= pStm->good();
-
-                    if (!bRecordOk)
-                    {
-                        pStm->SetError( SVSTREAM_FILEFORMAT_ERROR );
-                        bRet = sal_False;
-                        break;
-                    }
-
                     for (sal_uInt16 i = 0; i < nPoints; i++ )
                         GetWinExtMax( ReadPoint(), rPlaceableBound, nMapMode );
-
-                    bRecordOk &= pStm->good();
-
-                    if (!bRecordOk)
-                    {
-                        pStm->SetError( SVSTREAM_FILEFORMAT_ERROR );
-                        bRet = sal_False;
-                        break;
-                    }
                 }
                 break;
 
