@@ -26,16 +26,12 @@
  *
  ************************************************************************/
 
-
-
 #include <hintids.hxx>
 
 #include <string.h>
 #include <float.h>
 #include <tools/datetime.hxx>
-#ifndef _SVSTDARR_HXX
 #include <svl/svarray.hxx>
-#endif
 #include <vcl/svapp.hxx>
 #include <unotools/charclass.hxx>
 #include <unotools/transliterationwrapper.hxx>
@@ -88,7 +84,7 @@ SV_IMPL_OP_PTRARR_SORT( _SetGetExpFlds, _SetGetExpFldPtr )
  */
 SwFieldType* SwDoc::InsertFldType(const SwFieldType &rFldTyp)
 {
-    sal_uInt16 nSize = pFldTypes->Count(),
+    sal_uInt16 nSize = pFldTypes->size(),
             nFldWhich = rFldTyp.Which();
 
     sal_uInt16 i = INIT_FLDTYPES;
@@ -153,7 +149,7 @@ SwFieldType* SwDoc::InsertFldType(const SwFieldType &rFldTyp)
         break;
     }
 
-    pFldTypes->Insert( pNew, nSize );
+    pFldTypes->insert( pFldTypes->begin() + nSize, pNew );
     SetModified();
 
     return (*pFldTypes)[ nSize ];
@@ -166,7 +162,7 @@ void SwDoc::InsDeletedFldType( SwFieldType& rFldTyp )
     // - If it's not present, it can be re-inserted.
     // - If the same type is found, the deleted one has to be renamed.
 
-    sal_uInt16 nSize = pFldTypes->Count(), nFldWhich = rFldTyp.Which();
+    sal_uInt16 nSize = pFldTypes->size(), nFldWhich = rFldTyp.Which();
     sal_uInt16 i = INIT_FLDTYPES;
 
     OSL_ENSURE( RES_SETEXPFLD == nFldWhich ||
@@ -202,7 +198,7 @@ void SwDoc::InsDeletedFldType( SwFieldType& rFldTyp )
         }
 
     // not found, so insert and delete flag
-    pFldTypes->Insert( &rFldTyp, nSize );
+    pFldTypes->insert( pFldTypes->begin() + nSize, &rFldTyp );
     switch( nFldWhich )
     {
     case RES_SETEXPFLD:
@@ -226,7 +222,7 @@ void SwDoc::RemoveFldType(sal_uInt16 nFld)
     /*
      * Dependent fields present -> ErrRaise
      */
-    sal_uInt16 nSize = pFldTypes->Count();
+    sal_uInt16 nSize = pFldTypes->size();
     if(nFld < nSize)
     {
         SwFieldType* pTmp = (*pFldTypes)[nFld];
@@ -259,7 +255,7 @@ void SwDoc::RemoveFldType(sal_uInt16 nFld)
             // delete field type
             delete pTmp;
         }
-        pFldTypes->Remove( nFld );
+        pFldTypes->erase( pFldTypes->begin() + nFld );
         SetModified();
     }
 }
@@ -278,7 +274,7 @@ SwFieldType* SwDoc::GetFldType( sal_uInt16 nResId, const String& rName,
                                    // #i51815#
          ) const
 {
-    sal_uInt16 nSize = pFldTypes->Count(), i = 0;
+    sal_uInt16 nSize = pFldTypes->size(), i = 0;
     const ::utl::TransliterationWrapper& rSCmp = GetAppCmpStrIgnore();
 
     switch( nResId )
@@ -327,15 +323,15 @@ SwFieldType* SwDoc::GetFldType( sal_uInt16 nResId, const String& rName,
  */
 void SwDoc::UpdateFlds( SfxPoolItem *pNewHt, bool bCloseDB )
 {
-    // Call modify() for every field type,
+    // Call Modify() for every field type,
     // dependent SwTxtFld get notified ...
 
-    for( sal_uInt16 i=0; i < pFldTypes->Count(); ++i)
+    for( sal_uInt16 i=0; i < pFldTypes->size(); ++i)
     {
         switch( (*pFldTypes)[i]->Which() )
         {
             // Update table fields second to last
-            // Update references at last
+            // Update references last
         case RES_GETREFFLD:
         case RES_TABLEFLD:
         case RES_DBFLD:
@@ -378,7 +374,7 @@ void SwDoc::UpdateFlds( SfxPoolItem *pNewHt, bool bCloseDB )
     if( bCloseDB )
         GetNewDBMgr()->CloseAll();
 
-    // Only evaluate on CompleteUpdate
+    // Only evaluate on full update
     SetModified();
 }
 
@@ -389,7 +385,7 @@ void SwDoc::UpdateUsrFlds()
 {
     SwCalc* pCalc = 0;
     const SwFieldType* pFldType;
-    for( sal_uInt16 i = INIT_FLDTYPES; i < pFldTypes->Count(); ++i )
+    for( sal_uInt16 i = INIT_FLDTYPES; i < pFldTypes->size(); ++i )
         if( RES_USERFLD == ( pFldType = (*pFldTypes)[i] )->Which() )
         {
             if( !pCalc )
@@ -410,7 +406,7 @@ void SwDoc::UpdateUsrFlds()
 void SwDoc::UpdateRefFlds( SfxPoolItem* pHt )
 {
     SwFieldType* pFldType;
-    for( sal_uInt16 i = 0; i < pFldTypes->Count(); ++i )
+    for( sal_uInt16 i = 0; i < pFldTypes->size(); ++i )
         if( RES_GETREFFLD == ( pFldType = (*pFldTypes)[i] )->Which() )
             pFldType->ModifyNotification( 0, pHt );
 }
@@ -419,7 +415,7 @@ void SwDoc::UpdateRefFlds( SfxPoolItem* pHt )
 //optimization currently only available when no fields exist.
 bool SwDoc::containsUpdatableFields()
 {
-    for (sal_uInt16 i = 0; i < pFldTypes->Count(); ++i)
+    for (sal_uInt16 i = 0; i < pFldTypes->size(); ++i)
     {
         SwFieldType* pFldType = (*pFldTypes)[i];
         SwIterator<SwFmtFld,SwFieldType> aIter(*pFldType);
@@ -436,7 +432,7 @@ void SwDoc::UpdateTblFlds( SfxPoolItem* pHt )
 
     SwFieldType* pFldType(0);
 
-    for (sal_uInt16 i = 0; i < pFldTypes->Count(); ++i)
+    for (sal_uInt16 i = 0; i < pFldTypes->size(); ++i)
     {
         if( RES_TABLEFLD == ( pFldType = (*pFldTypes)[i] )->Which() )
         {
@@ -538,7 +534,7 @@ void SwDoc::UpdateTblFlds( SfxPoolItem* pHt )
                     (pFld = (SwTblField*)pFmtFld->GetFld())->GetSubType() ))
                     continue;
 
-                // needs to be recalculated (and is no textual note)
+                // needs to be recalculated
                 if( !pFld->IsValid() )
                 {
                     // table where this field is located
@@ -557,7 +553,7 @@ void SwDoc::UpdateTblFlds( SfxPoolItem* pHt )
                     if( !pCalc )
                         pCalc = new SwCalc( *this );
 
-                    // get the values of all SetExpresion fields, that are valid
+                    // get the values of all SetExpression fields that are valid
                     // until the table
                     SwFrm* pFrm = 0;
                     if( pTblNd->GetIndex() < GetNodes().GetEndOfExtras().GetIndex() )
@@ -622,7 +618,7 @@ void SwDoc::UpdateTblFlds( SfxPoolItem* pHt )
                     if( !pCalc )
                         pCalc = new SwCalc( *this );
 
-                    // get the values of all SetExpresion fields, that are valid
+                    // get the values of all SetExpression fields that are valid
                     // until the table
                     SwFrm* pFrm = 0;
                     if( pTblNd->GetIndex() < GetNodes().GetEndOfExtras().GetIndex() )
@@ -706,7 +702,7 @@ void SwDoc::UpdatePageFlds( SfxPoolItem* pMsgHnt )
 // ---- Remove all unreferenced field types of a document --
 void SwDoc::GCFieldTypes()
 {
-    for( sal_uInt16 n = pFldTypes->Count(); n > INIT_FLDTYPES; )
+    for( sal_uInt16 n = pFldTypes->size(); n > INIT_FLDTYPES; )
         if( !(*pFldTypes)[ --n ]->GetDepends() )
             RemoveFldType( n );
 }
@@ -935,11 +931,11 @@ sal_Bool _SetGetExpFld::operator<( const _SetGetExpFld& rFld ) const
         }
     }
 
-    // if it is the same section, then the field is in the same Node
+    // same Section: is the field in the same Node?
     if( pFirst != pNext )
         return pFirst->GetIndex() < pNext->GetIndex();
 
-    // same Node in the Section, then Position in the Node
+    // same Node in the Section, check Position in the Node
     return GetCntPosFromCntnt() < rFld.GetCntPosFromCntnt();
 }
 
@@ -1259,14 +1255,14 @@ void SwDoc::UpdateExpFlds( SwTxtFld* pUpdtFld, bool bUpdRefFlds )
 
     // Hash table for all string replacements is filled on-the-fly.
     // Try to fabricate an uneven number.
-    sal_uInt16 nStrFmtCnt = (( pFldTypes->Count() / 7 ) + 1 ) * 7;
+    sal_uInt16 nStrFmtCnt = (( pFldTypes->size() / 7 ) + 1 ) * 7;
     SwHash** pHashStrTbl = new SwHash*[ nStrFmtCnt ];
     memset( pHashStrTbl, 0, sizeof( _HashStr* ) * nStrFmtCnt );
 
     {
         const SwFieldType* pFldType;
         // process seperately:
-        for( n = pFldTypes->Count(); n; )
+        for( n = pFldTypes->size(); n; )
             switch( ( pFldType = (*pFldTypes)[ --n ] )->Which() )
             {
             case RES_USERFLD:
@@ -1300,18 +1296,8 @@ void SwDoc::UpdateExpFlds( SwTxtFld* pUpdtFld, bool bUpdRefFlds )
     SwNewDBMgr* pMgr = GetNewDBMgr();
     pMgr->CloseAll(sal_False);
 
-    // Make sure we don't hide all sections, which would lead to a crash. First, count how many of them do we have.
-    int nShownSections = 0;
-    const _SetGetExpFldPtr* ppSortLst = pUpdtFlds->GetSortLst()->GetData();
-    for( n = pUpdtFlds->GetSortLst()->Count(); n; --n, ++ppSortLst )
-    {
-        SwSection* pSect = (SwSection*)(*ppSortLst)->GetSection();
-        if ( pSect && !pSect->IsCondHidden())
-            nShownSections++;
-    }
-
     String aNew;
-    ppSortLst = pUpdtFlds->GetSortLst()->GetData();
+    const _SetGetExpFldPtr* ppSortLst = pUpdtFlds->GetSortLst()->GetData();
     for( n = pUpdtFlds->GetSortLst()->Count(); n; --n, ++ppSortLst )
     {
         SwSection* pSect = (SwSection*)(*ppSortLst)->GetSection();
@@ -1321,23 +1307,7 @@ void SwDoc::UpdateExpFlds( SwTxtFld* pUpdtFld, bool bUpdRefFlds )
             SwSbxValue aValue = aCalc.Calculate(
                                         pSect->GetCondition() );
             if(!aValue.IsVoidValue())
-            {
-                // Do we want to hide this one?
-                bool bHide = aValue.GetBool();
-                if (bHide && !pSect->IsCondHidden())
-                {
-                    // This section will be hidden, but it wasn't before
-                    if (nShownSections == 1)
-                    {
-                        // This would be the last section, so set its condition to false, and avoid hiding it.
-                        rtl::OUString aCond(RTL_CONSTASCII_USTRINGPARAM("0"));
-                        pSect->SetCondition(aCond);
-                        bHide = false;
-                    }
-                    nShownSections--;
-                }
-                pSect->SetCondHidden( bHide );
-            }
+                pSect->SetCondHidden( aValue.GetBool() );
             continue;
         }
 
@@ -1568,7 +1538,7 @@ void SwDoc::UpdateDBNumFlds( SwDBNameInfField& rDBFld, SwCalc& rCalc )
     else
         ((SwDBNumSetField&)rDBFld).SetCondValid( bPar1 );
 
-    if( rDBFld.GetRealDBData().sDataSource.getLength() )
+    if( !rDBFld.GetRealDBData().sDataSource.isEmpty() )
     {
         // Edit a certain database
         if( RES_DBNEXTSETFLD == nFldType )
@@ -1591,50 +1561,49 @@ void SwDoc::UpdateDBNumFlds( SwDBNameInfField& rDBFld, SwCalc& rCalc )
 void SwDoc::_InitFieldTypes()       // is being called by the CTOR
 {
     // Field types
-    sal_uInt16 nFldType = 0;
-    pFldTypes->Insert( new SwDateTimeFieldType(this), nFldType++ );
-    pFldTypes->Insert( new SwChapterFieldType, nFldType++ );
-    pFldTypes->Insert( new SwPageNumberFieldType, nFldType++ );
-    pFldTypes->Insert( new SwAuthorFieldType, nFldType++ );
-    pFldTypes->Insert( new SwFileNameFieldType(this), nFldType++ );
-    pFldTypes->Insert( new SwDBNameFieldType(this), nFldType++);
-    pFldTypes->Insert( new SwGetExpFieldType(this), nFldType++ );
-    pFldTypes->Insert( new SwGetRefFieldType( this ), nFldType++ );
-    pFldTypes->Insert( new SwHiddenTxtFieldType, nFldType++ );
-    pFldTypes->Insert( new SwPostItFieldType(this), nFldType++ );
-    pFldTypes->Insert( new SwDocStatFieldType(this), nFldType++);
-    pFldTypes->Insert( new SwDocInfoFieldType(this), nFldType++);
-    pFldTypes->Insert( new SwInputFieldType( this ), nFldType++ );
-    pFldTypes->Insert( new SwTblFieldType( this ), nFldType++);
-    pFldTypes->Insert( new SwMacroFieldType(this), nFldType++ );
-    pFldTypes->Insert( new SwHiddenParaFieldType, nFldType++ );
-    pFldTypes->Insert( new SwDBNextSetFieldType, nFldType++ );
-    pFldTypes->Insert( new SwDBNumSetFieldType, nFldType++ );
-    pFldTypes->Insert( new SwDBSetNumberFieldType, nFldType++ );
-    pFldTypes->Insert( new SwTemplNameFieldType(this), nFldType++);
-    pFldTypes->Insert( new SwTemplNameFieldType(this),nFldType++);
-    pFldTypes->Insert( new SwExtUserFieldType, nFldType++ );
-    pFldTypes->Insert( new SwRefPageSetFieldType, nFldType++ );
-    pFldTypes->Insert( new SwRefPageGetFieldType( this ), nFldType++ );
-    pFldTypes->Insert( new SwJumpEditFieldType( this ), nFldType++ );
-    pFldTypes->Insert( new SwScriptFieldType( this ), nFldType++ );
-    pFldTypes->Insert( new SwCombinedCharFieldType, nFldType++ );
-    pFldTypes->Insert( new SwDropDownFieldType, nFldType++ );
+    pFldTypes->push_back( new SwDateTimeFieldType(this) );
+    pFldTypes->push_back( new SwChapterFieldType );
+    pFldTypes->push_back( new SwPageNumberFieldType );
+    pFldTypes->push_back( new SwAuthorFieldType );
+    pFldTypes->push_back( new SwFileNameFieldType(this) );
+    pFldTypes->push_back( new SwDBNameFieldType(this) );
+    pFldTypes->push_back( new SwGetExpFieldType(this) );
+    pFldTypes->push_back( new SwGetRefFieldType( this ) );
+    pFldTypes->push_back( new SwHiddenTxtFieldType );
+    pFldTypes->push_back( new SwPostItFieldType(this) );
+    pFldTypes->push_back( new SwDocStatFieldType(this) );
+    pFldTypes->push_back( new SwDocInfoFieldType(this) );
+    pFldTypes->push_back( new SwInputFieldType( this ) );
+    pFldTypes->push_back( new SwTblFieldType( this ) );
+    pFldTypes->push_back( new SwMacroFieldType(this) );
+    pFldTypes->push_back( new SwHiddenParaFieldType );
+    pFldTypes->push_back( new SwDBNextSetFieldType );
+    pFldTypes->push_back( new SwDBNumSetFieldType );
+    pFldTypes->push_back( new SwDBSetNumberFieldType );
+    pFldTypes->push_back( new SwTemplNameFieldType(this) );
+    pFldTypes->push_back( new SwTemplNameFieldType(this) );
+    pFldTypes->push_back( new SwExtUserFieldType );
+    pFldTypes->push_back( new SwRefPageSetFieldType );
+    pFldTypes->push_back( new SwRefPageGetFieldType( this ) );
+    pFldTypes->push_back( new SwJumpEditFieldType( this ) );
+    pFldTypes->push_back( new SwScriptFieldType( this ) );
+    pFldTypes->push_back( new SwCombinedCharFieldType );
+    pFldTypes->push_back( new SwDropDownFieldType );
 
     // Types have to be at the end!
     // We expect this in the InsertFldType!
     // MIB 14.04.95: In Sw3StringPool::Setup (sw3imp.cxx) and
     //               lcl_sw3io_InSetExpField (sw3field.cxx) now also
-    pFldTypes->Insert( new SwSetExpFieldType(this,
-                SW_RESSTR(STR_POOLCOLL_LABEL_ABB), nsSwGetSetExpType::GSE_SEQ), nFldType++);
-    pFldTypes->Insert( new SwSetExpFieldType(this,
-                SW_RESSTR(STR_POOLCOLL_LABEL_TABLE), nsSwGetSetExpType::GSE_SEQ),nFldType++);
-    pFldTypes->Insert( new SwSetExpFieldType(this,
-                SW_RESSTR(STR_POOLCOLL_LABEL_FRAME), nsSwGetSetExpType::GSE_SEQ),nFldType++);
-    pFldTypes->Insert( new SwSetExpFieldType(this,
-                SW_RESSTR(STR_POOLCOLL_LABEL_DRAWING), nsSwGetSetExpType::GSE_SEQ),nFldType++);
+    pFldTypes->push_back( new SwSetExpFieldType(this,
+                SW_RESSTR(STR_POOLCOLL_LABEL_ABB), nsSwGetSetExpType::GSE_SEQ) );
+    pFldTypes->push_back( new SwSetExpFieldType(this,
+                SW_RESSTR(STR_POOLCOLL_LABEL_TABLE), nsSwGetSetExpType::GSE_SEQ) );
+    pFldTypes->push_back( new SwSetExpFieldType(this,
+                SW_RESSTR(STR_POOLCOLL_LABEL_FRAME), nsSwGetSetExpType::GSE_SEQ) );
+    pFldTypes->push_back( new SwSetExpFieldType(this,
+                SW_RESSTR(STR_POOLCOLL_LABEL_DRAWING), nsSwGetSetExpType::GSE_SEQ) );
 
-    OSL_ENSURE( nFldType == INIT_FLDTYPES, "Bad initsize: SwFldTypes" );
+    OSL_ENSURE( pFldTypes->size() == INIT_FLDTYPES, "Bad initsize: SwFldTypes" );
 }
 
 void SwDoc::InsDelFldInFldLst( bool bIns, const SwTxtFld& rFld )
@@ -1650,10 +1619,10 @@ SwDBData SwDoc::GetDBData()
 
 const SwDBData& SwDoc::GetDBDesc()
 {
-    if(!aDBData.sDataSource.getLength())
+    if(aDBData.sDataSource.isEmpty())
     {
-        const sal_uInt16 nSize = pFldTypes->Count();
-        for(sal_uInt16 i = 0; i < nSize && !aDBData.sDataSource.getLength(); ++i)
+        const sal_uInt16 nSize = pFldTypes->size();
+        for(sal_uInt16 i = 0; i < nSize && aDBData.sDataSource.isEmpty(); ++i)
         {
             SwFieldType& rFldType = *((*pFldTypes)[i]);
             sal_uInt16 nWhich = rFldType.Which();
@@ -1686,7 +1655,7 @@ const SwDBData& SwDoc::GetDBDesc()
             }
         }
     }
-    if(!aDBData.sDataSource.getLength())
+    if(aDBData.sDataSource.isEmpty())
         aDBData = GetNewDBMgr()->GetAddressDBName();
     return aDBData;
 }
@@ -1709,11 +1678,11 @@ String lcl_DBDataToString(const SwDBData& rData)
     return sRet;
 }
 
-void SwDoc::GetAllUsedDB( SvStringsDtor& rDBNameList,
-                            const SvStringsDtor* pAllDBNames )
+void SwDoc::GetAllUsedDB( std::vector<String>& rDBNameList,
+                          const std::vector<String>* pAllDBNames )
 {
-    SvStringsDtor aUsedDBNames;
-    SvStringsDtor aAllDBNames;
+    std::vector<String> aUsedDBNames;
+    std::vector<String> aAllDBNames;
 
     if( !pAllDBNames )
     {
@@ -1731,7 +1700,7 @@ void SwDoc::GetAllUsedDB( SvStringsDtor& rDBNameList,
             String aCond( pSect->GetCondition() );
             AddUsedDBToList( rDBNameList, FindUsedDBs( *pAllDBNames,
                                                 aCond, aUsedDBNames ) );
-            aUsedDBNames.DeleteAndDestroy( 0, aUsedDBNames.Count() );
+            aUsedDBNames.clear();
         }
     }
 
@@ -1771,7 +1740,7 @@ void SwDoc::GetAllUsedDB( SvStringsDtor& rDBNameList,
             case RES_HIDDENPARAFLD:
                 AddUsedDBToList(rDBNameList, FindUsedDBs( *pAllDBNames,
                                             pFld->GetPar1(), aUsedDBNames ));
-                aUsedDBNames.DeleteAndDestroy( 0, aUsedDBNames.Count() );
+                aUsedDBNames.clear();
                 break;
 
             case RES_SETEXPFLD:
@@ -1779,81 +1748,80 @@ void SwDoc::GetAllUsedDB( SvStringsDtor& rDBNameList,
             case RES_TABLEFLD:
                 AddUsedDBToList(rDBNameList, FindUsedDBs( *pAllDBNames,
                                         pFld->GetFormula(), aUsedDBNames ));
-                aUsedDBNames.DeleteAndDestroy( 0, aUsedDBNames.Count() );
+                aUsedDBNames.clear();
                 break;
         }
     }
 }
 
-void SwDoc::GetAllDBNames( SvStringsDtor& rAllDBNames )
+void SwDoc::GetAllDBNames( std::vector<String>& rAllDBNames )
 {
     SwNewDBMgr* pMgr = GetNewDBMgr();
 
     const SwDSParamArr& rArr = pMgr->GetDSParamArray();
-    for(sal_uInt16 i = 0; i < rArr.Count(); i++)
+    for(sal_uInt16 i = 0; i < rArr.size(); i++)
     {
-        SwDSParam* pParam = rArr[i];
+        const SwDSParam* pParam = &rArr[i];
         String* pStr = new String( pParam->sDataSource );
         (*pStr) += DB_DELIM;
         (*pStr) += (String)pParam->sCommand;
-        rAllDBNames.Insert( pStr, rAllDBNames.Count() );
+        rAllDBNames.push_back(*pStr);
     }
 }
 
-SvStringsDtor& SwDoc::FindUsedDBs( const SvStringsDtor& rAllDBNames,
+std::vector<String>& SwDoc::FindUsedDBs( const std::vector<String>& rAllDBNames,
                                     const String& rFormel,
-                                    SvStringsDtor& rUsedDBNames )
+                                   std::vector<String>& rUsedDBNames )
 {
     const CharClass& rCC = GetAppCharClass();
     String  sFormel( rFormel);
 #ifndef UNX
-    rCC.toUpper( sFormel );
+    sFormel = rCC.uppercase( sFormel );
 #endif
 
     xub_StrLen nPos;
-    for (sal_uInt16 i = 0; i < rAllDBNames.Count(); ++i )
+    for (sal_uInt16 i = 0; i < rAllDBNames.size(); ++i )
     {
-        const String* pStr = rAllDBNames.GetObject(i);
+        String pStr(rAllDBNames[i]);
 
-        if( STRING_NOTFOUND != (nPos = sFormel.Search( *pStr )) &&
-            sFormel.GetChar( nPos + pStr->Len() ) == '.' &&
+        if( STRING_NOTFOUND != (nPos = sFormel.Search( pStr )) &&
+            sFormel.GetChar( nPos + pStr.Len() ) == '.' &&
             (!nPos || !rCC.isLetterNumeric( sFormel, nPos - 1 )))
         {
             // Look up table name
             xub_StrLen nEndPos;
-            nPos += pStr->Len() + 1;
+            nPos += pStr.Len() + 1;
             if( STRING_NOTFOUND != (nEndPos = sFormel.Search('.', nPos)) )
             {
-                String* pDBNm = new String( *pStr );
-                pDBNm->Append( DB_DELIM );
-                pDBNm->Append( sFormel.Copy( nPos, nEndPos - nPos ));
-                rUsedDBNames.Insert( pDBNm, rUsedDBNames.Count() );
+                pStr.Append( DB_DELIM );
+                pStr.Append( sFormel.Copy( nPos, nEndPos - nPos ));
+                rUsedDBNames.push_back(pStr);
             }
         }
     }
     return rUsedDBNames;
 }
 
-void SwDoc::AddUsedDBToList( SvStringsDtor& rDBNameList,
-                             const SvStringsDtor& rUsedDBNames )
+void SwDoc::AddUsedDBToList( std::vector<String>& rDBNameList,
+                             const std::vector<String>& rUsedDBNames )
 {
-    for (sal_uInt16 i = 0; i < rUsedDBNames.Count(); i++)
-        AddUsedDBToList( rDBNameList, *rUsedDBNames.GetObject(i) );
+    for (sal_uInt16 i = 0; i < rUsedDBNames.size(); ++i)
+        AddUsedDBToList( rDBNameList, rUsedDBNames[i] );
 }
 
-void SwDoc::AddUsedDBToList( SvStringsDtor& rDBNameList, const String& rDBName)
+void SwDoc::AddUsedDBToList( std::vector<String>& rDBNameList, const String& rDBName)
 {
     if( !rDBName.Len() )
         return;
 
 #ifdef UNX
-    for( sal_uInt16 i = 0; i < rDBNameList.Count(); ++i )
-        if( rDBName == rDBNameList.GetObject(i)->GetToken(0) )
+    for( sal_uInt16 i = 0; i < rDBNameList.size(); ++i )
+        if( rDBName == rDBNameList[i].GetToken(0) )
             return;
 #else
     const ::utl::TransliterationWrapper& rSCmp = GetAppCmpStrIgnore();
-    for( sal_uInt16 i = 0; i < rDBNameList.Count(); ++i )
-        if( rSCmp.isEqual( rDBName, rDBNameList.GetObject(i)->GetToken(0) ) )
+    for( sal_uInt16 i = 0; i < rDBNameList.size(); ++i )
+        if( rSCmp.isEqual( rDBName, rDBNameList[i].GetToken(0) ) )
             return;
 #endif
 
@@ -1862,11 +1830,10 @@ void SwDoc::AddUsedDBToList( SvStringsDtor& rDBNameList, const String& rDBName)
     aData.sCommand = rDBName.GetToken(1, DB_DELIM);
     aData.nCommandType = -1;
     GetNewDBMgr()->CreateDSData(aData);
-    String* pNew = new String( rDBName );
-    rDBNameList.Insert( pNew, rDBNameList.Count() );
+    rDBNameList.push_back(rDBName);
 }
 
-void SwDoc::ChangeDBFields( const SvStringsDtor& rOldNames,
+void SwDoc::ChangeDBFields( const std::vector<String>& rOldNames,
                             const String& rNewName )
 {
     SwDBData aNewDBData;
@@ -1968,7 +1935,7 @@ void SwDoc::ChangeDBFields( const SvStringsDtor& rOldNames,
     SetModified();
 }
 
-void SwDoc::ReplaceUsedDBs( const SvStringsDtor& rUsedDBNames,
+void SwDoc::ReplaceUsedDBs( const std::vector<String>& rUsedDBNames,
                             const String& rNewName, String& rFormel )
 {
     const CharClass& rCC = GetAppCharClass();
@@ -1979,10 +1946,9 @@ void SwDoc::ReplaceUsedDBs( const SvStringsDtor& rUsedDBNames,
     sNewName = sNewName.GetToken(0, DB_DELIM);
     String sUpperNewNm( sNewName );
 
-
-    for( sal_uInt16 i = 0; i < rUsedDBNames.Count(); ++i )
+    for( sal_uInt16 i = 0; i < rUsedDBNames.size(); ++i )
     {
-        String  sDBName( *rUsedDBNames.GetObject( i ) );
+        String  sDBName( rUsedDBNames[i] );
 
         sDBName.SearchAndReplace( DB_DELIM, '.');
         //cut off command type
@@ -2009,16 +1975,16 @@ void SwDoc::ReplaceUsedDBs( const SvStringsDtor& rUsedDBNames,
     }
 }
 
-sal_Bool SwDoc::IsNameInArray( const SvStringsDtor& rArr, const String& rName )
+sal_Bool SwDoc::IsNameInArray( const std::vector<String>& rArr, const String& rName )
 {
 #ifdef UNX
-    for( sal_uInt16 i = 0; i < rArr.Count(); ++i )
-        if( rName == *rArr[ i ] )
+    for( sal_uInt16 i = 0; i < rArr.size(); ++i )
+        if( rName == rArr[ i ] )
             return sal_True;
 #else
     const ::utl::TransliterationWrapper& rSCmp = GetAppCmpStrIgnore();
-    for( sal_uInt16 i = 0; i < rArr.Count(); ++i )
-        if( rSCmp.isEqual( rName, *rArr[ i] ))
+    for( sal_uInt16 i = 0; i < rArr.size(); ++i )
+        if( rSCmp.isEqual( rName, rArr[ i] ))
             return sal_True;
 #endif
     return sal_False;
@@ -2176,7 +2142,7 @@ bool SwDoc::SetFieldsDirty( bool b, const SwNode* pChk, sal_uLong nLen )
 
 void SwDoc::ChangeAuthorityData( const SwAuthEntry* pNewData )
 {
-    const sal_uInt16 nSize = pFldTypes->Count();
+    const sal_uInt16 nSize = pFldTypes->size();
 
     for( sal_uInt16 i = INIT_FLDTYPES; i < nSize; ++i )
     {
@@ -2215,7 +2181,7 @@ void SwDocUpdtFld::InsDelFldInFldLst( sal_Bool bIns, const SwTxtFld& rFld )
     {
         if( !bIns )             // if list is present and deleted
             return;             // don't do a thing
-        pFldSortLst = new _SetGetExpFlds( 64, 16 );
+        pFldSortLst = new _SetGetExpFlds( 64 );
     }
 
     if( bIns )      // insert anew:
@@ -2242,7 +2208,7 @@ void SwDocUpdtFld::_MakeFldList( SwDoc& rDoc, int eGetMode )
 {
     // new version: walk all fields of the attribute pool
     delete pFldSortLst;
-    pFldSortLst = new _SetGetExpFlds( 64, 16 );
+    pFldSortLst = new _SetGetExpFlds( 64 );
 
     /// consider and unhide sections
     ///     with hide condition, only in mode GETFLD_ALL (<eGetMode == GETFLD_ALL>)
@@ -2257,8 +2223,8 @@ void SwDocUpdtFld::_MakeFldList( SwDoc& rDoc, int eGetMode )
     ///         have to be known in order to insert the hide condition as a new
     ///         expression field into the sorted field list (<pFldSortLst>).
     if ( eGetMode == GETFLD_ALL )
-    // Collect the ranges first. Supply all with frames, which are hidden by condition,
-    // so that the contained fields are not sorted.
+    // Collect the sections first. Supply sections that are hidden by condition
+    // with frames so that the contained fields are sorted properly.
     {
         // In order for the frames to be created the right way, they have to be expanded
         // from top to bottom
@@ -2304,14 +2270,11 @@ void SwDocUpdtFld::_MakeFldList( SwDoc& rDoc, int eGetMode )
         }
     }
 
-    String sTrue( String::CreateFromAscii(
-                                    RTL_CONSTASCII_STRINGPARAM( "TRUE" ))),
-           sFalse( String::CreateFromAscii(
-                                       RTL_CONSTASCII_STRINGPARAM( "FALSE" )));
+    rtl::OUString sTrue("TRUE"), sFalse("FALSE");
 
     sal_Bool bIsDBMgr = 0 != rDoc.GetNewDBMgr();
     sal_uInt16 nWhich, n;
-    const String* pFormel = 0;
+    const rtl::OUString* pFormel = 0;
     const SfxPoolItem* pItem;
     sal_uInt32 nMaxItems = rDoc.GetAttrPool().GetItemCount2( RES_TXTATR_FIELD );
     for( n = 0; n < nMaxItems; ++n )
@@ -2350,9 +2313,9 @@ void SwDocUpdtFld::_MakeFldList( SwDoc& rDoc, int eGetMode )
                 if( GETFLD_ALL == eGetMode )
                 {
                     pFormel = &pFld->GetPar1();
-                    if( !pFormel->Len() || pFormel->Equals( sFalse ))
+                    if (pFormel->isEmpty() || pFormel->equals(sFalse))
                         ((SwHiddenParaField*)pFld)->SetHidden( sal_False );
-                    else if( pFormel->Equals( sTrue ))
+                    else if (pFormel->equals(sTrue))
                         ((SwHiddenParaField*)pFld)->SetHidden( sal_True );
                     else
                         break;
@@ -2367,9 +2330,9 @@ void SwDocUpdtFld::_MakeFldList( SwDoc& rDoc, int eGetMode )
                 if( GETFLD_ALL == eGetMode )
                 {
                     pFormel = &pFld->GetPar1();
-                    if( !pFormel->Len() || pFormel->Equals( sFalse ))
+                    if (pFormel->isEmpty() || pFormel->equals(sFalse))
                         ((SwHiddenTxtField*)pFld)->SetValue( sal_True );
-                    else if( pFormel->Equals( sTrue ))
+                    else if (pFormel->equals(sTrue))
                         ((SwHiddenTxtField*)pFld)->SetValue( sal_False );
                     else
                         break;
@@ -2411,7 +2374,7 @@ void SwDocUpdtFld::_MakeFldList( SwDoc& rDoc, int eGetMode )
             break;
         }
 
-        if( pFormel && pFormel->Len() )
+        if (pFormel && !pFormel->isEmpty())
         {
             GetBodyNode( *pTxtFld, nWhich );
             pFormel = 0;
@@ -2530,7 +2493,7 @@ void SwDocUpdtFld::InsertFldType( const SwFieldType& rType )
     {
         SetFieldsDirty( sal_True );
         // look up and remove from the hash table
-        GetAppCharClass().toLower( sFldName );
+        sFldName = GetAppCharClass().lowercase( sFldName );
         sal_uInt16 n;
 
         SwHash* pFnd = Find( sFldName, GetFldTypeTable(), TBLSZ, &n );
@@ -2561,7 +2524,7 @@ void SwDocUpdtFld::RemoveFldType( const SwFieldType& rType )
     {
         SetFieldsDirty( sal_True );
         // look up and remove from the hash table
-        GetAppCharClass().toLower( sFldName );
+        sFldName = GetAppCharClass().lowercase( sFldName );
         sal_uInt16 n;
 
         SwHash* pFnd = Find( sFldName, GetFldTypeTable(), TBLSZ, &n );
@@ -2686,7 +2649,8 @@ bool SwDoc::UpdateFld(SwTxtFld * pDstTxtFld, SwField & rSrcFld,
             pDstFmtFld->ModifyNotification( 0, pMsgHnt );
         }
 
-        // The fields we can calculate here are being triggered for an update here explicitily.
+        // The fields we can calculate here are being triggered for an update
+        // here explicitly.
         if( nFldWhich == RES_USERFLD )
             UpdateUsrFlds();
     }
