@@ -173,6 +173,12 @@ sal_uInt16 SwNumRule::GetNumIndent( sal_uInt8 nLvl )
     return aDefNumIndents[ nLvl ];
 }
 
+sal_uInt16 SwNumRule::GetBullIndent( sal_uInt8 nLvl )
+{
+    OSL_ENSURE( MAXLEVEL > nLvl, "NumLevel is out of range" );
+    return aDefNumIndents[ nLvl ];
+}
+
 static void lcl_SetRuleChgd( SwTxtNode& rNd, sal_uInt8 nLevel )
 {
     if( rNd.GetActualListLevel() == nLevel )
@@ -290,8 +296,8 @@ void SwNumFmt::SetCharFmt( SwCharFmt* pChFmt)
 
 void SwNumFmt::Modify( const SfxPoolItem* pOld, const SfxPoolItem* pNew )
 {
-    // dann suche mal in dem Doc nach dem NumRules-Object, in dem dieses
-    // NumFormat gesetzt ist. Das Format muss es nicht geben!
+    // Look for the NumRules object in the Doc where this NumFormat is set.
+    // The format does not need to exist!
     const SwCharFmt* pFmt = 0;
     sal_uInt16 nWhich = pOld ? pOld->Which() : pNew ? pNew->Which() : 0;
     switch( nWhich )
@@ -351,7 +357,7 @@ void SwNumFmt::UpdateNumNodes( SwDoc* pDoc )
     sal_Bool bDocIsModified = pDoc->IsModified();
     sal_Bool bFnd = sal_False;
     const SwNumRule* pRule;
-    for( sal_uInt16 n = pDoc->GetNumRuleTbl().Count(); !bFnd && n; )
+    for( sal_uInt16 n = pDoc->GetNumRuleTbl().size(); !bFnd && n; )
     {
         pRule = pDoc->GetNumRuleTbl()[ --n ];
         for( sal_uInt8 i = 0; i < MAXLEVEL; ++i )
@@ -407,7 +413,7 @@ SwNumRule::SwNumRule( const String& rNm,
     meDefaultNumberFormatPositionAndSpaceMode( eDefaultNumberFormatPositionAndSpaceMode ),
     msDefaultListId()
 {
-    if( !nRefCount++ )          // zum erstmal, also initialisiern
+    if( !nRefCount++ )          // for the first time, initialize
     {
         SwNumFmt* pFmt;
         sal_uInt8 n;
@@ -485,7 +491,7 @@ SwNumRule::SwNumRule( const String& rNm,
         }
     }
     memset( aFmts, 0, sizeof( aFmts ));
-    OSL_ENSURE( sName.Len(), "NumRule ohne Namen!" );
+    OSL_ENSURE( sName.Len(), "NumRule without a name!" );
 }
 
 SwNumRule::SwNumRule( const SwNumRule& rNumRule )
@@ -522,16 +528,16 @@ SwNumRule::~SwNumRule()
         pNumRuleMap->erase(GetName());
     }
 
-    if( !--nRefCount )          // der letzte macht die Tuer zu
+    if( !--nRefCount )          // the last one closes the door (?)
     {
-            // Nummerierung:
+            // Numbering:
             SwNumFmt** ppFmts = (SwNumFmt**)SwNumRule::aBaseFmts;
             int n;
 
             for( n = 0; n < MAXLEVEL; ++n, ++ppFmts )
                 delete *ppFmts, *ppFmts = 0;
 
-            // Gliederung:
+            // Outline:
             for( n = 0; n < MAXLEVEL; ++n, ++ppFmts )
                 delete *ppFmts, *ppFmts = 0;
 
@@ -553,7 +559,7 @@ void SwNumRule::CheckCharFmts( SwDoc* pDoc )
         if( aFmts[ n ] && 0 != ( pFmt = aFmts[ n ]->GetCharFmt() ) &&
             pFmt->GetDoc() != pDoc )
         {
-            // dann kopieren!
+            // copy
             SwNumFmt* pNew = new SwNumFmt( *aFmts[ n ] );
             pNew->SetCharFmt( pDoc->CopyCharFmt( *pFmt ) );
             delete aFmts[ n ];
@@ -677,7 +683,7 @@ String SwNumRule::MakeNumString( const SwNumberTree::tNumberVector & rNumVector,
             if( !IsContinusNum() &&
                 // - do not include upper levels, if level isn't numbered.
                 rMyNFmt.GetNumberingType() != SVX_NUM_NUMBER_NONE &&
-                rMyNFmt.GetIncludeUpperLevels() )  // nur der eigene Level ?
+                rMyNFmt.GetIncludeUpperLevels() )  // Just the own level?
             {
                 sal_uInt8 n = rMyNFmt.GetIncludeUpperLevels();
                 if( 1 < n )
@@ -694,7 +700,7 @@ String SwNumRule::MakeNumString( const SwNumberTree::tNumberVector & rNumVector,
                 const SwNumFmt& rNFmt = Get( i );
                 if( SVX_NUM_NUMBER_NONE == rNFmt.GetNumberingType() )
                 {
-                    // Soll aus 1.1.1 --> 2. NoNum --> 1..1 oder 1.1 ??
+                    // Should 1.1.1 --> 2. NoNum --> 1..1 or 1.1 ??
                     //                 if( i != rNum.nMyLevel )
                     //                    aStr += aDotStr;
                     continue;
@@ -708,13 +714,13 @@ String SwNumRule::MakeNumString( const SwNumberTree::tNumberVector & rNumVector,
                         aStr += rNFmt.GetNumStr( rNumVector[ i ] );
                 }
                 else
-                    aStr += '0';        // alle 0-Level sind eine 0
+                    aStr += '0';        // all 0 level are a 0
                 if( i != nLevel && aStr.Len() )
                     aStr += aDotStr;
             }
 
-            //JP 14.12.99: the type dont have any number, so dont append
-            //              the Post-/Prefix String
+            // The type doesn't have any number, so don't append
+            // the post-/prefix string
             if( bInclStrings && !bOnlyArabic &&
                 SVX_NUM_CHAR_SPECIAL != rMyNFmt.GetNumberingType() &&
                 SVX_NUM_BITMAP != rMyNFmt.GetNumberingType() )
@@ -746,6 +752,8 @@ String SwNumRule::MakeRefNumString( const SwNodeNum& rNodeNum,
     if ( rNodeNum.GetLevelInListTree() >= 0 )
     {
         sal_Bool bOldHadPrefix = sal_True;
+        bool bFirstIteration = true;
+        ::rtl::OUString sOldPrefix;
 
         const SwNodeNum* pWorkingNodeNum( &rNodeNum );
         do
@@ -781,26 +789,44 @@ String SwNumRule::MakeRefNumString( const SwNodeNum& rNodeNum,
 
                 if (nStrip)
                 {
-                        aPrevStr.Erase( 0, nStrip );
-                        aExtremities.nPrefixChars -= nStrip;
-                        nLen -= nStrip;
+                    aPrevStr.Erase( 0, nStrip );
+                    aExtremities.nPrefixChars -= nStrip;
+                    nLen -= nStrip;
                 }
 
-                if ( bOldHadPrefix &&
+                if ((bFirstIteration || bOldHadPrefix) &&
                      aExtremities.nSuffixChars &&
                      !aExtremities.nPrefixChars
                    )
                 {
-                        aPrevStr.Erase( nLen - aExtremities.nSuffixChars, aExtremities.nSuffixChars );
+                    int nStrip2 = aPrevStr.Len();
+                    while (aPrevStr.Len() - nStrip2 < aExtremities.nSuffixChars)
+                    {
+                        char const cur = aPrevStr.GetChar(nStrip2);
+                        if  (!bFirstIteration && '\t' != cur && ' ' != cur)
+                        {
+                            break;
+                        }
+                        --nStrip2;
+                    }
+                    if (nStrip2 < aPrevStr.Len())
+                    {
+                        aPrevStr.Erase(nStrip2, aPrevStr.Len() - nStrip2);
+                    }
                 }
+                else if (sOldPrefix.getLength())
+                {
+                    aRefNumStr.Insert(sOldPrefix, 0);
+                }
+                sOldPrefix = ::rtl::OUString();
+
                 bOldHadPrefix = ( aExtremities.nPrefixChars >  0);
 
                 aRefNumStr.Insert( aPrevStr, 0 );
-
             }
             else if ( aRefNumStr.Len() > 0 )
             {
-                aRefNumStr.Insert( String::CreateFromAscii(" "), 0 );
+                sOldPrefix += " ";
                 bOldHadPrefix = true;
             }
 
@@ -819,6 +845,7 @@ String SwNumRule::MakeRefNumString( const SwNodeNum& rNodeNum,
             {
                 break;
             }
+            bFirstIteration = false;
         } while ( pWorkingNodeNum &&
                   pWorkingNodeNum->GetLevelInListTree() >= 0 &&
                   static_cast<sal_uInt8>(pWorkingNodeNum->GetLevelInListTree()) >= nRestrictInclToThisLevel );
@@ -827,11 +854,11 @@ String SwNumRule::MakeRefNumString( const SwNodeNum& rNodeNum,
     return aRefNumStr;
 }
 
-//  ----- Copy-Methode vom SwNumRule ------
+//  ----- Copy method of SwNumRule ------
 
-    // eine Art Copy-Constructor, damit die Num-Formate auch an den
-    // richtigen CharFormaten eines Dokumentes haengen !!
-    // (Kopiert die NumFormate und returnt sich selbst)
+    // A kind of copy constructor, so that the num formats are attached
+    // to the right CharFormats of a Document.
+    // Copies the NumFormats and returns itself.
 SwNumRule& SwNumRule::CopyNumRule( SwDoc* pDoc, const SwNumRule& rNumRule )
 {
     for( sal_uInt16 n = 0; n < MAXLEVEL; ++n )
@@ -839,9 +866,8 @@ SwNumRule& SwNumRule::CopyNumRule( SwDoc* pDoc, const SwNumRule& rNumRule )
         Set( n, rNumRule.aFmts[ n ] );
         if( aFmts[ n ] && aFmts[ n ]->GetCharFmt() &&
             USHRT_MAX == pDoc->GetCharFmts()->GetPos( aFmts[n]->GetCharFmt() ))
-            // ueber unterschiedliche Dokumente kopieren, dann
-            // kopiere das entsprechende Char-Format ins neue
-            // Dokument.
+            // If we copy across different Documents, then copy the
+            // corresponding CharFormat into the new Document.
             aFmts[n]->SetCharFmt( pDoc->CopyCharFmt( *aFmts[n]->
                                         GetCharFmt() ) );
     }
