@@ -397,12 +397,12 @@ void SwGetExpField::ChangeExpansion( const SwFrm& rFrm, const SwTxtFld& rFld )
     }
 }
 
-String SwGetExpField::GetPar2() const
+rtl::OUString SwGetExpField::GetPar2() const
 {
     return GetFormula();
 }
 
-void SwGetExpField::SetPar2(const String& rStr)
+void SwGetExpField::SetPar2(const rtl::OUString& rStr)
 {
     SetFormula(rStr);
 }
@@ -524,7 +524,7 @@ SwFieldType* SwSetExpFieldType::Copy() const
     return pNew;
 }
 
-const String& SwSetExpFieldType::GetName() const
+const rtl::OUString& SwSetExpFieldType::GetName() const
 {
     return sName;
 }
@@ -896,21 +896,19 @@ void SwGetExpField::SetValue( const double& rAny )
 /* --------------------------------------------------
     Description: Find the index of the reference text
     following the current field
-    nHint: search starting position after the current
-    field (or 0 if default)
  --------------------------------------------------*/
-xub_StrLen SwGetExpField::GetReferenceTextPos( const SwFmtFld& rFmt, SwDoc& rDoc, unsigned nHint)
+xub_StrLen SwGetExpField::GetReferenceTextPos( const SwFmtFld& rFmt, SwDoc& rDoc)
 {
     //
     const SwTxtFld* pTxtFld = rFmt.GetTxtFld();
     const SwTxtNode& rTxtNode = pTxtFld->GetTxtNode();
     //
-    xub_StrLen nRet = nHint ? nHint : *pTxtFld->GetStart() + 1;
+    xub_StrLen nRet = *pTxtFld->GetStart() + 1;
     String sNodeText = rTxtNode.GetTxt();
     sNodeText.Erase(0, nRet);
     if(sNodeText.Len())
     {
-        // now check if sNodeText starts with a non-alphanumeric character plus blanks
+        //now check if sNodeText starts with a non-alphanumeric character plus a blank
         sal_uInt16 nSrcpt = pBreakIt->GetRealScriptOfText( sNodeText, 0 );
 
         static sal_uInt16 nIds[] =
@@ -937,14 +935,11 @@ xub_StrLen SwGetExpField::GetReferenceTextPos( const SwFmtFld& rFmt, SwDoc& rDoc
             if( !bIsAlphaNum ||
                 (c0 == ' ' || c0 == '\t'))
             {
-                // ignoring blanks
                 nRet++;
-                unsigned i = 1;
-                while (i < sNodeText.Len() &&
-                    (sNodeText.GetChar(i) == ' ' ||
-                     sNodeText.GetChar(i) == '\t')
-                )
-                    nRet++, i++;
+                if( sNodeText.Len() > 1 &&
+                    (sNodeText.GetChar(1) == ' ' ||
+                     sNodeText.GetChar(1) == '\t'))
+                    nRet++;
             }
         }
     }
@@ -956,12 +951,12 @@ xub_StrLen SwGetExpField::GetReferenceTextPos( const SwFmtFld& rFmt, SwDoc& rDoc
     Beschreibung: Parameter setzen
  --------------------------------------------------------------------*/
 
-const String& SwSetExpField::GetPar1() const
+const rtl::OUString& SwSetExpField::GetPar1() const
 {
-    return ((SwSetExpFieldType*)GetTyp())->GetName();
+    return ((const SwSetExpFieldType*)GetTyp())->GetName();
 }
 
-String SwSetExpField::GetPar2() const
+rtl::OUString SwSetExpField::GetPar2() const
 {
     sal_uInt16 nType = ((SwSetExpFieldType*)GetTyp())->GetType();
 
@@ -970,11 +965,11 @@ String SwSetExpField::GetPar2() const
     return GetExpandedFormula();
 }
 
-void SwSetExpField::SetPar2(const String& rStr)
+void SwSetExpField::SetPar2(const rtl::OUString& rStr)
 {
     sal_uInt16 nType = ((SwSetExpFieldType*)GetTyp())->GetType();
 
-    if( !(nType & nsSwGetSetExpType::GSE_SEQ) || rStr.Len() )
+    if( !(nType & nsSwGetSetExpType::GSE_SEQ) || !rStr.isEmpty() )
     {
         if (nType & nsSwGetSetExpType::GSE_STRING)
             SetFormula(rStr);
@@ -1076,7 +1071,7 @@ bool SwInputField::PutValue( const uno::Any& rAny, sal_uInt16 nWhichId )
     switch( nWhichId )
     {
     case FIELD_PROP_PAR1:
-         ::GetString( rAny, aContent );
+         rAny >>= aContent;
         break;
     case FIELD_PROP_PAR2:
         ::GetString( rAny, aPText );
@@ -1096,12 +1091,12 @@ bool SwInputField::PutValue( const uno::Any& rAny, sal_uInt16 nWhichId )
     Beschreibung: Bedingung setzen
  --------------------------------------------------------------------*/
 
-void SwInputField::SetPar1(const String& rStr)
+void SwInputField::SetPar1(const rtl::OUString& rStr)
 {
     aContent = rStr;
 }
 
-const String& SwInputField::GetPar1() const
+const rtl::OUString& SwInputField::GetPar1() const
 {
     return aContent;
 }
@@ -1110,12 +1105,12 @@ const String& SwInputField::GetPar1() const
     Beschreibung: True/False Text
  --------------------------------------------------------------------*/
 
-void SwInputField::SetPar2(const String& rStr)
+void SwInputField::SetPar2(const rtl::OUString& rStr)
 {
     aPText = rStr;
 }
 
-String SwInputField::GetPar2() const
+rtl::OUString SwInputField::GetPar2() const
 {
     return aPText;
 }
