@@ -69,7 +69,6 @@
 
 #include <set>
 #include <map>
-#include <algorithm> // min, max
 
 #include <sfx2/childwin.hxx>
 
@@ -118,7 +117,7 @@ sal_Bool IsFrameBehind( const SwTxtNode& rMyNd, sal_uInt16 nMySttPos,
     if( !pFrm || !pMyFrm || pFrm == pMyFrm )
         return sal_False;
 
-    SvPtrarr aRefArr( 10, 10 ), aArr( 10, 10 );
+    SvPtrarr aRefArr( 10 ), aArr( 10 );
     ::lcl_GetLayTree( pFrm, aRefArr );
     ::lcl_GetLayTree( pMyFrm, aArr );
 
@@ -277,7 +276,7 @@ String SwGetRefField::Expand() const
 
 String SwGetRefField::GetFieldName() const
 {
-    if ( GetTyp()->GetName().Len() > 0 || sSetRefName.Len() > 0 )
+    if ( GetTyp()->GetName().getLength() > 0 || sSetRefName.getLength() > 0 )
     {
         String aStr(GetTyp()->GetName());
         aStr += ' ';
@@ -294,28 +293,16 @@ void SwGetRefField::UpdateField( const SwTxtFld* pFldTxtAttr )
     sTxt.Erase();
 
     SwDoc* pDoc = ((SwGetRefFieldType*)GetTyp())->GetDoc();
-    // finding the reference target (the number)
-    sal_uInt16 nNumStart, nNumEnd;
-    SwTxtNode* pTxtNd = SwGetRefFieldType::FindAnchor(
-        pDoc, sSetRefName, nSubType, nSeqNo, &nNumStart, &nNumEnd
-    );
-    // not found?
+    sal_uInt16 nStt = USHRT_MAX;
+    sal_uInt16 nEnd = USHRT_MAX;
+    SwTxtNode* pTxtNd = SwGetRefFieldType::FindAnchor( pDoc, sSetRefName,
+                                        nSubType, nSeqNo, &nStt, &nEnd );
     if ( !pTxtNd )
     {
         sTxt = ViewShell::GetShellRes()->aGetRefFld_RefItemNotFound;
         return ;
     }
-    // where is the category name (e.g. "Illustration")?
-    rtl::OUString const Text = pTxtNd->GetTxt();
-    unsigned const nCatStart = Text.indexOf(sSetRefName);
-    unsigned const nCatEnd = nCatStart == unsigned(-1) ?
-        unsigned(-1) : nCatStart + sSetRefName.Len();
-    bool const bHasCat = nCatStart != unsigned(-1);
 
-    // length of the referenced text
-    unsigned const nLen = Text.getLength();
-
-    // which format?
     switch( GetFormat() )
     {
     case REF_CONTENT:
@@ -323,95 +310,73 @@ void SwGetRefField::UpdateField( const SwTxtFld* pFldTxtAttr )
     case REF_ONLYCAPTION:
     case REF_ONLYSEQNO:
         {
-            // needed part of Text
-            unsigned nStart, nEnd;
-
             switch( nSubType )
             {
             case REF_SEQUENCEFLD:
-
+                nEnd = pTxtNd->GetTxt().Len();
                 switch( GetFormat() )
                 {
-                // "Category and Number"
                 case REF_ONLYNUMBER:
-                    if (bHasCat) {
-                        nStart = std::min<unsigned>(nNumStart, nCatStart);
-                        nEnd = std::max<unsigned>(nNumEnd, nCatEnd);
-                    } else {
-                        nStart = nNumStart;
-                        nEnd = nNumEnd;
+                    if( nStt + 1 < nEnd )
+                        nEnd = nStt + 1;
+                    nStt = 0;
+                    break;
+
+                case REF_ONLYCAPTION:
+                    {
+                        const SwTxtAttr* const pTxtAttr =
+                            pTxtNd->GetTxtAttrForCharAt(nStt, RES_TXTATR_FIELD);
+                        if( pTxtAttr )
+                            nStt = SwGetExpField::GetReferenceTextPos(
+                                                pTxtAttr->GetFld(), *pDoc );
+                        else if( nStt + 1 < nEnd )
+                            ++nStt;
                     }
                     break;
 
-                // "Caption Text"
-                case REF_ONLYCAPTION: {
-                    // next alphanumeric character after category+number
-                    if (const SwTxtAttr* const pTxtAttr =
-                        pTxtNd->GetTxtAttrForCharAt(nNumStart, RES_TXTATR_FIELD)
-                    ) {
-                        // start searching from nFrom
-                        unsigned const nFrom = bHasCat ?
-                            std::max<unsigned>(nNumStart + 1, nCatEnd) : nNumStart + 1;
-                        nStart = SwGetExpField::GetReferenceTextPos(
-                            pTxtAttr->GetFld(), *pDoc, nFrom
-                        );
-                    } else {
-                        nStart = bHasCat ?
-                            std::max<unsigned>(nNumEnd, nCatEnd) : nNumEnd;
-                    }
-                    nEnd = nLen;
-                    break;
-                }
-
-                // "Numbering"
                 case REF_ONLYSEQNO:
-                    nStart = nNumStart;
-                    nEnd = std::min<unsigned>(nStart + 1, nLen);
+                    if( nStt + 1 < nEnd )
+                        nEnd = nStt + 1;
                     break;
 
-                // "Reference" (whole Text)
                 default:
-                    nStart = 0;
-                    nEnd = nLen;
+                    nStt = 0;
                     break;
                 }
                 break;
 
             case REF_BOOKMARK:
-                nStart = nNumStart;
-                // Text steht ueber verschiedene Nodes verteilt.
-                // Gesamten Text oder nur bis zum Ende vom Node?
-                nEnd = nNumEnd == USHRT_MAX ? nLen : nNumEnd;
+                if( USHRT_MAX == nEnd )
+                {
+                    // Text steht ueber verschiedene Nodes verteilt.
+                    // Gesamten Text oder nur bis zum Ende vom Node?
+                    nEnd = pTxtNd->GetTxt().Len();
+                }
                 break;
 
             case REF_OUTLINE:
-                nStart = nNumStart;
-                nEnd = nNumEnd;
                 break;
 
             case REF_FOOTNOTE:
             case REF_ENDNOTE:
-                // die Nummer oder den NumString besorgen
-                for( unsigned i = 0; i < pDoc->GetFtnIdxs().Count(); ++i )
                 {
-                    SwTxtFtn* const pFtnIdx = pDoc->GetFtnIdxs()[i];
-                    if( nSeqNo == pFtnIdx->GetSeqRefNo() )
-                    {
-                        sTxt = pFtnIdx->GetFtn().GetViewNumStr( *pDoc );
-                        break;
-                    }
+                    // die Nummer oder den NumString besorgen
+                    sal_uInt16 n, nFtnCnt = pDoc->GetFtnIdxs().Count();
+                    SwTxtFtn* pFtnIdx;
+                    for( n = 0; n < nFtnCnt; ++n )
+                        if( nSeqNo == (pFtnIdx = pDoc->GetFtnIdxs()[ n ])->GetSeqRefNo() )
+                        {
+                            sTxt = pFtnIdx->GetFtn().GetViewNumStr( *pDoc );
+                            break;
+                        }
+                    nStt = nEnd;        // kein Bereich, der String ist fertig
                 }
-                return;
-
-            default:
-                nStart = nNumStart;
-                nEnd = nNumEnd;
                 break;
             }
 
-            if( nStart != nEnd ) // ein Bereich?
+            if( nStt != nEnd )      // ein Bereich?
             {
-                sTxt = pTxtNd->GetExpandTxt( nStart, nEnd - nStart );
+                sTxt = pTxtNd->GetExpandTxt( nStt, nEnd - nStt );
 
                 // alle Sonderzeichen entfernen (durch Blanks ersetzen):
                 if( sTxt.Len() )
@@ -434,7 +399,7 @@ void SwGetRefField::UpdateField( const SwTxtFld* pFldTxtAttr )
         {
             const SwTxtFrm* pFrm = (SwTxtFrm*)pTxtNd->getLayoutFrm( pDoc->GetCurrentLayout(), 0,0,sal_False),
                         *pSave = pFrm;
-            while( pFrm && !pFrm->IsInside( nNumStart ) )
+            while( pFrm && !pFrm->IsInside( nStt ) )
                 pFrm = (SwTxtFrm*)pFrm->GetFollow();
 
             if( pFrm || 0 != ( pFrm = pSave ))
@@ -481,14 +446,14 @@ void SwGetRefField::UpdateField( const SwTxtFld* pFldTxtAttr )
             // Node stehen!
             if( pFldTxtAttr->GetpTxtNode() == pTxtNd )
             {
-                sTxt = nNumStart < *pFldTxtAttr->GetStart()
+                sTxt = nStt < *pFldTxtAttr->GetStart()
                             ? aLocaleData.getAboveWord()
                             : aLocaleData.getBelowWord();
                 break;
             }
 
             sTxt = ::IsFrameBehind( *pFldTxtAttr->GetpTxtNode(), *pFldTxtAttr->GetStart(),
-                                    *pTxtNd, nNumStart )
+                                    *pTxtNd, nStt )
                         ? aLocaleData.getAboveWord()
                         : aLocaleData.getBelowWord();
         }
@@ -598,19 +563,19 @@ SwField* SwGetRefField::Copy() const
  --------------------------------------------------------------------*/
 
 
-const String& SwGetRefField::GetPar1() const
+const rtl::OUString& SwGetRefField::GetPar1() const
 {
     return sSetRefName;
 }
 
 
-void SwGetRefField::SetPar1( const String& rName )
+void SwGetRefField::SetPar1( const rtl::OUString& rName )
 {
     sSetRefName = rName;
 }
 
 
-String SwGetRefField::GetPar2() const
+rtl::OUString SwGetRefField::GetPar2() const
 {
     return Expand();
 }
@@ -963,8 +928,7 @@ public:
     String GetName() { return aName; }
 };
 
-SV_DECL_PTRARR_DEL( _RefIdsMaps, _RefIdsMap*, 5, 5 )
-SV_IMPL_PTRARR( _RefIdsMaps, _RefIdsMap* )
+typedef boost::ptr_vector<_RefIdsMap> _RefIdsMaps;
 
 /// Get a sorted list of the field IDs from a document.
 /// @param[in]     rDoc The document to search.
@@ -1126,16 +1090,18 @@ void SwGetRefFieldType::MergeWithOtherDoc( SwDoc& rDestDoc )
             case REF_SEQUENCEFLD:
                 {
                     _RefIdsMap* pMap = 0;
-                    for( sal_uInt16 n = aFldMap.Count(); n; )
-                        if( aFldMap[ --n ]->GetName() == rRefFld.GetSetRefName() )
+                    for( sal_uInt16 n = aFldMap.size(); n; )
+                    {
+                        if( aFldMap[ --n ].GetName().Equals(rRefFld.GetSetRefName()) )
                         {
-                            pMap = aFldMap[ n ];
+                            pMap = &aFldMap[ n ];
                             break;
                         }
+                    }
                     if( !pMap )
                     {
                         pMap = new _RefIdsMap( rRefFld.GetSetRefName() );
-                        aFldMap.C40_INSERT( _RefIdsMap, pMap, aFldMap.Count() );
+                        aFldMap.push_back( pMap );
                     }
 
                     pMap->Check( *pDoc, rDestDoc, rRefFld, sal_True );
