@@ -86,7 +86,6 @@
 #include <vbahelper/vbaaccesshelper.hxx>
 #include <basic/basmgr.hxx>
 #include <comphelper/processfactory.hxx>
-#include <comphelper/sequenceasvector.hxx>
 
 using ::rtl::OUString;
 using namespace ::com::sun::star;
@@ -98,6 +97,8 @@ using namespace ::com::sun::star::lang;
 
 using rtl::OUString;
 
+#ifndef DISABLE_SCRIPTING
+
 class SwVbaCodeNameProvider : public ::cppu::WeakImplHelper1< document::XCodeNameQuery >
 {
     SwDocShell* mpDocShell;
@@ -115,7 +116,7 @@ public:
     rtl::OUString SAL_CALL getCodeNameForObject( const uno::Reference< uno::XInterface >& xIf ) throw( uno::RuntimeException )
     {
         // Initialise the code name
-        if ( msThisDocumentCodeName.getLength() == 0 )
+        if ( msThisDocumentCodeName.isEmpty() )
         {
             try
             {
@@ -257,10 +258,11 @@ public:
     {
         // #FIXME #TODO we really need to be checking against the codename for
         // ThisDocument
-        if ( aName.equals( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM("ThisDocument" ) ) ) )
+        if ( aName == "ThisDocument" )
             return sal_True;
         return sal_False;
     }
+
     ::com::sun::star::uno::Any SAL_CALL getByName( const ::rtl::OUString& aName ) throw (::com::sun::star::container::NoSuchElementException, ::com::sun::star::lang::WrappedTargetException, ::com::sun::star::uno::RuntimeException)
     {
         if ( !hasByName( aName ) )
@@ -283,6 +285,8 @@ public:
 
 };
 
+#endif
+
 struct  ProvNamesId_Type
 {
     const char *    pName;
@@ -486,7 +490,7 @@ OUString    SwXServiceProvider::GetProviderName(sal_uInt16 nObjectType)
 {
     SolarMutexGuard aGuard;
     OUString sRet;
-    sal_uInt16 nEntries = SAL_N_ELEMENTS(aProvNamesId);
+    sal_uInt16 nEntries = sizeof(aProvNamesId) / sizeof(aProvNamesId[0]);
     if(nObjectType < nEntries)
         sRet = rtl::OUString::createFromAscii(aProvNamesId[nObjectType].pName);
     return sRet;
@@ -494,7 +498,7 @@ OUString    SwXServiceProvider::GetProviderName(sal_uInt16 nObjectType)
 
 uno::Sequence<OUString>     SwXServiceProvider::GetAllServiceNames()
 {
-    sal_uInt16 nEntries = SAL_N_ELEMENTS(aProvNamesId);
+    sal_uInt16 nEntries = sizeof(aProvNamesId) / sizeof(aProvNamesId[0]);
     uno::Sequence<OUString> aRet(nEntries);
     OUString* pArray = aRet.getArray();
     sal_uInt16 n = 0;
@@ -514,7 +518,7 @@ uno::Sequence<OUString>     SwXServiceProvider::GetAllServiceNames()
 
 sal_uInt16  SwXServiceProvider::GetProviderType(const OUString& rServiceName)
 {
-    sal_uInt16 nEntries = SAL_N_ELEMENTS(aProvNamesId);
+    sal_uInt16 nEntries = sizeof(aProvNamesId) / sizeof(aProvNamesId[0]);
     for(sal_uInt16 i = 0; i < nEntries; i++ )
     {
         if( COMPARE_EQUAL == rServiceName.compareToAscii(aProvNamesId[i].pName))
@@ -574,12 +578,15 @@ uno::Reference< uno::XInterface >   SwXServiceProvider::MakeInstance(sal_uInt16
         }
         break;
         case  SW_SERVICE_VBAOBJECTPROVIDER :
+#ifndef DISABLE_SCRIPTING
         {
             SwVbaObjectForCodeNameProvider* pObjProv = new SwVbaObjectForCodeNameProvider( pDoc->GetDocShell() );
             xRet =  (cppu::OWeakObject*)pObjProv;
         }
+#endif
         break;
         case  SW_SERVICE_VBACODENAMEPROVIDER :
+#ifndef DISABLE_SCRIPTING
         {
             if ( pDoc->GetDocShell()  && ooo::vba::isAlienWordDoc( *pDoc->GetDocShell() ) )
             {
@@ -587,8 +594,10 @@ uno::Reference< uno::XInterface >   SwXServiceProvider::MakeInstance(sal_uInt16
                 xRet =  (cppu::OWeakObject*)pObjProv;
             }
         }
+#endif
         break;
         case  SW_SERVICE_VBAPROJECTNAMEPROVIDER :
+#ifndef DISABLE_SCRIPTING
         {
                         uno::Reference< container::XNameContainer > xProjProv = pDoc->GetVBATemplateToProjectCache();
                         if ( !xProjProv.is() && pDoc->GetDocShell()  && ooo::vba::isAlienWordDoc( *pDoc->GetDocShell() ) )
@@ -599,8 +608,10 @@ uno::Reference< uno::XInterface >   SwXServiceProvider::MakeInstance(sal_uInt16
             //xRet =  (cppu::OWeakObject*)xProjProv;
             xRet = xProjProv;
         }
+#endif
         break;
         case  SW_SERVICE_VBAGLOBALS :
+#ifndef DISABLE_SCRIPTING
         {
             if ( pDoc )
             {
@@ -615,6 +626,7 @@ uno::Reference< uno::XInterface >   SwXServiceProvider::MakeInstance(sal_uInt16
                 aGlobs >>= xRet;
             }
         }
+#endif
         break;
 
         case  SW_SERVICE_TYPE_FOOTNOTE :
@@ -1632,20 +1644,7 @@ sal_Int32 SwXBookmarks::getCount(void)
     SolarMutexGuard aGuard;
     if(!IsValid())
         throw uno::RuntimeException();
-
-    sal_Int32 count(0);
-    IDocumentMarkAccess* const pMarkAccess = GetDoc()->getIDocumentMarkAccess();
-    for (IDocumentMarkAccess::const_iterator_t ppMark =
-            pMarkAccess->getBookmarksBegin();
-         ppMark != pMarkAccess->getBookmarksEnd(); ++ppMark)
-    {
-        if (IDocumentMarkAccess::BOOKMARK ==
-                IDocumentMarkAccess::GetType(**ppMark))
-        {
-            ++count; // only count real bookmarks
-        }
-    }
-    return count;
+    return GetDoc()->getIDocumentMarkAccess()->getBookmarksCount();
 }
 
 uno::Any SwXBookmarks::getByIndex(sal_Int32 nIndex)
@@ -1658,26 +1657,12 @@ uno::Any SwXBookmarks::getByIndex(sal_Int32 nIndex)
     if(nIndex < 0 || nIndex >= pMarkAccess->getBookmarksCount())
         throw IndexOutOfBoundsException();
 
-    sal_Int32 count(0);
-    for (IDocumentMarkAccess::const_iterator_t ppMark =
-            pMarkAccess->getBookmarksBegin();
-         ppMark != pMarkAccess->getBookmarksEnd(); ++ppMark)
-    {
-        if (IDocumentMarkAccess::BOOKMARK ==
-                IDocumentMarkAccess::GetType(**ppMark))
-        {
-            if (count == nIndex)
-            {
-                uno::Any aRet;
-                const uno::Reference< text::XTextContent > xRef =
-                    SwXBookmark::CreateXBookmark(*GetDoc(), **ppMark);
-                aRet <<= xRef;
-                return aRet;
-            }
-            ++count; // only count real bookmarks
-        }
-    }
-    throw IndexOutOfBoundsException();
+    uno::Any aRet;
+    ::sw::mark::IMark* pBkmk = pMarkAccess->getBookmarksBegin()[nIndex].get();
+    const uno::Reference< text::XTextContent > xRef =
+        SwXBookmark::CreateXBookmark(*GetDoc(), *pBkmk);
+    aRet <<= xRef;
+    return aRet;
 }
 
 uno::Any SwXBookmarks::getByName(const rtl::OUString& rName)
@@ -1706,19 +1691,13 @@ uno::Sequence< OUString > SwXBookmarks::getElementNames(void)
     if(!IsValid())
         throw uno::RuntimeException();
 
-    ::comphelper::SequenceAsVector< ::rtl::OUString > ret;
     IDocumentMarkAccess* const pMarkAccess = GetDoc()->getIDocumentMarkAccess();
-    for (IDocumentMarkAccess::const_iterator_t ppMark =
-            pMarkAccess->getBookmarksBegin();
-         ppMark != pMarkAccess->getBookmarksEnd(); ++ppMark)
-    {
-        if (IDocumentMarkAccess::BOOKMARK ==
-                IDocumentMarkAccess::GetType(**ppMark))
-        {
-            ret.push_back((*ppMark)->GetName()); // only add real bookmarks
-        }
-    }
-    return ret.getAsConstList();
+    uno::Sequence<OUString> aSeq(pMarkAccess->getBookmarksCount());
+    sal_Int32 nCnt = 0;
+    for(IDocumentMarkAccess::const_iterator_t ppMark = pMarkAccess->getBookmarksBegin();
+        ppMark != pMarkAccess->getBookmarksEnd();)
+        aSeq[nCnt++] = (*ppMark++)->GetName();
+    return aSeq;
 }
 
 sal_Bool SwXBookmarks::hasByName(const OUString& rName)
@@ -1744,19 +1723,7 @@ sal_Bool SwXBookmarks::hasElements(void)
     SolarMutexGuard aGuard;
     if(!IsValid())
         throw uno::RuntimeException();
-
-    IDocumentMarkAccess* const pMarkAccess = GetDoc()->getIDocumentMarkAccess();
-    for (IDocumentMarkAccess::const_iterator_t ppMark =
-            pMarkAccess->getBookmarksBegin();
-         ppMark != pMarkAccess->getBookmarksEnd(); ++ppMark)
-    {
-        if (IDocumentMarkAccess::BOOKMARK ==
-                IDocumentMarkAccess::GetType(**ppMark))
-        {
-            return true;
-        }
-    }
-    return false;
+    return GetDoc()->getIDocumentMarkAccess()->getBookmarksCount() != 0;
 }
 
 SwXNumberingRulesCollection::SwXNumberingRulesCollection( SwDoc* _pDoc ) :
@@ -1773,7 +1740,7 @@ sal_Int32 SwXNumberingRulesCollection::getCount(void) throw( uno::RuntimeExcepti
     SolarMutexGuard aGuard;
     if(!IsValid())
         throw uno::RuntimeException();
-    return GetDoc()->GetNumRuleTbl().Count();
+    return GetDoc()->GetNumRuleTbl().size();
 }
 
 uno::Any SwXNumberingRulesCollection::getByIndex(sal_Int32 nIndex)
@@ -1784,9 +1751,9 @@ uno::Any SwXNumberingRulesCollection::getByIndex(sal_Int32 nIndex)
     if(IsValid())
     {
         uno::Reference< XIndexReplace >  xRef;
-        if ( nIndex < GetDoc()->GetNumRuleTbl().Count() )
+        if ( nIndex < (sal_Int32)GetDoc()->GetNumRuleTbl().size() )
         {
-            xRef = new SwXNumberingRules( *GetDoc()->GetNumRuleTbl()[ static_cast< sal_uInt16 >(nIndex) ] );
+            xRef = new SwXNumberingRules( *GetDoc()->GetNumRuleTbl()[ static_cast< sal_uInt16 >(nIndex) ], GetDoc());
             aRet.setValue(&xRef, ::getCppuType((uno::Reference<XIndexReplace>*)0));
         }
 
@@ -1808,7 +1775,7 @@ sal_Bool SwXNumberingRulesCollection::hasElements(void) throw( uno::RuntimeExcep
     SolarMutexGuard aGuard;
     if(!IsValid())
         throw uno::RuntimeException();
-    return GetDoc()->GetNumRuleTbl().Count() > 0;
+    return !GetDoc()->GetNumRuleTbl().empty();
 }
 
 OUString SwXFootnotes::getImplementationName(void) throw( RuntimeException )
@@ -1863,12 +1830,12 @@ uno::Any SwXFootnotes::getByIndex(sal_Int32 nIndex)
 {
     SolarMutexGuard aGuard;
     uno::Any aRet;
+    sal_Int32 nCount = 0;
     if(IsValid())
     {
         sal_uInt16 n, nFtnCnt = GetDoc()->GetFtnIdxs().Count();
         SwTxtFtn* pTxtFtn;
         uno::Reference< XFootnote >  xRef;
-        sal_Int32 nCount = 0;
         for( n = 0; n < nFtnCnt; ++n )
         {
             pTxtFtn = GetDoc()->GetFtnIdxs()[ n ];
@@ -1994,12 +1961,12 @@ uno::Sequence< OUString > SwXReferenceMarks::getElementNames(void) throw( uno::R
     uno::Sequence<OUString> aRet;
     if(IsValid())
     {
-        SvStringsDtor aStrings;
+        std::vector<rtl::OUString> aStrings;
         sal_uInt16 nCount = GetDoc()->GetRefMarks( &aStrings );
         aRet.realloc(nCount);
         OUString* pNames = aRet.getArray();
         for(sal_uInt16 i = 0; i < nCount; i++)
-            pNames[i] = *aStrings.GetObject(i);
+            pNames[i] = aStrings[i];
     }
     else
         throw uno::RuntimeException();
