@@ -34,10 +34,6 @@
 #include <functional>
 #include <iostream>
 
-#if OSL_DEBUG_LEVEL > 1
-#include <cstdio>
-#endif
-
 #include <hintids.hxx>
 #include <comphelper/string.hxx>
 #include <tools/urlobj.hxx>
@@ -122,17 +118,17 @@ static String lcl_getFieldCode( const IFieldmark* pFieldmark ) {
 
     if ( !pFieldmark) {
         return String();
-    } else if ( pFieldmark->GetFieldname( ).equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( ODF_FORMTEXT ) ) ) {
+    } else if ( pFieldmark->GetFieldname( ) == ODF_FORMTEXT ) {
         return String::CreateFromAscii(" FORMTEXT ");
-    } else if ( pFieldmark->GetFieldname( ).equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( ODF_FORMDROPDOWN ) ) ) {
+    } else if ( pFieldmark->GetFieldname( ) == ODF_FORMDROPDOWN ) {
         return String::CreateFromAscii(" FORMDROPDOWN ");
-    } else if ( pFieldmark->GetFieldname( ).equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( ODF_FORMCHECKBOX ) ) ) {
+    } else if ( pFieldmark->GetFieldname( ) == ODF_FORMCHECKBOX ) {
         return String::CreateFromAscii(" FORMCHECKBOX ");
-    } else if ( pFieldmark->GetFieldname( ).equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( ODF_TOC ) ) ) {
+    } else if ( pFieldmark->GetFieldname( ) == ODF_TOC ) {
         return String::CreateFromAscii(" TOC ");
-    } else if ( pFieldmark->GetFieldname( ).equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( ODF_HYPERLINK ) ) ) {
+    } else if ( pFieldmark->GetFieldname( ) == ODF_HYPERLINK ) {
         return String::CreateFromAscii(" HYPERLINK ");
-    } else if ( pFieldmark->GetFieldname( ).equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( ODF_PAGEREF ) ) ) {
+    } else if ( pFieldmark->GetFieldname( ) == ODF_PAGEREF ) {
         return String::CreateFromAscii(" PAGEREF ");
     } else {
         return pFieldmark->GetFieldname();
@@ -143,17 +139,17 @@ ww::eField lcl_getFieldId( const IFieldmark* pFieldmark ) {
     OSL_ENSURE(pFieldmark!=NULL, "where is my fieldmark???");
     if ( !pFieldmark ) {
         return ww::eUNKNOWN;
-    } else if ( pFieldmark->GetFieldname( ).equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( ODF_FORMTEXT ) ) ) {
+    } else if ( pFieldmark->GetFieldname( ) == ODF_FORMTEXT ) {
         return ww::eFORMTEXT;
-    } else if ( pFieldmark->GetFieldname( ).equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( ODF_FORMDROPDOWN ) ) ) {
+    } else if ( pFieldmark->GetFieldname( ) == ODF_FORMDROPDOWN ) {
         return ww::eFORMDROPDOWN;
-    } else if ( pFieldmark->GetFieldname( ).equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( ODF_FORMCHECKBOX ) ) ) {
+    } else if ( pFieldmark->GetFieldname( ) == ODF_FORMCHECKBOX ) {
         return ww::eFORMCHECKBOX;
-    } else if ( pFieldmark->GetFieldname( ).equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( ODF_TOC ) ) ) {
+    } else if ( pFieldmark->GetFieldname( ) == ODF_TOC ) {
         return ww::eTOC;
-    } else if ( pFieldmark->GetFieldname( ).equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( ODF_HYPERLINK ) ) ) {
+    } else if ( pFieldmark->GetFieldname( ) == ODF_HYPERLINK ) {
         return ww::eHYPERLINK;
-    } else if ( pFieldmark->GetFieldname( ).equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( ODF_PAGEREF ) ) ) {
+    } else if ( pFieldmark->GetFieldname( ) == ODF_PAGEREF ) {
         return ww::ePAGEREF;
     } else {
         return ww::eUNKNOWN;
@@ -245,7 +241,7 @@ xub_StrLen lcl_getMinPos( xub_StrLen pos1, xub_StrLen pos2 )
         min = pos2;
     else if ( pos2 == STRING_NOTFOUND && pos1 != STRING_NOTFOUND )
         min = pos1;
-    else if ( pos2 != STRING_NOTFOUND && pos2 != STRING_NOTFOUND )
+    else if ( pos1 != STRING_NOTFOUND && pos2 != STRING_NOTFOUND )
     {
         if ( pos1 < pos2 )
             min = pos1;
@@ -795,7 +791,7 @@ bool AttributeOutputBase::AnalyzeURL( const String& rUrl, const String& /*rTarge
 
                 if ( bkmkName == sLink )
                 {
-                    sMark = String( RTL_CONSTASCII_USTRINGPARAM( "_toc" ) );
+                    sMark = String(  "_toc"  );
                     sMark += String::CreateFromInt32( aIter->second );
                 }
             }
@@ -1626,10 +1622,8 @@ void MSWordExportBase::UpdatePosition( SwWW8AttrIter* aAttrIter, xub_StrLen nAkt
     xub_StrLen nNextPos;
 
     // go to next attribute if no bookmark is found or if the bookmark is behind the next attribute position
-    // It may happend that the WhereNext() wasn't used in the previous increment because there was a
-    // bookmark before it. Use that position before trying to find another one.
     bool bNextBookmark = NearestBookmark( nNextPos, nAktPos, true );
-    if( nAktPos == aAttrIter->WhereNext() && ( !bNextBookmark || nNextPos > aAttrIter->WhereNext() ) )
+    if( !bNextBookmark || nNextPos > aAttrIter->WhereNext() )
         aAttrIter->NextPos();
 }
 
@@ -1678,7 +1672,7 @@ bool MSWordExportBase::NearestBookmark( xub_StrLen& rNearest, const xub_StrLen n
 {
     bool bHasBookmark = false;
 
-    if ( m_rSortedMarksStart.size( ) > 0 )
+    if ( !m_rSortedMarksStart.empty() )
     {
         IMark* pMarkStart = m_rSortedMarksStart.front();
         xub_StrLen nNext = pMarkStart->GetMarkStart().nContent.GetIndex();
@@ -1689,7 +1683,7 @@ bool MSWordExportBase::NearestBookmark( xub_StrLen& rNearest, const xub_StrLen n
         }
     }
 
-    if ( m_rSortedMarksEnd.size( ) > 0 )
+    if ( !m_rSortedMarksEnd.empty() )
     {
         IMark* pMarkEnd = m_rSortedMarksEnd[0];
         xub_StrLen nNext = pMarkEnd->GetMarkEnd().nContent.GetIndex();
@@ -1714,7 +1708,7 @@ void MSWordExportBase::GetSortedBookmarks( const SwTxtNode& rNode, xub_StrLen nA
         IMarkVector aSortedEnd;
         IMarkVector aSortedStart;
         for ( IMarkVector::const_iterator it = aMarksStart.begin(), end = aMarksStart.end();
-              it < end; ++it )
+              it != end; ++it )
         {
             IMark* pMark = (*it);
 
@@ -1793,7 +1787,7 @@ void MSWordExportBase::OutputTextNode( const SwTxtNode& rNode )
 
     if ( aAttrIter.RequiresImplicitBookmark() )
     {
-        String sBkmkName = String( RTL_CONSTASCII_USTRINGPARAM( "_toc" ) );
+        String sBkmkName = String(  "_toc"  );
         sBkmkName += String::CreateFromInt32( rNode.GetIndex() );
         AppendWordBookmark( sBkmkName );
     }
@@ -1842,14 +1836,13 @@ void MSWordExportBase::OutputTextNode( const SwTxtNode& rNode )
                 ::sw::mark::IFieldmark const * const pFieldmark = pMarkAccess->getFieldmarkFor( aPosition );
                 OSL_ENSURE( pFieldmark, "Looks like this doc is broken...; where is the Fieldmark for the FIELDSTART??" );
 
-                if ( pFieldmark && pFieldmark->GetFieldname().equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( ODF_FORMTEXT ) ) )
+                if ( pFieldmark && pFieldmark->GetFieldname() == ODF_FORMTEXT )
                     AppendBookmark( pFieldmark->GetName(), false );
                 ww::eField eFieldId = lcl_getFieldId( pFieldmark );
                 String sCode = lcl_getFieldCode( pFieldmark );
-                if ( pFieldmark && pFieldmark->GetFieldname().equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( ODF_UNHANDLED ) ) )
+                if ( pFieldmark && pFieldmark->GetFieldname() == ODF_UNHANDLED )
                 {
-                    IFieldmark::parameter_map_t::const_iterator it = pFieldmark->GetParameters()->find(
-                            rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( ODF_ID_PARAM )) );
+                    IFieldmark::parameter_map_t::const_iterator it = pFieldmark->GetParameters()->find( ODF_ID_PARAM );
                     if ( it != pFieldmark->GetParameters()->end() )
                     {
                         rtl::OUString sFieldId;
@@ -1857,8 +1850,7 @@ void MSWordExportBase::OutputTextNode( const SwTxtNode& rNode )
                         eFieldId = (ww::eField)sFieldId.toInt32();
                     }
 
-                    it = pFieldmark->GetParameters()->find(
-                            rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( ODF_CODE_PARAM )) );
+                    it = pFieldmark->GetParameters()->find( ODF_CODE_PARAM );
                     if ( it != pFieldmark->GetParameters()->end() )
                     {
                         rtl::OUString sOUCode;
@@ -1867,38 +1859,37 @@ void MSWordExportBase::OutputTextNode( const SwTxtNode& rNode )
                     }
                 }
                 OutputField( NULL, eFieldId, sCode, WRITEFIELD_START | WRITEFIELD_CMD_START );
-                if ( pFieldmark && pFieldmark->GetFieldname( ).equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( ODF_FORMTEXT ) ) )
+                if ( pFieldmark && pFieldmark->GetFieldname( ) == ODF_FORMTEXT )
                     WriteFormData( *pFieldmark );
-                else if ( pFieldmark && pFieldmark->GetFieldname( ).equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( ODF_HYPERLINK ) ) )
+                else if ( pFieldmark && pFieldmark->GetFieldname( ) == ODF_HYPERLINK )
                     WriteHyperlinkData( *pFieldmark );
                 OutputField( NULL, lcl_getFieldId( pFieldmark ), String(), WRITEFIELD_CMD_END );
 
-                if ( pFieldmark && pFieldmark->GetFieldname().equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( ODF_UNHANDLED ) ) )
+                if ( pFieldmark && pFieldmark->GetFieldname() == ODF_UNHANDLED )
                 {
                     // Check for the presence of a linked OLE object
-                    IFieldmark::parameter_map_t::const_iterator it = pFieldmark->GetParameters()->find(
-                            rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( ODF_OLE_PARAM )) );
+                    IFieldmark::parameter_map_t::const_iterator it = pFieldmark->GetParameters()->find( ODF_OLE_PARAM );
                     if ( it != pFieldmark->GetParameters()->end() )
                     {
                         rtl::OUString sOleId;
                         uno::Any aValue = it->second;
                         aValue >>= sOleId;
-                        if ( sOleId.getLength( ) > 0 )
+                        if ( !sOleId.isEmpty() )
                             OutputLinkedOLE( sOleId );
                     }
                 }
             }
             else if ( ch == CH_TXT_ATR_FIELDEND )
             {
-                SwPosition aPosition( rNode, SwIndex( const_cast< SwTxtNode* >( &rNode ), nAktPos - 1 ) );
+                SwPosition aPosition( rNode, SwIndex( const_cast< SwTxtNode* >( &rNode ), nAktPos ) );
                 ::sw::mark::IFieldmark const * const pFieldmark = pMarkAccess->getFieldmarkFor( aPosition );
+
                 OSL_ENSURE( pFieldmark, "Looks like this doc is broken...; where is the Fieldmark for the FIELDEND??" );
 
                 ww::eField eFieldId = lcl_getFieldId( pFieldmark );
-                if ( pFieldmark && pFieldmark->GetFieldname().equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( ODF_UNHANDLED ) ) )
+                if ( pFieldmark && pFieldmark->GetFieldname() == ODF_UNHANDLED )
                 {
-                    IFieldmark::parameter_map_t::const_iterator it = pFieldmark->GetParameters()->find(
-                            rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( ODF_ID_PARAM )) );
+                    IFieldmark::parameter_map_t::const_iterator it = pFieldmark->GetParameters()->find( ODF_ID_PARAM );
                     if ( it != pFieldmark->GetParameters()->end() )
                     {
                         rtl::OUString sFieldId;
@@ -1908,7 +1899,7 @@ void MSWordExportBase::OutputTextNode( const SwTxtNode& rNode )
                 }
 
                 OutputField( NULL, eFieldId, String(), WRITEFIELD_CLOSE );
-                if ( pFieldmark && pFieldmark->GetFieldname().equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( ODF_FORMTEXT ) ) )
+                if ( pFieldmark && pFieldmark->GetFieldname() == ODF_FORMTEXT )
                     AppendBookmark( pFieldmark->GetName(), false );
             }
             else if ( ch == CH_TXT_ATR_FORMELEMENT )
@@ -1917,8 +1908,8 @@ void MSWordExportBase::OutputTextNode( const SwTxtNode& rNode )
                 ::sw::mark::IFieldmark const * const pFieldmark = pMarkAccess->getFieldmarkFor( aPosition );
                 OSL_ENSURE( pFieldmark, "Looks like this doc is broken...; where is the Fieldmark for the FIELDSTART??" );
 
-                bool isDropdownOrCheckbox = pFieldmark && (pFieldmark->GetFieldname( ).equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( ODF_FORMDROPDOWN ) ) ||
-                    pFieldmark->GetFieldname( ).equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( ODF_FORMCHECKBOX ) ));
+                bool isDropdownOrCheckbox = pFieldmark && (pFieldmark->GetFieldname( ) == ODF_FORMDROPDOWN ||
+                    pFieldmark->GetFieldname( ) == ODF_FORMCHECKBOX );
 
                 if ( isDropdownOrCheckbox )
                     AppendBookmark( pFieldmark->GetName(), 0 );
