@@ -33,7 +33,6 @@
 #include <vcl/svapp.hxx>
 #include <vcl/wrkwin.hxx>
 #include <vcl/jobset.hxx>
-#include <tools/urlobj.hxx>
 #include <svl/whiter.hxx>
 #include <svl/zforlist.hxx>
 #include <svl/eitem.hxx>
@@ -276,7 +275,7 @@ sal_Bool SwDocShell::ConvertFrom( SfxMedium& rMedium )
 
     SW_MOD()->SetEmbeddedLoadSave( sal_False );
 
-    SetError( nErr, ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX ) ) );
+    SetError( nErr, ::rtl::OUString(  OSL_LOG_PREFIX  ) );
     sal_Bool bOk = !IsError( nErr );
 
     if ( bOk && !pDoc->IsInLoadAsynchron() )
@@ -372,7 +371,7 @@ sal_Bool SwDocShell::Save()
         }
         SW_MOD()->SetEmbeddedLoadSave( sal_False );
     }
-    SetError( nErr ? nErr : nVBWarning, ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX ) ) );
+    SetError( nErr ? nErr : nVBWarning, ::rtl::OUString(  OSL_LOG_PREFIX  ) );
 
     SfxViewFrame* pFrm = pWrtShell ? pWrtShell->GetView().GetViewFrame() : 0;
     if( pFrm )
@@ -507,8 +506,11 @@ sal_Bool SwDocShell::SaveAs( SfxMedium& rMedium )
         pDoc->SetOle2Link( aOldOLELnk );
 
         SW_MOD()->SetEmbeddedLoadSave( sal_False );
+
+        // Increase RSID
+        pDoc->setRsid( pDoc->getRsid() );
     }
-    SetError( nErr ? nErr : nVBWarning, ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX ) ) );
+    SetError( nErr ? nErr : nVBWarning, ::rtl::OUString(  OSL_LOG_PREFIX  ) );
 
     return !IsError( nErr );
 }
@@ -578,6 +580,7 @@ sal_Bool SwDocShell::ConvertTo( SfxMedium& rMedium )
 
     if( pFlt->GetUserData().EqualsAscii( "HTML") )
     {
+#ifndef DISABLE_SCRIPTING
         SvxHtmlOptions& rHtmlOpt = SvxHtmlOptions::Get();
         if( !rHtmlOpt.IsStarBasic() && rHtmlOpt.IsStarBasicWarning() && HasBasic() )
         {
@@ -594,12 +597,13 @@ sal_Bool SwDocShell::ConvertTo( SfxMedium& rMedium )
                     Sequence<rtl::OUString> aModNames = xLib->getElementNames();
                     if(aModNames.getLength())
                     {
-                        SetError(WARN_SWG_HTML_NO_MACROS, ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX ) ) );
+                        SetError(WARN_SWG_HTML_NO_MACROS, ::rtl::OUString(  OSL_LOG_PREFIX  ) );
                         break;
                     }
                 }
             }
         }
+#endif
         UpdateDocInfoForSave();
     }
 
@@ -665,7 +669,7 @@ sal_Bool SwDocShell::ConvertTo( SfxMedium& rMedium )
                 // TODO/MBA: testing
                 uno::Reference < beans::XPropertySet > xSet( rMedium.GetStorage(), uno::UNO_QUERY );
                 if ( xSet.is() )
-                    xSet->setPropertyValue( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("MediaType")), uno::makeAny( ::rtl::OUString( SotExchange::GetFormatMimeType( nSaveClipId ) ) ) );
+                    xSet->setPropertyValue( ::rtl::OUString("MediaType"), uno::makeAny( ::rtl::OUString( SotExchange::GetFormatMimeType( nSaveClipId ) ) ) );
             }
             catch (const uno::Exception&)
             {
@@ -749,7 +753,7 @@ sal_Bool SwDocShell::ConvertTo( SfxMedium& rMedium )
     }
 
     SW_MOD()->SetEmbeddedLoadSave( sal_False );
-    SetError( nErrno ? nErrno : nVBWarning, ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX ) ) );
+    SetError( nErrno ? nErrno : nVBWarning, ::rtl::OUString(  OSL_LOG_PREFIX  ) );
     if( !rMedium.IsStorage() )
         rMedium.CloseOutStream();
 
@@ -1031,6 +1035,11 @@ void SwDocShell::GetState(SfxItemSet& rSet)
                 rSet.DisableItem( nWhich );
             break;
 
+        case FN_OPEN_FILE:
+            if( ISA( SwWebDocShell ) )
+                rSet.DisableItem( nWhich );
+            break;
+
         case SID_ATTR_YEAR2000:
             {
                 const SvNumberFormatter* pFmtr = pDoc->GetNumberFormatter(sal_False);
@@ -1221,7 +1230,7 @@ uno::Reference< frame::XController >
     return aRet;
 }
 
-static const char* s_EventNames[] =
+static const char* pEventNames[] =
 {
     "OnPageCountChange",
     "OnMailMerge",
@@ -1230,7 +1239,6 @@ static const char* s_EventNames[] =
     "OnFieldMergeFinished",
     "OnLayoutFinished"
 };
-static sal_Int32 const s_nEvents(sizeof(s_EventNames)/sizeof(s_EventNames[0]));
 
 Sequence< OUString >    SwDocShell::GetEventNames()
 {
@@ -1248,12 +1256,12 @@ Sequence< OUString >    SwDocShell::GetEventNames()
     return aRet;
 }
 
+static sal_Int32 nEvents=13;
+
 rtl::OUString SwDocShell::GetEventName( sal_Int32 nIndex )
 {
-    if (nIndex < s_nEvents)
-    {
-        return ::rtl::OUString::createFromAscii(s_EventNames[nIndex]);
-    }
+    if ( nIndex<nEvents )
+        return ::rtl::OUString::createFromAscii(pEventNames[nIndex]);
     return rtl::OUString();
 }
 
