@@ -59,7 +59,7 @@
 #include <drawinglayer/primitive2d/textlayoutdevice.hxx>
 #include <drawinglayer/primitive2d/textprimitive2d.hxx>
 #include <editeng/boxitem.hxx>
-#include <svtools/svtdata.hxx>
+#include <svtools/svtresid.hxx>
 #include <svx/hdft.hxx>
 #include <svx/sdr/contact/objectcontacttools.hxx>
 #include <vcl/decoview.hxx>
@@ -201,9 +201,9 @@ const SwPageFrm* SwHeaderFooterWin::GetPageFrame( )
 void SwHeaderFooterWin::SetOffset( Point aOffset, long nXLineStart, long nXLineEnd )
 {
     // Compute the text to show
-    m_sLabel = ResId::toString( SW_RES( STR_HEADER_TITLE ) );
+    m_sLabel = SW_RESSTR( STR_HEADER_TITLE );
     if ( !m_bIsHeader )
-        m_sLabel = ResId::toString( SW_RES( STR_FOOTER_TITLE ) );
+        m_sLabel = SW_RESSTR( STR_FOOTER_TITLE );
     sal_Int32 nPos = m_sLabel.lastIndexOf( rtl::OUString::createFromAscii( "%1" ) );
     m_sLabel = m_sLabel.replaceAt( nPos, 2, GetPageFrame()->GetPageDesc()->GetName() );
 
@@ -390,7 +390,6 @@ void SwHeaderFooterWin::Paint( const Rectangle& )
                 aSeq, BColorModifier( Color( COL_WHITE ).getBColor(), 1.0 - nFadeRate, BCOLORMODIFYMODE_INTERPOLATE ) ) );
 
     pProcessor->process( aGhostedSeq );
-    delete pProcessor;
 }
 
 bool SwHeaderFooterWin::IsEmptyHeaderFooter( )
@@ -514,7 +513,7 @@ void SwHeaderFooterWin::Select( )
     ExecuteCommand( GetCurItemId() );
 }
 
-IMPL_LINK( SwHeaderFooterWin, FadeHandler, Timer *, EMPTYARG )
+IMPL_LINK_NOARG(SwHeaderFooterWin, FadeHandler)
 {
     const int TICKS_BEFORE_WE_APPEAR = 10;
     if ( m_bIsAppearing && m_nDelayAppearing < TICKS_BEFORE_WE_APPEAR )
