@@ -37,7 +37,6 @@
 #include <hintids.hxx>
 
 #include <vcl/msgbox.hxx>
-#include <tools/urlobj.hxx>
 #include <sfx2/app.hxx>
 #include <sfx2/imgmgr.hxx>
 #include <svx/gallery.hxx>
@@ -263,11 +262,6 @@ void SwNumPositionTabPage::InitControls()
         nMask <<= 1;
 
     }
-    if (MAXLEVEL <= nLvl)
-    {
-        OSL_ENSURE(false, "cannot happen.");
-        return;
-    }
     if(bSameDistBorderNum)
     {
         long nDistBorderNum;
@@ -575,7 +569,7 @@ void SwNumPositionTabPage::SetWrtShell(SwWrtShell* pSh)
     aIndentAtMF.SetUnit( eMetric );
 }
 
-IMPL_LINK( SwNumPositionTabPage, EditModifyHdl, Edit *, EMPTYARG )
+IMPL_LINK_NOARG(SwNumPositionTabPage, EditModifyHdl)
 {
     sal_uInt16 nMask = 1;
     for(sal_uInt16 i = 0; i < MAXLEVEL; i++)
@@ -746,11 +740,10 @@ IMPL_LINK( SwNumPositionTabPage, RelativeHdl, CheckBox *, pBox )
     return 0;
 }
 
-IMPL_LINK( SwNumPositionTabPage, LabelFollowedByHdl_Impl, ListBox*, EMPTYARG )
+IMPL_LINK_NOARG(SwNumPositionTabPage, LabelFollowedByHdl_Impl)
 {
     // determine value to be set at the chosen list levels
-    SvxNumberFormat::SvxNumLabelFollowedBy eLabelFollowedBy =
-                                                    SvxNumberFormat::LISTTAB;
+    SvxNumberFormat::LabelFollowedBy eLabelFollowedBy = SvxNumberFormat::LISTTAB;
     {
         const sal_uInt16 nPos = aLabelFollowedByLB.GetSelectEntryPos();
         if ( nPos == 1 )
@@ -882,7 +875,7 @@ IMPL_LINK( SwNumPositionTabPage, IndentAtHdl_Impl, MetricField*, pFld )
     return 0;
 }
 
-IMPL_LINK( SwNumPositionTabPage, StandardHdl, PushButton *, EMPTYARG )
+IMPL_LINK_NOARG(SwNumPositionTabPage, StandardHdl)
 {
     sal_uInt16 nMask = 1;
     for(sal_uInt16 i = 0; i < MAXLEVEL; i++)
@@ -1024,7 +1017,7 @@ short  SwSvxNumBulletTabDialog::Ok()
     return nRet;
 }
 
-IMPL_LINK(SwSvxNumBulletTabDialog, RemoveNumberingHdl, PushButton*, EMPTYARG)
+IMPL_LINK_NOARG(SwSvxNumBulletTabDialog, RemoveNumberingHdl)
 {
     EndDialog(RET_USER);
     return 0;
