@@ -1010,12 +1010,6 @@ void   SwTableColumnPage::ModifyHdl( PercentField* pEdit )
             if(pEdit == pFieldArr[i])
                 break;
 
-        if (MET_FIELDS <= i)
-        {
-            OSL_ENSURE(false, "cannot happen.");
-            return;
-        }
-
         SetVisibleWidth(aValueTbl[i], static_cast< SwTwips >(pEdit->DenormalizePercent(pEdit->GetValue( FUNIT_TWIP ))) );
         nAktPos = aValueTbl[i];
 
@@ -1415,7 +1409,7 @@ sal_Bool  SwTextFlowPage::FillItemSet( SfxItemSet& rSet )
 {
     sal_Bool bModified = sal_False;
 
-    //Ueberschrift wiederholen
+    // Repeat Heading
     if(aHeadLineCB.IsChecked() != aHeadLineCB.GetSavedValue() ||
         String::CreateFromInt32( static_cast< sal_Int32 >(aRepeatHeaderNF.GetValue()) ) != aRepeatHeaderNF.GetSavedValue() )
     {
@@ -1438,7 +1432,7 @@ sal_Bool  SwTextFlowPage::FillItemSet( SfxItemSet& rSet )
 
     sal_Bool bState = aPageCollCB.IsChecked();
 
-    //Wenn Seitenvorlage, dann kein Break
+    // If we have a page style, then there's no break
     sal_Bool bPageItemPut = sal_False;
     if ( bState != aPageCollCB.GetSavedValue() ||
          ( bState &&
@@ -1723,7 +1717,7 @@ void SwTextFlowPage::SetShell(SwWrtShell* pSh)
     }
 }
 
-IMPL_LINK( SwTextFlowPage, PageBreakHdl_Impl, CheckBox*, EMPTYARG )
+IMPL_LINK_NOARG(SwTextFlowPage, PageBreakHdl_Impl)
 {
     if( aPgBrkCB.IsChecked() )
     {
@@ -1761,7 +1755,7 @@ IMPL_LINK( SwTextFlowPage, PageBreakHdl_Impl, CheckBox*, EMPTYARG )
     return 0;
 }
 
-IMPL_LINK( SwTextFlowPage, ApplyCollClickHdl_Impl, CheckBox*, EMPTYARG )
+IMPL_LINK_NOARG(SwTextFlowPage, ApplyCollClickHdl_Impl)
 {
     sal_Bool bEnable = sal_False;
     if ( aPageCollCB.IsChecked() &&
@@ -1840,7 +1834,7 @@ IMPL_LINK( SwTextFlowPage, SplitRowHdl_Impl, TriStateBox*, pBox )
     return 0;
 }
 
-IMPL_LINK( SwTextFlowPage, HeadLineCBClickHdl, void*, EMPTYARG )
+IMPL_LINK_NOARG(SwTextFlowPage, HeadLineCBClickHdl)
 {
     aRepeatHeaderCombo.Enable(aHeadLineCB.IsChecked());
 
