@@ -38,18 +38,15 @@
 #include <doctok/sprmids.hxx>
 #include <ooxml/OOXMLnamespaceids.hxx>
 #include <dmapper/DomainMapper.hxx>
-#include <GraphicHelpers.hxx>
+#include <dmapper/GraphicHelpers.hxx>
 #include <comphelper/embeddedobjectcontainer.hxx>
 #include <tools/globname.hxx>
 #include <comphelper/classids.hxx>
-#include <sfx2/sfxbasemodel.hxx>
 #include "OOXMLFastContextHandler.hxx"
 #include "OOXMLFactory.hxx"
 #include "Handler.hxx"
 #include "ooxmlLoggers.hxx"
 
-static const ::rtl::OUString aEmptyStr;
-
 static const sal_uInt8 s0x7[] = { 0x7, 0x0 };
 static const sal_uInt8 s0xd[] = { 0xd, 0x0 };
 static const sal_uInt8 sCR[] = { 0xd, 0x0 };
@@ -112,7 +109,7 @@ public:
     {
         string s((*QNameToString::Instance())(rId));
 
-        if (s.size() == 0)
+        if (s.empty())
             s = "(fasttoken)" + fastTokenToId(rId);
         else
             s = "(qname)" + s;
@@ -418,7 +415,7 @@ void OOXMLFastContextHandler::dumpXml( const TagLogger::Pointer_t pLogger ) cons
     static char sBuffer[128];
     snprintf(sBuffer, sizeof(sBuffer), "%p", this);
 
-    pLogger->attribute("parent", sBuffer);
+    pLogger->attribute("parent", std::string(sBuffer));
     pLogger->attribute("type", getType());
     pLogger->attribute("resource", resourceToString(getResource()));
     pLogger->attribute("token", fastTokenToId(getToken()));
@@ -429,7 +426,7 @@ void OOXMLFastContextHandler::dumpXml( const TagLogger::Pointer_t pLogger ) cons
     if (pVal.get() != NULL)
         pLogger->attribute("value", pVal->toString());
     else
-        pLogger->attribute("value", "(null)");
+        pLogger->attribute("value", std::string("(null)"));
 
     pLogger->propertySet(getPropertySet(),
             IdToString::Pointer_t(new OOXMLIdToString()));
@@ -449,7 +446,7 @@ void OOXMLFastContextHandler::setId(Id rId)
     static char sBuffer[256];
     snprintf(sBuffer, sizeof(sBuffer), "%" SAL_PRIuUINT32, rId);
 
-    debug_logger->attribute("id", sBuffer);
+    debug_logger->attribute("id", std::string(sBuffer));
     debug_logger->attribute("name", (*QNameToString::Instance())(rId));
     debug_logger->endElement();
 #endif
@@ -1079,9 +1076,9 @@ void OOXMLFastContextHandler::setForwardEvents(bool bForwardEvents)
     debug_logger->startElement("contexthandler.setForwardEvents");
 
     if (bForwardEvents)
-        debug_logger->chars("true");
+        debug_logger->chars(std::string("true"));
     else
-        debug_logger->chars("false");
+        debug_logger->chars(std::string("false"));
 
     debug_logger->endElement();
 #endif
@@ -1342,7 +1339,7 @@ void OOXMLFastContextHandlerProperties::dumpXml( const TagLogger::Pointer_t pLog
     static char sBuffer[128];
     snprintf(sBuffer, sizeof(sBuffer), "%p", this);
 
-    pLogger->attribute("parent", sBuffer);
+    pLogger->attribute("parent", std::string(sBuffer));
     pLogger->attribute("type", getType());
     pLogger->attribute("resource", resourceToString(getResource()));
     pLogger->attribute("token", fastTokenToId(getToken()));
@@ -1353,7 +1350,7 @@ void OOXMLFastContextHandlerProperties::dumpXml( const TagLogger::Pointer_t pLog
     if (pVal.get() != NULL)
         pLogger->attribute("value", pVal->toString());
     else
-        pLogger->attribute("value", "(null)");
+        pLogger->attribute("value", std::string("(null)"));
 
     pLogger->attribute("resolve", mbResolve ? "resolve" : "noResolve");
 
@@ -1465,7 +1462,7 @@ void OOXMLFastContextHandlerProperties::setParent
 {
 #ifdef DEBUG_ELEMENT
     debug_logger->startElement("setParent");
-    debug_logger->chars("OOXMLFastContextHandlerProperties");
+    debug_logger->chars(std::string("OOXMLFastContextHandlerProperties"));
     debug_logger->endElement();
 #endif
 
@@ -1953,7 +1950,7 @@ OOXMLFastContextHandlerShape::OOXMLFastContextHandlerShape
         else
         {
             debug_logger->startElement("error");
-            debug_logger->chars("failed to get shape handler");
+            debug_logger->chars(std::string("failed to get shape handler"));
             debug_logger->endElement();
         }
 #endif
@@ -2244,7 +2241,12 @@ OOXMLFastContextHandlerWrapper::lcl_createFastChildContext
 
     bool bInNamespaces = mMyNamespaces.find(nNameSpace) != mMyNamespaces.end();
     bool bInTokens = mMyTokens.find( Element ) != mMyTokens.end( );
-    if ( bInNamespaces )
+
+    // We have methods to _add_ individual tokens or whole namespaces to be
+    // processed by writerfilter (instead of oox), but we have no method to
+    // filter out a single token. Just hardwire the wrap token here till we
+    // need a more generic solution.
+    if ( bInNamespaces && Element != static_cast<sal_Int32>(NS_vml_wordprocessingDrawing | OOXML_wrap) )
         xResult.set(OOXMLFactory::getInstance()->createFastChildContextFromStart(this, Element));
     else if (mxContext.is())
     {
@@ -2450,12 +2452,8 @@ void OOXMLFastContextHandlerMath::process()
     rtl::OUString aName;
     uno::Reference< embed::XEmbeddedObject > ref = container.CreateEmbeddedObject( name.GetByteSequence(), aName );
     uno::Reference< uno::XInterface > component( ref->getComponent(), uno::UNO_QUERY );
-// gcc4.4 (and 4.3 and possibly older) have a problem with dynamic_cast directly to the target class,
-// so help it with an intermediate cast. I'm not sure what exactly the problem is, seems to be unrelated
-// to RTLD_GLOBAL, so most probably a gcc bug.
-    oox::FormulaImportBase* import = dynamic_cast< oox::FormulaImportBase* >( dynamic_cast< SfxBaseModel* >(component.get()));
-    assert( import != NULL );
-    import->readFormulaOoxml( buffer );
+    if( oox::FormulaImportBase* import = dynamic_cast< oox::FormulaImportBase* >( component.get()))
+        import->readFormulaOoxml( buffer );
     if (isForwardEvents())
     {
         OOXMLPropertySet * pProps = new OOXMLPropertySetImpl();
